@@ -4,6 +4,7 @@ namespace dokuwiki\Action;
 
 use dokuwiki\Action\Exception\ActionAbort;
 use dokuwiki\Action\Exception\ActionDisabledException;
+use dokuwiki\Extension\AuthPlugin;
 
 /**
  * Class ProfileDelete
@@ -12,31 +13,33 @@ use dokuwiki\Action\Exception\ActionDisabledException;
  *
  * @package dokuwiki\Action
  */
-class ProfileDelete extends AbstractUserAction {
-
+class ProfileDelete extends AbstractUserAction
+{
     /** @inheritdoc */
-    public function minimumPermission() {
+    public function minimumPermission()
+    {
         return AUTH_NONE;
     }
 
     /** @inheritdoc */
-    public function checkPreconditions() {
+    public function checkPreconditions()
+    {
         parent::checkPreconditions();
 
-        /** @var \dokuwiki\Extension\AuthPlugin $auth */
+        /** @var AuthPlugin $auth */
         global $auth;
-        if(!$auth->canDo('delUser')) throw new ActionDisabledException();
+        if (!$auth->canDo('delUser')) throw new ActionDisabledException();
     }
 
     /** @inheritdoc */
-    public function preProcess() {
+    public function preProcess()
+    {
         global $lang;
-        if(auth_deleteprofile()) {
+        if (auth_deleteprofile()) {
             msg($lang['profdeleted'], 1);
             throw new ActionAbort('show');
         } else {
             throw new ActionAbort('profile');
         }
     }
-
 }
