@@ -7,7 +7,6 @@ namespace dokuwiki\Cache;
  */
 class CacheParser extends Cache
 {
-
     public $file = '';       // source file for cache
     public $mode = '';       // input mode (represents the processing the input file will undergo)
     public $page = '';
@@ -35,32 +34,30 @@ class CacheParser extends Cache
     /**
      * method contains cache use decision logic
      *
-     * @return bool               see useCache()
+     * @return bool see useCache()
      */
     public function makeDefaultCacheDecision()
     {
-
         if (!file_exists($this->file)) {
+            // source doesn't exist
             return false;
-        }                   // source exists?
+        }
         return parent::makeDefaultCacheDecision();
     }
 
     protected function addDependencies()
     {
-
         // parser cache file dependencies ...
-        $files = array(
-            $this->file,                              // ... source
-            DOKU_INC . 'inc/Parsing/Parser.php',                // ... parser
-            DOKU_INC . 'inc/parser/handler.php',               // ... handler
-        );
-        $files = array_merge($files, getConfigFiles('main'));    // ... wiki settings
+        $files = [
+            $this->file, // source
+            DOKU_INC . 'inc/Parsing/Parser.php', // parser
+            DOKU_INC . 'inc/parser/handler.php', // handler
+        ];
+        $files = array_merge($files, getConfigFiles('main')); // wiki settings
 
-        $this->depends['files'] = !empty($this->depends['files']) ?
-            array_merge($files, $this->depends['files']) :
-            $files;
+        $this->depends['files'] = empty($this->depends['files']) ?
+            $files :
+            array_merge($files, $this->depends['files']);
         parent::addDependencies();
     }
-
 }
