@@ -11,12 +11,11 @@ namespace dokuwiki\Form;
  */
 class FieldsetOpenElement extends TagOpenElement
 {
-
     /**
      * @param string $legend
      * @param array $attributes
      */
-    public function __construct($legend='', $attributes = array())
+    public function __construct($legend = '', $attributes = [])
     {
         // this is a bit messy and we just do it for the nicer class hierarchy
         // the parent would expect the tag in $value but we're storing the
@@ -32,9 +31,9 @@ class FieldsetOpenElement extends TagOpenElement
      */
     public function toHTML()
     {
-        $html = '<fieldset '.buildAttributes($this->attrs()).'>';
+        $html = '<fieldset ' . buildAttributes($this->attrs()) . '>';
         $legend = $this->val();
-        if ($legend) $html .= DOKU_LF.'<legend>'.hsc($legend).'</legend>';
+        if ($legend) $html .= DOKU_LF . '<legend>' . hsc($legend) . '</legend>';
         return $html;
     }
 }
