@@ -7,10 +7,11 @@ namespace dokuwiki\Menu\Item;
  *
  * Opens the Admin screen. Only shown to managers or above
  */
-class Admin extends AbstractItem {
-
+class Admin extends AbstractItem
+{
     /** @inheritdoc */
-    public function __construct() {
+    public function __construct()
+    {
         parent::__construct();
 
         $this->svg = DOKU_INC . 'lib/images/menu/settings.svg';
@@ -20,9 +21,8 @@ class Admin extends AbstractItem {
     public function visibleInContext($ctx)
     {
         global $INFO;
-        if(!$INFO['ismanager']) return false;
+        if (!$INFO['ismanager']) return false;
 
         return parent::visibleInContext($ctx);
     }
-
 }
