@@ -7,18 +7,18 @@ namespace dokuwiki\Menu\Item;
  *
  * Access the subscription management view
  */
-class Subscribe extends AbstractItem {
-
+class Subscribe extends AbstractItem
+{
     /** @inheritdoc */
-    public function __construct() {
+    public function __construct()
+    {
         global $INPUT;
         parent::__construct();
 
-        if(!$INPUT->server->str('REMOTE_USER')) {
+        if (!$INPUT->server->str('REMOTE_USER')) {
             throw new \RuntimeException("subscribe is only for logged in users");
         }
 
         $this->svg = DOKU_INC . 'lib/images/menu/09-subscribe_email-outline.svg';
     }
-
 }
