@@ -8,15 +8,16 @@ namespace dokuwiki\Menu\Item;
  * Scroll back to the top. Uses a hash as $id which is handled special in getLink().
  * Not shown in mobile context
  */
-class Top extends AbstractItem {
-
+class Top extends AbstractItem
+{
     /** @inheritdoc */
-    public function __construct() {
+    public function __construct()
+    {
         parent::__construct();
 
         $this->svg = DOKU_INC . 'lib/images/menu/10-top_arrow-up.svg';
         $this->accesskey = 't';
-        $this->params = array('do' => '');
+        $this->params = ['do' => ''];
         $this->id = '#dokuwiki__top';
         $this->context = self::CTX_DESKTOP;
     }
@@ -26,11 +27,11 @@ class Top extends AbstractItem {
      *
      * Uses html_topbtn()
      *
-     * @todo this does currently not support the SVG icon
      * @return string
+     * @todo this does currently not support the SVG icon
      */
-    public function asHtmlButton() {
+    public function asHtmlButton()
+    {
         return html_topbtn();
     }
-
 }
