@@ -6,8 +6,7 @@ use dokuwiki\Parsing\Lexer\Lexer;
 
 class Entity extends AbstractMode
 {
-
-    protected $entities = array();
+    protected $entities = [];
     protected $pattern = '';
 
     /**
@@ -27,7 +26,7 @@ class Entity extends AbstractMode
 
         $sep = '';
         foreach ($this->entities as $entity) {
-            $this->pattern .= $sep. Lexer::escape($entity);
+            $this->pattern .= $sep . Lexer::escape($entity);
             $sep = '|';
         }
     }
