@@ -1,5 +1,6 @@
 <?php
 // phpcs:ignoreFile
+use dokuwiki\Cache\Cache as NewCache;
 use dokuwiki\Cache\CacheParser;
 use dokuwiki\Cache\CacheInstructions;
 use dokuwiki\Cache\CacheRenderer;
@@ -8,11 +9,11 @@ use dokuwiki\Debug\DebugHelper;
 /**
  * @deprecated since 2019-02-02 use \dokuwiki\Cache\Cache instead!
  */
-class cache extends \dokuwiki\Cache\Cache
+class cache extends NewCache
 {
     public function __construct($key, $ext)
     {
-        DebugHelper::dbgDeprecatedFunction(dokuwiki\Cache\Cache::class);
+        DebugHelper::dbgDeprecatedFunction(NewCache::class);
         parent::__construct($key, $ext);
     }
 }
@@ -20,7 +21,7 @@ class cache extends \dokuwiki\Cache\Cache
 /**
  * @deprecated since 2019-02-02 use \dokuwiki\Cache\CacheParser instead!
  */
-class cache_parser extends \dokuwiki\Cache\CacheParser
+class cache_parser extends CacheParser
 {
 
     public function __construct($id, $file, $mode)
@@ -34,7 +35,7 @@ class cache_parser extends \dokuwiki\Cache\CacheParser
 /**
  * @deprecated since 2019-02-02 use \dokuwiki\Cache\CacheRenderer instead!
  */
-class cache_renderer extends \dokuwiki\Cache\CacheRenderer
+class cache_renderer extends CacheRenderer
 {
 
     public function __construct($id, $file, $mode)
@@ -47,7 +48,7 @@ class cache_renderer extends \dokuwiki\Cache\CacheRenderer
 /**
  * @deprecated since 2019-02-02 use \dokuwiki\Cache\CacheInstructions instead!
  */
-class cache_instructions extends \dokuwiki\Cache\CacheInstructions
+class cache_instructions extends CacheInstructions
 {
     public function __construct($id, $file)
     {
