@@ -1,4 +1,5 @@
 <?php
+
 /**
  * DokuWiki fulltextsearch functions using the index
  *
@@ -6,6 +7,8 @@
  * @author     Andreas Gohr <andi@splitbrain.org>
  */
 
+use dokuwiki\Utf8\Asian;
+use dokuwiki\Search\Indexer;
 use dokuwiki\Extension\Event;
 use dokuwiki\Utf8\Clean;
 use dokuwiki\Utf8\PhpString;
@@ -14,7 +17,7 @@ use dokuwiki\Utf8\Sort;
 /**
  * create snippets for the first few results only
  */
-if(!defined('FT_SNIPPET_NUMBER')) define('FT_SNIPPET_NUMBER',15);
+if (!defined('FT_SNIPPET_NUMBER')) define('FT_SNIPPET_NUMBER', 15);
 
 /**
  * The fulltext search
@@ -31,7 +34,8 @@ if(!defined('FT_SNIPPET_NUMBER')) define('FT_SNIPPET_NUMBER',15);
  *
  * @return array
  */
-function ft_pageSearch($query,&$highlight, $sort = null, $after = null, $before = null){
+function ft_pageSearch($query, &$highlight, $sort = null, $after = null, $before = null)
+{
 
     if ($sort === null) {
         $sort = 'hits';
@@ -56,33 +60,34 @@ function ft_pageSearch($query,&$highlight, $sort = null, $after = null, $before
  * @param array $data event data
  * @return array matching documents
  */
-function _ft_pageSearch(&$data) {
+function _ft_pageSearch(&$data)
+{
     $Indexer = idx_get_indexer();
 
     // parse the given query
     $q = ft_queryParser($Indexer, $data['query']);
     $data['highlight'] = $q['highlight'];
 
-    if (empty($q['parsed_ary'])) return array();
+    if (empty($q['parsed_ary'])) return [];
 
     // lookup all words found in the query
     $lookup = $Indexer->lookup($q['words']);
 
     // get all pages in this dokuwiki site (!: includes nonexistent pages)
-    $pages_all = array();
+    $pages_all = [];
     foreach ($Indexer->getPages() as $id) {
         $pages_all[$id] = 0; // base: 0 hit
     }
 
     // process the query
-    $stack = array();
+    $stack = [];
     foreach ($q['parsed_ary'] as $token) {
         switch (substr($token, 0, 3)) {
             case 'W+:':
             case 'W-:':
             case 'W_:': // word
                 $word    = substr($token, 3);
-                if(isset($lookup[$word])) {
+                if (isset($lookup[$word])) {
                     $stack[] = (array)$lookup[$word];
                 }
                 break;
@@ -93,14 +98,14 @@ function _ft_pageSearch(&$data) {
                 // the end($stack) always points the pages that contain
                 // all words in this phrase
                 $pages  = end($stack);
-                $pages_matched = array();
-                foreach(array_keys($pages) as $id){
-                    $evdata = array(
+                $pages_matched = [];
+                foreach (array_keys($pages) as $id) {
+                    $evdata = [
                         'id' => $id,
                         'phrase' => $phrase,
                         'text' => rawWiki($id)
-                    );
-                    $evt = new Event('FULLTEXT_PHRASE_MATCH',$evdata);
+                    ];
+                    $evt = new Event('FULLTEXT_PHRASE_MATCH', $evdata);
                     if ($evt->advise_before() && $evt->result !== true) {
                         $text = PhpString::strtolower($evdata['text']);
                         if (strpos($text, $phrase) !== false) {
@@ -117,7 +122,7 @@ function _ft_pageSearch(&$data) {
             case 'N+:':
             case 'N-:': // namespace
                 $ns = cleanID(substr($token, 3)) . ':';
-                $pages_matched = array();
+                $pages_matched = [];
                 foreach (array_keys($pages_all) as $id) {
                     if (strpos($id, $ns) === 0) {
                         $pages_matched[$id] = 0; // namespace: always 0 hit
@@ -126,22 +131,28 @@ function _ft_pageSearch(&$data) {
                 $stack[] = $pages_matched;
                 break;
             case 'AND': // and operation
-                list($pages1, $pages2) = array_splice($stack, -2);
-                $stack[] = ft_resultCombine(array($pages1, $pages2));
+                $pages = array_splice($stack, -2);
+                if ($pages === []) {
+                    break;
+                }
+                $stack[] = ft_resultCombine($pages);
                 break;
             case 'OR':  // or operation
-                list($pages1, $pages2) = array_splice($stack, -2);
-                $stack[] = ft_resultUnite(array($pages1, $pages2));
+                $pages = array_splice($stack, -2);
+                if ($pages === []) {
+                    break;
+                }
+                $stack[] = ft_resultUnite($pages);
                 break;
             case 'NOT': // not operation (unary)
                 $pages   = array_pop($stack);
-                $stack[] = ft_resultComplement(array($pages_all, $pages));
+                $stack[] = ft_resultComplement([$pages_all, $pages]);
                 break;
         }
     }
     $docs = array_pop($stack);
 
-    if (empty($docs)) return array();
+    if (empty($docs)) return [];
 
     // check: settings, acls, existence
     foreach (array_keys($docs) as $id) {
@@ -172,16 +183,19 @@ function _ft_pageSearch(&$data) {
  * @param bool   $ignore_perms Ignore the fact that pages are hidden or read-protected
  * @return array The pages that contain links to the given page
  */
-function ft_backlinks($id, $ignore_perms = false){
+function ft_backlinks($id, $ignore_perms = false)
+{
     $result = idx_get_indexer()->lookupKey('relation_references', $id);
 
-    if(!count($result)) return $result;
+    if ($result === []) return $result;
 
     // check ACL permissions
-    foreach(array_keys($result) as $idx){
-        if(($ignore_perms !== true && (
+    foreach (array_keys($result) as $idx) {
+        if (
+            (!$ignore_perms && (
                 isHiddenPage($result[$idx]) || auth_quickaclcheck($result[$idx]) < AUTH_READ
-            )) || !page_exists($result[$idx], '', false)){
+            )) || !page_exists($result[$idx], '', false)
+        ) {
             unset($result[$idx]);
         }
     }
@@ -203,16 +217,19 @@ function ft_backlinks($id, $ignore_perms = false){
  * @param bool   $ignore_perms Ignore hidden pages and acls (optional, default: false)
  * @return array A list of pages that use the given media file
  */
-function ft_mediause($id, $ignore_perms = false){
+function ft_mediause($id, $ignore_perms = false)
+{
     $result = idx_get_indexer()->lookupKey('relation_media', $id);
 
-    if(!count($result)) return $result;
+    if ($result === []) return $result;
 
     // check ACL permissions
-    foreach(array_keys($result) as $idx){
-        if(($ignore_perms !== true && (
+    foreach (array_keys($result) as $idx) {
+        if (
+            (!$ignore_perms && (
                     isHiddenPage($result[$idx]) || auth_quickaclcheck($result[$idx]) < AUTH_READ
-                )) || !page_exists($result[$idx], '', false)){
+                )) || !page_exists($result[$idx], '', false)
+        ) {
             unset($result[$idx]);
         }
     }
@@ -243,7 +260,8 @@ function ft_mediause($id, $ignore_perms = false){
  *
  * @return string[]
  */
-function ft_pageLookup($id, $in_ns=false, $in_title=false, $after = null, $before = null){
+function ft_pageLookup($id, $in_ns = false, $in_title = false, $after = null, $before = null)
+{
     $data = [
         'id' => $id,
         'in_ns' => $in_ns,
@@ -261,7 +279,8 @@ function ft_pageLookup($id, $in_ns=false, $in_title=false, $after = null, $befor
  * @param array &$data event data
  * @return string[]
  */
-function _ft_pageLookup(&$data){
+function _ft_pageLookup(&$data)
+{
     // split out original parameters
     $id = $data['id'];
     $Indexer = idx_get_indexer();
@@ -282,7 +301,7 @@ function _ft_pageLookup(&$data){
     $Indexer = idx_get_indexer();
     $page_idx = $Indexer->getPages();
 
-    $pages = array();
+    $pages = [];
     if ($id !== '' && $cleaned !== '') {
         foreach ($page_idx as $p_id) {
             if ((strpos($in_ns ? $p_id : noNSorNS($p_id), $cleaned) !== false)) {
@@ -316,16 +335,18 @@ function _ft_pageLookup(&$data){
     // discard hidden pages
     // discard nonexistent pages
     // check ACL permissions
-    foreach(array_keys($pages) as $idx){
-        if(!isVisiblePage($idx) || !page_exists($idx) ||
-           auth_quickaclcheck($idx) < AUTH_READ) {
+    foreach (array_keys($pages) as $idx) {
+        if (
+            !isVisiblePage($idx) || !page_exists($idx) ||
+            auth_quickaclcheck($idx) < AUTH_READ
+        ) {
             unset($pages[$idx]);
         }
     }
 
     $pages = _ft_filterResultsByTime($pages, $data['after'], $data['before']);
 
-    uksort($pages,'ft_pagesorter');
+    uksort($pages, 'ft_pagesorter');
     return $pages;
 }
 
@@ -337,12 +358,13 @@ function _ft_pageLookup(&$data){
  *
  * @return array
  */
-function _ft_filterResultsByTime(array $results, $after, $before) {
+function _ft_filterResultsByTime(array $results, $after, $before)
+{
     if ($after || $before) {
         $after = is_int($after) ? $after : strtotime($after);
         $before = is_int($before) ? $before : strtotime($before);
 
-        foreach ($results as $id => $value) {
+        foreach (array_keys($results) as $id) {
             $mTime = filemtime(wikiFN($id));
             if ($after && $after > $mTime) {
                 unset($results[$id]);
@@ -366,7 +388,8 @@ function _ft_filterResultsByTime(array $results, $after, $before) {
  * @param string $title  title from index
  * @return bool
  */
-function _ft_pageLookupTitleCompare($search, $title) {
+function _ft_pageLookupTitleCompare($search, $title)
+{
     if (Clean::isASCII($search)) {
         $pos = stripos($title, $search);
     } else {
@@ -388,15 +411,16 @@ function _ft_pageLookupTitleCompare($search, $title) {
  * @param string $b
  * @return int Returns < 0 if $a is less than $b; > 0 if $a is greater than $b, and 0 if they are equal.
  */
-function ft_pagesorter($a, $b){
-    $ac = count(explode(':',$a));
-    $bc = count(explode(':',$b));
-    if($ac < $bc){
+function ft_pagesorter($a, $b)
+{
+    $ac = count(explode(':', $a));
+    $bc = count(explode(':', $b));
+    if ($ac < $bc) {
         return -1;
-    }elseif($ac > $bc){
+    } elseif ($ac > $bc) {
         return 1;
     }
-    return Sort::strcmp($a,$b);
+    return Sort::strcmp($a, $b);
 }
 
 /**
@@ -407,7 +431,8 @@ function ft_pagesorter($a, $b){
  *
  * @return int Returns < 0 if $a is newer than $b, > 0 if $b is newer than $a and 0 if they are of the same age
  */
-function ft_pagemtimesorter($a, $b) {
+function ft_pagemtimesorter($a, $b)
+{
     $mtimeA = filemtime(wikiFN($a));
     $mtimeB = filemtime(wikiFN($b));
     return $mtimeB - $mtimeA;
@@ -423,26 +448,30 @@ function ft_pagemtimesorter($a, $b) {
  * @param array $highlight
  * @return mixed
  */
-function ft_snippet($id,$highlight){
+function ft_snippet($id, $highlight)
+{
     $text = rawWiki($id);
-    $text = str_replace("\xC2\xAD",'',$text); // remove soft-hyphens
-    $evdata = array(
-            'id'        => $id,
-            'text'      => &$text,
-            'highlight' => &$highlight,
-            'snippet'   => '',
-            );
+    $text = str_replace("\xC2\xAD", '', $text);
+     // remove soft-hyphens
+    $evdata = [
+        'id'        => $id,
+        'text'      => &$text,
+        'highlight' => &$highlight,
+        'snippet'   => ''
+    ];
 
-    $evt = new Event('FULLTEXT_SNIPPET_CREATE',$evdata);
+    $evt = new Event('FULLTEXT_SNIPPET_CREATE', $evdata);
     if ($evt->advise_before()) {
-        $match = array();
-        $snippets = array();
-        $utf8_offset = $offset = $end = 0;
+        $match = [];
+        $snippets = [];
+        $utf8_offset = 0;
+        $offset = 0;
+        $end = 0;
         $len = PhpString::strlen($text);
 
         // build a regexp from the phrases to highlight
         $re1 = '(' .
-            join(
+            implode(
                 '|',
                 array_map(
                     'ft_snippet_re_preprocess',
@@ -456,38 +485,39 @@ function ft_snippet($id,$highlight){
         $re2 = "$re1.{0,75}(?!\\1)$re1";
         $re3 = "$re1.{0,45}(?!\\1)$re1.{0,45}(?!\\1)(?!\\2)$re1";
 
-        for ($cnt=4; $cnt--;) {
+        for ($cnt = 4; $cnt--;) {
             if (0) {
-            } else if (preg_match('/'.$re3.'/iu',$text,$match,PREG_OFFSET_CAPTURE,$offset)) {
-            } else if (preg_match('/'.$re2.'/iu',$text,$match,PREG_OFFSET_CAPTURE,$offset)) {
-            } else if (preg_match('/'.$re1.'/iu',$text,$match,PREG_OFFSET_CAPTURE,$offset)) {
+            } elseif (preg_match('/' . $re3 . '/iu', $text, $match, PREG_OFFSET_CAPTURE, $offset)) {
+            } elseif (preg_match('/' . $re2 . '/iu', $text, $match, PREG_OFFSET_CAPTURE, $offset)) {
+            } elseif (preg_match('/' . $re1 . '/iu', $text, $match, PREG_OFFSET_CAPTURE, $offset)) {
             } else {
                 break;
             }
 
-            list($str,$idx) = $match[0];
+            [$str, $idx] = $match[0];
 
             // convert $idx (a byte offset) into a utf8 character offset
-            $utf8_idx = PhpString::strlen(substr($text,0,$idx));
+            $utf8_idx = PhpString::strlen(substr($text, 0, $idx));
             $utf8_len = PhpString::strlen($str);
 
             // establish context, 100 bytes surrounding the match string
             // first look to see if we can go 100 either side,
             // then drop to 50 adding any excess if the other side can't go to 50,
-            $pre = min($utf8_idx-$utf8_offset,100);
-            $post = min($len-$utf8_idx-$utf8_len,100);
+            $pre = min($utf8_idx - $utf8_offset, 100);
+            $post = min($len - $utf8_idx - $utf8_len, 100);
 
-            if ($pre>50 && $post>50) {
-                $pre = $post = 50;
-            } else if ($pre>50) {
-                $pre = min($pre,100-$post);
-            } else if ($post>50) {
-                $post = min($post, 100-$pre);
-            } else if ($offset == 0) {
+            if ($pre > 50 && $post > 50) {
+                $pre = 50;
+                $post = 50;
+            } elseif ($pre > 50) {
+                $pre = min($pre, 100 - $post);
+            } elseif ($post > 50) {
+                $post = min($post, 100 - $pre);
+            } elseif ($offset == 0) {
                 // both are less than 50, means the context is the whole string
                 // make it so and break out of this loop - there is no need for the
                 // complex snippet calculations
-                $snippets = array($text);
+                $snippets = [$text];
                 break;
             }
 
@@ -498,9 +528,9 @@ function ft_snippet($id,$highlight){
             $end = $utf8_idx + $utf8_len + $post;      // now set it to the end of this context
 
             if ($append) {
-                $snippets[count($snippets)-1] .= PhpString::substr($text,$append,$end-$append);
+                $snippets[count($snippets) - 1] .= PhpString::substr($text, $append, $end - $append);
             } else {
-                $snippets[] = PhpString::substr($text,$start,$end-$start);
+                $snippets[] = PhpString::substr($text, $start, $end - $start);
             }
 
             // set $offset for next match attempt
@@ -509,16 +539,16 @@ function ft_snippet($id,$highlight){
             // this prevents further matching of this snippet but for possible matches of length
             // smaller than match length + context (at least 50 characters) this match is part of the context
             $utf8_offset = $utf8_idx + $utf8_len;
-            $offset = $idx + strlen(PhpString::substr($text,$utf8_idx,$utf8_len));
-            $offset = Clean::correctIdx($text,$offset);
+            $offset = $idx + strlen(PhpString::substr($text, $utf8_idx, $utf8_len));
+            $offset = Clean::correctIdx($text, $offset);
         }
 
         $m = "\1";
-        $snippets = preg_replace('/'.$re1.'/iu',$m.'$1'.$m,$snippets);
+        $snippets = preg_replace('/' . $re1 . '/iu', $m . '$1' . $m, $snippets);
         $snippet = preg_replace(
             '/' . $m . '([^' . $m . ']*?)' . $m . '/iu',
             '<strong class="search_hit">$1</strong>',
-            hsc(join('... ', $snippets))
+            hsc(implode('... ', $snippets))
         );
 
         $evdata['snippet'] = $snippet;
@@ -535,9 +565,10 @@ function ft_snippet($id,$highlight){
  * @param string $term
  * @return string
  */
-function ft_snippet_re_preprocess($term) {
+function ft_snippet_re_preprocess($term)
+{
     // do not process asian terms where word boundaries are not explicit
-    if(\dokuwiki\Utf8\Asian::isAsianWords($term)) return $term;
+    if (Asian::isAsianWords($term)) return $term;
 
     if (UTF8_PROPERTYSUPPORT) {
         // unicode word boundaries
@@ -550,19 +581,19 @@ function ft_snippet_re_preprocess($term) {
         $BR = '\b';
     }
 
-    if(substr($term,0,2) == '\\*'){
-        $term = substr($term,2);
-    }else{
-        $term = $BL.$term;
+    if (str_starts_with($term, '\\*')) {
+        $term = substr($term, 2);
+    } else {
+        $term = $BL . $term;
     }
 
-    if(substr($term,-2,2) == '\\*'){
-        $term = substr($term,0,-2);
-    }else{
-        $term = $term.$BR;
+    if (str_ends_with($term, '\\*')) {
+        $term = substr($term, 0, -2);
+    } else {
+        $term .= $BR;
     }
 
-    if($term == $BL || $term == $BR || $term == $BL.$BR) $term = '';
+    if ($term == $BL || $term == $BR || $term == $BL . $BR) $term = '';
     return $term;
 }
 
@@ -577,13 +608,14 @@ function ft_snippet_re_preprocess($term) {
  * @param array $args An array of page arrays
  * @return array
  */
-function ft_resultCombine($args){
+function ft_resultCombine($args)
+{
     $array_count = count($args);
-    if($array_count == 1){
+    if ($array_count == 1) {
         return $args[0];
     }
 
-    $result = array();
+    $result = [];
     if ($array_count > 1) {
         foreach ($args[0] as $key => $value) {
             $result[$key] = $value;
@@ -609,7 +641,8 @@ function ft_resultCombine($args){
  *
  * @author Kazutaka Miyasaka <kazmiya@gmail.com>
  */
-function ft_resultUnite($args) {
+function ft_resultUnite($args)
+{
     $array_count = count($args);
     if ($array_count === 1) {
         return $args[0];
@@ -634,7 +667,8 @@ function ft_resultUnite($args) {
  *
  * @author Kazutaka Miyasaka <kazmiya@gmail.com>
  */
-function ft_resultComplement($args) {
+function ft_resultComplement($args)
+{
     $array_count = count($args);
     if ($array_count === 1) {
         return $args[0];
@@ -655,11 +689,12 @@ function ft_resultComplement($args) {
  * @author Andreas Gohr <andi@splitbrain.org>
  * @author Kazutaka Miyasaka <kazmiya@gmail.com>
  *
- * @param dokuwiki\Search\Indexer $Indexer
+ * @param Indexer $Indexer
  * @param string                  $query search query
  * @return array of search formulas
  */
-function ft_queryParser($Indexer, $query){
+function ft_queryParser($Indexer, $query)
+{
     /**
      * parse a search query and transform it into intermediate representation
      *
@@ -698,22 +733,26 @@ function ft_queryParser($Indexer, $query){
      */
     $parsed_query = '';
     $parens_level = 0;
-    $terms = preg_split('/(-?".*?")/u', PhpString::strtolower($query),
-        -1, PREG_SPLIT_DELIM_CAPTURE | PREG_SPLIT_NO_EMPTY);
+    $terms = preg_split(
+        '/(-?".*?")/u',
+        PhpString::strtolower($query),
+        -1,
+        PREG_SPLIT_DELIM_CAPTURE | PREG_SPLIT_NO_EMPTY
+    );
 
     foreach ($terms as $term) {
         $parsed = '';
         if (preg_match('/^(-?)"(.+)"$/u', $term, $matches)) {
             // phrase-include and phrase-exclude
             $not = $matches[1] ? 'NOT' : '';
-            $parsed = $not.ft_termParser($Indexer, $matches[2], false, true);
+            $parsed = $not . ft_termParser($Indexer, $matches[2], false, true);
         } else {
             // fix incomplete phrase
             $term = str_replace('"', ' ', $term);
 
             // fix parentheses
-            $term = str_replace(')'  , ' ) ', $term);
-            $term = str_replace('('  , ' ( ', $term);
+            $term = str_replace(')', ' ) ', $term);
+            $term = str_replace('(', ' ( ', $term);
             $term = str_replace('- (', ' -(', $term);
 
             // treat pipe symbols as 'OR' operators
@@ -721,7 +760,7 @@ function ft_queryParser($Indexer, $query){
 
             // treat ideographic spaces (U+3000) as search term separators
             // FIXME: some more separators?
-            $term = preg_replace('/[ \x{3000}]+/u', ' ',  $term);
+            $term = preg_replace('/[ \x{3000}]+/u', ' ', $term);
             $term = trim($term);
             if ($term === '') continue;
 
@@ -747,13 +786,13 @@ function ft_queryParser($Indexer, $query){
                     $parsed .= 'OR';
                 } elseif (preg_match('/^(?:\^|-ns:)(.+)$/u', $token, $matches)) {
                     // namespace-exclude
-                    $parsed .= 'NOT(N+:'.$matches[1].')';
+                    $parsed .= 'NOT(N+:' . $matches[1] . ')';
                 } elseif (preg_match('/^(?:@|ns:)(.+)$/u', $token, $matches)) {
                     // namespace-include
-                    $parsed .= '(N+:'.$matches[1].')';
+                    $parsed .= '(N+:' . $matches[1] . ')';
                 } elseif (preg_match('/^-(.+)$/', $token, $matches)) {
                     // word-exclude
-                    $parsed .= 'NOT('.ft_termParser($Indexer, $matches[1]).')';
+                    $parsed .= 'NOT(' . ft_termParser($Indexer, $matches[1]) . ')';
                 } else {
                     // word-include
                     $parsed .= ft_termParser($Indexer, $token);
@@ -769,15 +808,15 @@ function ft_queryParser($Indexer, $query){
         $parsed_query_old = $parsed_query;
         $parsed_query = preg_replace('/(NOT)?\(\)/u', '', $parsed_query);
     } while ($parsed_query !== $parsed_query_old);
-    $parsed_query = preg_replace('/(NOT|OR)+\)/u', ')'      , $parsed_query);
-    $parsed_query = preg_replace('/(OR)+/u'      , 'OR'     , $parsed_query);
-    $parsed_query = preg_replace('/\(OR/u'       , '('      , $parsed_query);
-    $parsed_query = preg_replace('/^OR|OR$/u'    , ''       , $parsed_query);
-    $parsed_query = preg_replace('/\)(NOT)?\(/u' , ')AND$1(', $parsed_query);
+    $parsed_query = preg_replace('/(NOT|OR)+\)/u', ')', $parsed_query);
+    $parsed_query = preg_replace('/(OR)+/u', 'OR', $parsed_query);
+    $parsed_query = preg_replace('/\(OR/u', '(', $parsed_query);
+    $parsed_query = preg_replace('/^OR|OR$/u', '', $parsed_query);
+    $parsed_query = preg_replace('/\)(NOT)?\(/u', ')AND$1(', $parsed_query);
 
     // adjustment: make highlightings right
     $parens_level     = 0;
-    $notgrp_levels    = array();
+    $notgrp_levels    = [];
     $parsed_query_new = '';
     $tokens = preg_split('/(NOT\(|[()])/u', $parsed_query, -1, PREG_SPLIT_DELIM_CAPTURE | PREG_SPLIT_NO_EMPTY);
     foreach ($tokens as $token) {
@@ -802,9 +841,9 @@ function ft_queryParser($Indexer, $query){
      * see: http://en.wikipedia.org/wiki/Reverse_Polish_notation
      * see: http://en.wikipedia.org/wiki/Shunting-yard_algorithm
      */
-    $parsed_ary     = array();
-    $ope_stack      = array();
-    $ope_precedence = array(')' => 1, 'OR' => 2, 'AND' => 3, 'NOT' => 4, '(' => 5);
+    $parsed_ary     = [];
+    $ope_stack      = [];
+    $ope_precedence = [')' => 1, 'OR' => 2, 'AND' => 3, 'NOT' => 4, '(' => 5];
     $ope_regex      = '/([()]|OR|AND|NOT)/u';
 
     $tokens = preg_split($ope_regex, $parsed_query, -1, PREG_SPLIT_DELIM_CAPTURE | PREG_SPLIT_NO_EMPTY);
@@ -823,11 +862,11 @@ function ft_queryParser($Indexer, $query){
             }
         } else {
             // operand
-            $token_decoded = str_replace(array('OP', 'CP'), array('(', ')'), $token);
+            $token_decoded = str_replace(['OP', 'CP'], ['(', ')'], $token);
             $parsed_ary[] = $token_decoded;
         }
     }
-    $parsed_ary = array_values(array_merge($parsed_ary, array_reverse($ope_stack)));
+    $parsed_ary = array_values([...$parsed_ary, ...array_reverse($ope_stack)]);
 
     // cleanup: each double "NOT" in RPN array actually does nothing
     $parsed_ary_count = count($parsed_ary);
@@ -839,7 +878,7 @@ function ft_queryParser($Indexer, $query){
     $parsed_ary = array_values($parsed_ary);
 
     // build return value
-    $q = array();
+    $q = [];
     $q['query']      = $query;
     $q['parsed_str'] = $parsed_query;
     $q['parsed_ary'] = $parsed_ary;
@@ -851,33 +890,33 @@ function ft_queryParser($Indexer, $query){
         switch (substr($token, 0, 3)) {
             case 'N+:':
                      $q['ns'][]        = $body; // for backward compatibility
-                     break;
+                break;
             case 'N-:':
                      $q['notns'][]     = $body; // for backward compatibility
-                     break;
+                break;
             case 'W_:':
                      $q['words'][]     = $body;
-                     break;
+                break;
             case 'W-:':
                      $q['words'][]     = $body;
                      $q['not'][]       = $body; // for backward compatibility
-                     break;
+                break;
             case 'W+:':
                      $q['words'][]     = $body;
                      $q['highlight'][] = $body;
                      $q['and'][]       = $body; // for backward compatibility
-                     break;
+                break;
             case 'P-:':
                      $q['phrases'][]   = $body;
-                     break;
+                break;
             case 'P+:':
                      $q['phrases'][]   = $body;
                      $q['highlight'][] = $body;
-                     break;
+                break;
         }
     }
-    foreach (array('words', 'phrases', 'highlight', 'ns', 'notns', 'and', 'not') as $key) {
-        $q[$key] = empty($q[$key]) ? array() : array_values(array_unique($q[$key]));
+    foreach (['words', 'phrases', 'highlight', 'ns', 'notns', 'and', 'not'] as $key) {
+        $q[$key] = empty($q[$key]) ? [] : array_values(array_unique($q[$key]));
     }
 
     return $q;
@@ -890,35 +929,36 @@ function ft_queryParser($Indexer, $query){
  *
  * @author Kazutaka Miyasaka <kazmiya@gmail.com>
  *
- * @param dokuwiki\Search\Indexer $Indexer
+ * @param Indexer $Indexer
  * @param string                  $term
  * @param bool                    $consider_asian
  * @param bool                    $phrase_mode
  * @return string
  */
-function ft_termParser($Indexer, $term, $consider_asian = true, $phrase_mode = false) {
+function ft_termParser($Indexer, $term, $consider_asian = true, $phrase_mode = false)
+{
     $parsed = '';
     if ($consider_asian) {
         // successive asian characters need to be searched as a phrase
-        $words = \dokuwiki\Utf8\Asian::splitAsianWords($term);
+        $words = Asian::splitAsianWords($term);
         foreach ($words as $word) {
-            $phrase_mode = $phrase_mode ? true : \dokuwiki\Utf8\Asian::isAsianWords($word);
+            $phrase_mode = $phrase_mode ? true : Asian::isAsianWords($word);
             $parsed .= ft_termParser($Indexer, $word, false, $phrase_mode);
         }
     } else {
-        $term_noparen = str_replace(array('(', ')'), ' ', $term);
+        $term_noparen = str_replace(['(', ')'], ' ', $term);
         $words = $Indexer->tokenizer($term_noparen, true);
 
         // W_: no need to highlight
         if (empty($words)) {
             $parsed = '()'; // important: do not remove
         } elseif ($words[0] === $term) {
-            $parsed = '(W+:'.$words[0].')';
+            $parsed = '(W+:' . $words[0] . ')';
         } elseif ($phrase_mode) {
-            $term_encoded = str_replace(array('(', ')'), array('OP', 'CP'), $term);
-            $parsed = '((W_:'.implode(')(W_:', $words).')(P+:'.$term_encoded.'))';
+            $term_encoded = str_replace(['(', ')'], ['OP', 'CP'], $term);
+            $parsed = '((W_:' . implode(')(W_:', $words) . ')(P+:' . $term_encoded . '))';
         } else {
-            $parsed = '((W+:'.implode(')(W+:', $words).'))';
+            $parsed = '((W+:' . implode(')(W+:', $words) . '))';
         }
     }
     return $parsed;
@@ -935,21 +975,22 @@ function ft_termParser($Indexer, $term, $consider_asian = true, $phrase_mode = f
  *
  * @return string
  */
-function ft_queryUnparser_simple(array $and, array $not, array $phrases, array $ns, array $notns) {
+function ft_queryUnparser_simple(array $and, array $not, array $phrases, array $ns, array $notns)
+{
     $query = implode(' ', $and);
-    if (!empty($not)) {
+    if ($not !== []) {
         $query .= ' -' . implode(' -', $not);
     }
 
-    if (!empty($phrases)) {
+    if ($phrases !== []) {
         $query .= ' "' . implode('" "', $phrases) . '"';
     }
 
-    if (!empty($ns)) {
+    if ($ns !== []) {
         $query .= ' @' . implode(' @', $ns);
     }
 
-    if (!empty($notns)) {
+    if ($notns !== []) {
         $query .= ' ^' . implode(' ^', $notns);
     }
 
