@@ -3,6 +3,7 @@
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  *
+ * @author talal <ksa76@hotmail.com>
  * @author Khalid <khalid.aljahil@gmail.com>
  * @author Mostafa Hussein <mostafa@gmail.com>
  * @author Yaman Hokan <always.smile.yh@hotmail.com>
@@ -70,6 +71,8 @@ $lang['badpassconfirm']        = 'عذراً,كلمة السر غير صحيحة
 $lang['minoredit']             = 'تعديلات طفيفة';
 $lang['draftdate']             = 'حفظ المسودات آليا مفعّل';
 $lang['nosecedit']             = 'غُيرت الصفحة في هذه الأثناء، معلومات الجزء اصبحت قديمة. حُمُلت كل الصفحة بدلا.';
+$lang['searchcreatepage']      = 'إذا لم تجد ما كنت تبحث عنه، فيمكنك إنشاء الصفحة %s أو تحريرها، والتي سميت باسم استعلامك.	';
+$lang['search_fullresults']    = 'نتائج النص الكامل';
 $lang['js']['search_toggle_tools'] = 'إظهار / إخفاء أدوات البحث';
 $lang['js']['willexpire']      = 'سينتهي قفل تحرير هذه الصفحه خلال دقيقة.\nلتجنب التعارض استخدم زر المعاينة لتصفير مؤقت القفل.';
 $lang['js']['notsavedyet']     = 'التعديلات غير المحفوظة ستفقد.';
@@ -105,6 +108,7 @@ $lang['js']['del_confirm']     = 'هل حقاً تريد حذف البنود ا
 $lang['js']['restore_confirm'] = 'أمتأكد من استرجاع هذه النسخة؟';
 $lang['js']['media_diff']      = 'عرض الفروق:';
 $lang['js']['media_diff_both'] = 'جنبا إلى جنب';
+$lang['js']['media_diff_opacity'] = 'تألق من خلال';
 $lang['js']['media_diff_portions'] = 'اسحب';
 $lang['js']['media_select']    = 'اختر ملفا...';
 $lang['js']['media_upload_btn'] = 'ارفع';
@@ -112,11 +116,13 @@ $lang['js']['media_done_btn']  = 'تم';
 $lang['js']['media_drop']      = 'اسقط الملف هنا لرفعه';
 $lang['js']['media_cancel']    = 'أزل';
 $lang['js']['media_overwrt']   = 'أكتب فوق الملفات الموجودة';
+$lang['js']['data_insecure']   = 'تحذير: يبدو أن دليل البيانات الخاص بك غير مؤمن بشكل صحيح. يرجى القراءة عن <a href="https://www.dokuwiki.org/security#web_access_security">Web Access Security في DokuWiki</a>.	';
 $lang['search_exact_match']    = 'تطابق تام';
 $lang['search_starts_with']    = 'يبدأ بالتالي';
 $lang['search_ends_with']      = 'ينتهي بالتالي';
 $lang['search_contains']       = 'يحتوي';
 $lang['search_custom_match']   = 'مخصص';
+$lang['search_any_ns']         = 'أي مساحة اسم';
 $lang['search_any_time']       = 'أي وقت';
 $lang['search_past_7_days']    = 'الأسبوع الماضي';
 $lang['search_past_month']     = 'الشهر الماضي';
@@ -160,6 +166,7 @@ $lang['txt_upload']            = 'اختر ملفاً للرفع:';
 $lang['txt_filename']          = 'رفع كـ (اختياري):';
 $lang['txt_overwrt']           = 'اكتب على ملف موجود';
 $lang['maxuploadsize']         = 'الحجم الاقصى %s للملف';
+$lang['allowedmime']           = 'قائمة امتدادات الملفات المسموح بها';
 $lang['lockedby']              = 'مقفلة حاليا لـ:';
 $lang['lockexpire']            = 'ينتهي القفل في:';
 $lang['rssfailed']             = 'خطأ ما حدث أثناء جلب ملف التغذية:';
@@ -213,7 +220,8 @@ $lang['created']               = 'اُنشئت';
 $lang['restored']              = 'استعيدت نسخة قديمة (%s)';
 $lang['external_edit']         = 'تحرير خارجي';
 $lang['summary']               = 'ملخص التحرير';
-$lang['noflash']               = 'تحتاج إلى<a href="http://www.adobe.com/products/flashplayer/">ملحق فلاش أدوبي</a> لعرض هذا المحتوى.';
+$lang['unknowndate']           = 'تاريخ غير معروف';
+$lang['noflash']               = 'تحتاج إلى<a href="http://get.adobe.com/flashplayer">ملحق فلاش أدوبي</a> لعرض هذا المحتوى.';
 $lang['download']              = 'نزل Snippet';
 $lang['tools']                 = 'أدوات';
 $lang['user_tools']            = 'أدوات المستخدم';
@@ -294,16 +302,19 @@ $lang['i_enableacl']           = 'تفعيل ACL - مفضل';
 $lang['i_superuser']           = 'مشرف';
 $lang['i_problems']            = 'وجد برنامج التنصيب المشاكل التالية، لا يمكنك المتابعة قبل حلها.';
 $lang['i_modified']            = 'لأسباب أمنية هذا البرنامج سيعمل فقط مع تنصيب دوكو ويكي جديد و غير معدّل.
-يجب أن تعيد فك ضغط الملفات مرة أخرى من المكتبة المضغوطة، أو راجع <a href="http://dokuwiki.org/install"> تعليمات تنصيب دوكو ويكي </a> ';
+يجب أن تعيد فك ضغط الملفات مرة أخرى من المكتبة المضغوطة، أو راجع <a href="https://www.dokuwiki.org/install"> تعليمات تنصيب دوكو ويكي </a> ';
 $lang['i_funcna']              = 'دالة PHP التالية غير متوفرة.
 <code>%s</code>
 قد يكون مزود خدمة الاستفادة قد حجبها لسبب ما.';
+$lang['i_disabled']            = 'تم تعطيله من قبل مزود الخدمة الخاص بك.';
+$lang['i_funcnmail']           = '<b>ملاحظة:</b> وظيفة بريد PHP غير متوفرة. %s إذا ظل غير متوفر ، فيمكنك تثبيت المكون الإضافي <a href="https://www.dokuwiki.org/plugin:smtp">smtp</a>.	';
 $lang['i_phpver']              = 'نسخة PHP التي لديك هي
 <code>%s</code>
 وهي أقل من النسخة المطلوبة
 <code>%s</code>
 عليك تحديث نسخة PHP';
 $lang['i_mbfuncoverload']      = 'يجب ايقاف تشغيل mbstring.func_overload في ملف php.ini لتشغيل دوكوويكي.';
+$lang['i_urandom']             = 'لا يمكن ل DokuWiki إنشاء أرقام آمنة مشفرة لملفات تعريف الارتباط. قد ترغب في التحقق من إعدادات open_basedir الخاصة بك في php.ini للوصول المناسب إلى <code>/dev/urandom</code>.';
 $lang['i_permfail']            = 'إن <code>%s</code> غير قابل للكتابة بواسطة دوكو ويكي، عليك تعديل إعدادات الصلاحيات لهذا المجلد!';
 $lang['i_confexists']          = 'إن <code>%s</code> موجود أصلاً';
 $lang['i_writeerr']            = 'لا يمكن إنشاء <code>%s</code>، عليك التأكد من صلاحيات الملف أو المجلد وإنشاء الملف يدوياً.';
@@ -355,9 +366,16 @@ $lang['media_perm_read']       = 'عفوا، لست مخولا بقراءة ال
 $lang['media_perm_upload']     = 'عفوا، لست مخولا برفع الملفات.';
 $lang['media_update']          = 'ارفع إصدارا أحدث';
 $lang['media_restore']         = 'استرجع هذه النسخة';
+$lang['media_acl_warning']     = 'قد لا تكون هذه القائمة كاملة بسبب قيود ACL والصفحات المخفية.';
+$lang['email_fail']            = 'بريد PHP () مفقود أو معطل. لم يتم إرسال البريد الإلكتروني التالي: 	';
 $lang['currentns']             = 'مساحة الاسم الحالية';
 $lang['searchresult']          = 'نتيجة البحث';
 $lang['plainhtml']             = 'نص HTML غير منسق';
 $lang['wikimarkup']            = 'علامات الوكي';
+$lang['page_nonexist_rev']     = 'الصفحة غير موجودة في %s. تم إنشاؤه لاحقا في  <a href="%s">%s</a>.';
+$lang['unable_to_parse_date']  = 'غير قادر على التحليل عند المعلمة "%s".';
 $lang['email_signature_text']  = 'أنشئت هذه الرسالة من دوكو ويكي في
 @DOKUWIKIURL@';
+$lang['log_file_too_large']    = 'ملف السجل كبير جدا. تم تخطي الأسطر السابقة!';
+$lang['log_file_failed_to_open'] = 'فشل فتح ملف السجل.';
+$lang['log_file_failed_to_read'] = 'حدث خطأ أثناء قراءة السجل.';
