@@ -1,9 +1,10 @@
 <?php
+
 /**
- * Azerbaijani language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ *
  * @author Pasha L. Topchiyev <pasha@itopchiyev.com>
+ * @author Elchin <quliyev_elchin1989@mail.ru>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -35,9 +36,7 @@ $lang['btn_update']            = 'Yenilə';
 $lang['btn_delete']            = 'Sil';
 $lang['btn_back']              = 'Geri';
 $lang['btn_backlink']          = 'Bura olan link-lər';
-$lang['btn_backtomedia']       = 'media-fayl seçiminə qayıt';
 $lang['btn_subscribe']         = 'Abunə ol (bütün dəyişiklər)';
-$lang['btn_unsubscribe']       = 'Abunəlikdən çıx (bütün dəyişiklər)';
 $lang['btn_profile']           = 'Profil';
 $lang['btn_reset']             = 'Boşalt';
 $lang['btn_draft']             = 'Qaralamada düzəliş etmək';
@@ -45,7 +44,8 @@ $lang['btn_recover']           = 'Qaralamanı qaytar';
 $lang['btn_draftdel']          = 'Qaralamanı sil';
 $lang['btn_revert']            = 'Qaytar';
 $lang['btn_register']          = 'Qeydiyyatdan keç';
-$lang['loggedinas']            = 'İstifadəcinin adı';
+$lang['btn_img_backto']        = 'Qayıd %s';
+$lang['loggedinas']            = 'İstifadəcinin adı:';
 $lang['user']                  = 'istifadəci adı';
 $lang['pass']                  = 'Şifrə';
 $lang['newpass']               = 'Yeni şifrə';
@@ -72,6 +72,9 @@ $lang['profna']                = 'Bu wiki profilin dəyişdirilməsini dəstəkl
 $lang['profnochange']          = 'Dəyişiklər edilmədi, profil yenilənmədi.';
 $lang['profnoempty']           = 'istifadəci adı və e-mail ünvanı boş ola bilməz.';
 $lang['profchanged']           = 'İstifadəçi profili uğurla yeniləndi.';
+$lang['profdeleteuser']        = 'Profili sil.';
+$lang['profconfdeletemissing'] = 'Təsdiq xanası seçilməib.';
+$lang['proffail']              = 'İstifadəçi profili yenilənmiyib.';
 $lang['pwdforget']             = 'Şifrəni yaddan çıxartmısız? Buyurun yenisini əldə edin';
 $lang['resendna']              = 'Bu wiki şifrəni yenidən göndərməyi dəstəkləmir.';
 $lang['resendpwdmissing']      = 'Formanın bütün xanəlırini doldurun.';
@@ -83,17 +86,33 @@ $lang['license']               = 'Fərqli şey göstərilmiş hallardan başqa,
 $lang['licenseok']             = 'Qeyd: bu səhifəni düzəliş edərək, Siz elədiyiniz düzəlişi aşağıda göstərilmiş lisenziyanın şərtlərinə uyğun istifadəsinə razılıq verirsiniz:';
 $lang['searchmedia']           = 'Faylın adına görə axtarış:';
 $lang['searchmedia_in']        = '%s-ın içində axtarış';
-$lang['txt_upload']            = 'Serverə yükləmək üçün fayl seçin';
-$lang['txt_filename']          = 'Faylın wiki-də olan adını daxil edin (mütləq deyil)';
+$lang['txt_upload']            = 'Serverə yükləmək üçün fayl seçin:';
+$lang['txt_filename']          = 'Faylın wiki-də olan adını daxil edin (mütləq deyil):';
 $lang['txt_overwrt']           = 'Mövcud olan faylın üstündən yaz';
-$lang['lockedby']              = 'В данный момент заблокирован Bu an blokdadır';
+$lang['lockedby']              = 'В данный момент заблокирован Bu an blokdadır:';
 $lang['lockexpire']            = 'Blok bitir:';
-$lang['js']['willexpire']            = 'Sizin bu səhifədə dəyişik etmək üçün blokunuz bir dəqiqə ərzində bitəcək.\nMünaqişələrdən yayınmaq və blokun taymerini sıfırlamaq üçün, baxış düyməsini sıxın.';
-$lang['notsavedyet']           = 'Yaddaşa yazılmamış dəyişiklər itəcəklər.\nSiz davam etmək istəyirsiz?';
+$lang['js']['willexpire']      = 'Sizin bu səhifədə dəyişik etmək üçün blokunuz bir dəqiqə ərzində bitəcək.\nMünaqişələrdən yayınmaq və blokun taymerini sıfırlamaq üçün, baxış düyməsini sıxın.';
+$lang['js']['notsavedyet']     = 'Yaddaşa verilməmiş məlumatlar itəcək.';
+$lang['js']['searchmedia']     = 'Faylların axtarışı';
+$lang['js']['keepopen']        = 'Seçimdən sonra pəncərəni açıq saxlamaq';
+$lang['js']['hidedetails']     = 'Təfərruatı gizlət';
+$lang['js']['mediadisplay']    = 'Link növü';
+$lang['js']['mediasize']       = 'Şəkil ölçüsü.';
+$lang['js']['mediaclose']      = 'Bağla.';
+$lang['js']['mediadisplayimg'] = 'Şəkili göstər.';
+$lang['js']['mediadisplaylnk'] = 'Ancaq linki göstər.';
+$lang['js']['mediasmall']      = 'Kiçik versiya.';
+$lang['js']['mediamedium']     = 'Orta versiya.';
+$lang['js']['medialarge']      = 'Böyük versiya.';
+$lang['js']['mediaoriginal']   = 'Orjinal versiya.';
+$lang['js']['medialnk']        = 'Məlumat səhifəsinə keçid.';
+$lang['js']['nosmblinks']      = 'Windows-un şəbəkə qovluqlarına link ancaq Internet Explorer-dən işləyir. \nAmma Siz linki köçürə bilərsiniz.';
+$lang['js']['linkwiz']         = 'Linklər köməkçisi';
+$lang['js']['linkto']          = 'Link göstərir:';
+$lang['js']['del_confirm']     = 'Siz əminsiz ki, seçilmişləri silmək istəyirsiniz?';
 $lang['rssfailed']             = 'Aşağıda göstərilmiş xəbər lentini əldə edən zaman xəta baş verdi: ';
 $lang['nothingfound']          = 'Heçnə tapılmadı.';
 $lang['mediaselect']           = 'Mediya-faylın seçilməsi';
-$lang['fileupload']            = 'Mediya-faylın serverə yüklənməsi';
 $lang['uploadsucc']            = 'Yüklənmə uğur ilə başa çatdı';
 $lang['uploadfail']            = 'Yüklənmə zamanı xəta baş veri. Bəlkə giriş haqları ilə problem var?';
 $lang['uploadwrong']           = 'Yuklənməyə qadağa qoyuldu. Belə növlu faylları serverə yükləmək olmaz. ';
@@ -107,13 +126,6 @@ $lang['deletefail']            = '"%s" adlı fayl silinmədi. Faylın giriş haq
 $lang['mediainuse']            = '"%s" adlı fayl silinmədi. Fayl hələ istifadə olunur';
 $lang['namespaces']            = 'Namespace-lər';
 $lang['mediafiles']            = 'Mövcud olan fayllar';
-$lang['js']['searchmedia']     = 'Faylların axtarışı';
-$lang['js']['keepopen']        = 'Seçimdən sonra pəncərəni açıq saxlamaq';
-$lang['js']['hidedetails']     = 'Təfərruatı gizlət';
-$lang['js']['nosmblinks']      = 'Windows-un şəbəkə qovluqlarına link ancaq Internet Explorer-dən işləyir. \nAmma Siz linki köçürə bilərsiniz.';
-$lang['js']['linkwiz']         = 'Linklər köməkçisi';
-$lang['js']['linkto']          = 'Link göstərir:';
-$lang['js']['del_confirm']     = 'Siz əminsiz ki, seçilmişləri silmək istəyirsiniz?';
 $lang['mediausage']            = 'Bu fayla link yaratmaq üçün aşağıdakı sintaksisdən istifadə edin:';
 $lang['mediaview']             = 'Bu faylın ilkinə bax';
 $lang['mediaroot']             = 'kök';
@@ -130,16 +142,16 @@ $lang['yours']                 = 'Sizin versiyanız';
 $lang['diff']                  = 'hazırki versiyadan fərqləri göstər';
 $lang['diff2']                 = 'Versiyaların arasındaki fərqləri göstər  ';
 $lang['line']                  = 'Sətr';
-$lang['breadcrumb']            = 'Siz ziyarət etdiniz';
-$lang['youarehere']            = 'Siz burdasınız';
-$lang['lastmod']               = 'Son dəyişiklər';
+$lang['breadcrumb']            = 'Siz ziyarət etdiniz:';
+$lang['youarehere']            = 'Siz burdasınız:';
+$lang['lastmod']               = 'Son dəyişiklər:';
 $lang['by']                    = ' Kimdən';
 $lang['deleted']               = 'silinib';
 $lang['created']               = 'yaranıb';
 $lang['restored']              = 'köhnə versiya qaytarıldı (%s)';
 $lang['external_edit']         = 'bayırdan dəyişik';
 $lang['summary']               = 'Dəyişiklər xülasəsi';
-$lang['noflash']               = 'Bu məzmuna baxmaq üçün <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> tələb olunur.';
+$lang['noflash']               = 'Bu məzmuna baxmaq üçün <a href="http://get.adobe.com/flashplayer">Adobe Flash Plugin</a> tələb olunur.';
 $lang['download']              = 'Kodu yüklə';
 $lang['mail_newpage']          = 'səhifə əlavə olundu:';
 $lang['mail_changed']          = 'səhifəyə düzəliş edildi:';
@@ -170,27 +182,19 @@ $lang['qb_sig']                = 'İmza at';
 $lang['qb_smileys']            = 'Smayllar';
 $lang['qb_chars']              = 'Xüsusi simvollar';
 $lang['upperns']               = 'Ana namespace-ə keç';
-$lang['admin_register']        = 'İstifadəçi əlavə et';
 $lang['metaedit']              = 'Meta-məlumatlarda düzəliş et';
 $lang['metasaveerr']           = 'Meta-məlumatları yazan zamanı xəta';
 $lang['metasaveok']            = 'Meta-məlumatlar yadda saxlandı';
-$lang['img_backto']            = 'Qayıd';
-$lang['img_title']             = 'Başlıq';
-$lang['img_caption']           = 'İmza';
-$lang['img_date']              = 'Tarix';
-$lang['img_fname']             = 'Faylın adı';
-$lang['img_fsize']             = 'Boy';
-$lang['img_artist']            = 'Şkilin müəllifi';
-$lang['img_copyr']             = 'Müəllif hüquqları';
-$lang['img_format']            = 'Format';
-$lang['img_camera']            = 'Model';
-$lang['img_keywords']          = 'Açar sözlər';
-$lang['subscribe_success']     = '%s adlı istifadəçi %s səhifənin paylanma siyahısına əlavə olundu';
-$lang['subscribe_error']       = '%s adlı istifadəçini %s səhifənin paylanma siyahısına əlavə etmə zamanı səhv baş verdi';
-$lang['subscribe_noaddress']   = 'Sizin profilinizdə e-mail göstərilməyib.Ona görə siz paylnma siyahılarına əlavə edilə bilməzsiniz.';
-$lang['unsubscribe_success']   = '%s adlı istifadəçi %s səhifənin paylanma siyahısından silinmişdir';
-$lang['unsubscribe_error']     = '%s adlı istifadəçini %s səhifənin paylanma siyahısından silən zaman xəta baş verdi.';
-$lang['authmodfailed']         = 'İstifadəçinin autentifikasiyasının konfiqurasiyası səhfdir. Xaiş olunur ki wiki-nin administratoru ilə əlaqə saxlayasınız.';
+$lang['img_title']             = 'Başlıq:';
+$lang['img_caption']           = 'İmza:';
+$lang['img_date']              = 'Tarix:';
+$lang['img_fname']             = 'Faylın adı:';
+$lang['img_fsize']             = 'Boy:';
+$lang['img_artist']            = 'Şkilin müəllifi:';
+$lang['img_copyr']             = 'Müəllif hüquqları:';
+$lang['img_format']            = 'Format:';
+$lang['img_camera']            = 'Model:';
+$lang['img_keywords']          = 'Açar sözlər:';
 $lang['authtempfail']          = 'İstifadəçilərin autentifikasiyası müvəqqəti dayandırılıb. Əgər bu problem uzun müddət davam edir sə, administrator ilə əlaqə saxlayın.';
 $lang['i_chooselang']          = 'Dili seçin/Language';
 $lang['i_installer']           = 'DokuWiki quraşdırılır';
@@ -199,7 +203,7 @@ $lang['i_enableacl']           = 'Haqlar kontrolu siyahısının istifadəsinə
 $lang['i_superuser']           = 'Super-istifadəci';
 $lang['i_problems']            = 'Quraşdırma proqramı aşağıdakı problemlər ilə üzləşdi. Davam etmək üçün onları həll etmək lazımdır. ';
 $lang['i_modified']            = 'Təhlükəsizlik baxımından bu proqram ancaq yeni, dəyişməmiş halda olan DokuWiki üzərində işləyir.
-                         Siz ya yüklənmiş quraşdırma paketini yenidən açmalısınız, ya da <a href="http://dokuwiki.org/install">DokuWiki-nin tam quraşdırma instruksiyasına</a> müraciyət etməlisiniz';
+                         Siz ya yüklənmiş quraşdırma paketini yenidən açmalısınız, ya da <a href="https://www.dokuwiki.org/install">DokuWiki-nin tam quraşdırma instruksiyasına</a> müraciyət etməlisiniz';
 $lang['i_funcna']              = 'PHP-nin <code>%s</code> funksiyası mövcud deyil. Bəlkə, o hansı sa səbəbdən sizin host-unuz tərəfindən blok edilib?';
 $lang['i_phpver']              = 'Sizin PHP-nin versiyası (<code>%s</code>) tələb olunan versiyadan aşagıdır (<code>%s</code>). Quraşdırılmış PHP-nin versiyasını yeniləyin.';
 $lang['i_permfail']            = '<code>%s</code> DokuWiki-yə yazı üçün bağlıdır. Bu qovluğun giriş haqlarını yoxlamaq lazımdır!';
@@ -223,3 +227,5 @@ $lang['days']                  = '%d gün əvvəl';
 $lang['hours']                 = '%d saat əvvəl';
 $lang['minutes']               = '%d dəqiqə əvvəl';
 $lang['seconds']               = '%d saniyə əvvəl';
+$lang['email_signature_text']  = 'DokuWiki aşağıdakı adresdə yerləşir
+@DOKUWIKIURL@';
