@@ -3,6 +3,7 @@
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  *
+ * @author Alinur <alinur@danwin1210.de>
  * @author Salif Mehmed <salif13mehmed@gmail.com>
  * @author Nikolay Vladimirov <nikolay@vladimiroff.com>
  * @author Viktor Usunov <usun0v@mail.bg>
@@ -68,6 +69,7 @@ $lang['badpassconfirm']        = 'За съжаление паролата е г
 $lang['minoredit']             = 'Промените са незначителни';
 $lang['draftdate']             = 'Черновата е автоматично записана на';
 $lang['nosecedit']             = 'Страницата бе междувременно променена, презареждане на страницата поради неактуална информация.';
+$lang['searchcreatepage']      = 'Ако не си намерил, каквото ти търсиш, ти можеш да го създадеш или редактираш страницата %s, кръстена на вашето запитване.';
 $lang['js']['willexpire']      = 'Страницата ще бъде отключена за редактиране след минута.\nЗа предотвратяване на конфликти, ползвайте бутона "Преглед", за рестартиране на брояча за заключване.';
 $lang['js']['notsavedyet']     = 'Незаписаните промени ще бъдат загубени. Желаете ли да продължите?';
 $lang['js']['searchmedia']     = 'Търсене на файлове';
@@ -109,6 +111,7 @@ $lang['js']['media_done_btn']  = 'Готово';
 $lang['js']['media_drop']      = 'Влачете и пуснете файлове тук, за да бъдат качени';
 $lang['js']['media_cancel']    = 'премахване';
 $lang['js']['media_overwrt']   = 'Презапиши съществуващите файлове';
+$lang['search_exact_match']    = 'Точно съвпадение';
 $lang['search_starts_with']    = 'започва с';
 $lang['search_ends_with']      = 'завършва с';
 $lang['search_contains']       = 'съдържа';
@@ -203,7 +206,7 @@ $lang['created']               = 'създадена';
 $lang['restored']              = 'възстановена предишна версия (%s)';
 $lang['external_edit']         = 'външна редакция';
 $lang['summary']               = 'Обобщение';
-$lang['noflash']               = 'Необходим е <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> за изобразяване на съдържанието.';
+$lang['noflash']               = 'Необходим е <a href="http://get.adobe.com/flashplayer">Adobe Flash Plugin</a> за изобразяване на съдържанието.';
 $lang['download']              = 'Изтегляне на фрагмент';
 $lang['tools']                 = 'Инструменти';
 $lang['user_tools']            = 'Инструменти за потребители';
@@ -284,7 +287,7 @@ $lang['i_enableacl']           = 'Ползване на списък за дос
 $lang['i_superuser']           = 'Супер потребител';
 $lang['i_problems']            = 'Открити са проблеми, които възпрепятстват инсталирането. Ще можете да продължите след като отстраните долуизброените проблеми.';
 $lang['i_modified']            = 'Поради мерки за сигурност инсталаторът работи само с нови и непроменени инсталационни файлове.
-								  Трябва да разархивирате отново файловете от сваления архив или да се посъветвате с <a href="http://dokuwiki.org/install">Инструкциите за инсталиране на Dokuwiki</a>.';
+								  Трябва да разархивирате отново файловете от сваления архив или да се посъветвате с <a href="https://www.dokuwiki.org/install">Инструкциите за инсталиране на Dokuwiki</a>.';
 $lang['i_funcna']              = 'PHP функцията <code>%s</code> не е достъпна. Може би е забранена от доставчика на хостинг.';
 $lang['i_phpver']              = 'Инсталираната версия <code>%s</code> на PHP е по-стара от необходимата <code>%s</code>. Актуализирайте PHP инсталацията.';
 $lang['i_mbfuncoverload']      = 'Необходимо е да изключите mbstring.func_overload в php.ini за да може DokuWiki да стартира.';
@@ -338,6 +341,7 @@ $lang['media_perm_read']       = 'За съжаление нямате дост
 $lang['media_perm_upload']     = 'За съжаление нямате достатъчно права, за да можете да качите файла.';
 $lang['media_update']          = 'Качване на нова версия';
 $lang['media_restore']         = 'Възстановяване на тази версия';
+$lang['email_fail']            = 'PHP mail() липсва или деактивиран. Следният имейл не беше изпратен:';
 $lang['currentns']             = 'Текущо именно пространство';
 $lang['searchresult']          = 'Резултати от търсенето';
 $lang['plainhtml']             = 'Обикновен HTML';
