@@ -3,10 +3,10 @@
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  *
+ * @author Name <nam@example.com>
  * @author Foysol <ragebot1125@gmail.com>
  * @author ninetailz <ninetailz1125@gmail.com>
  * @author Khan M. B. Asad <muhammad2017@gmail.com>
- * @author Ninetailz <ninetailz1125@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -20,6 +20,7 @@ $lang['btn_source']            = 'দেখান পাতা উৎস';
 $lang['btn_show']              = 'দেখান পৃষ্ঠা';
 $lang['btn_create']            = 'এই পৃষ্ঠা তৈরি করুন';
 $lang['btn_search']            = 'অনুসন্ধান';
+$lang['btn_save']              = 'সংরক্ষণ';
 $lang['btn_preview']           = 'পূর্বরূপ';
 $lang['btn_top']               = 'উপরে ফিরে যান ';
 $lang['btn_newer']             = '<< আরো সাম্প্রতিক';
@@ -67,42 +68,7 @@ $lang['minoredit']             = 'ক্ষুদ্র পরিবর্তন
 $lang['draftdate']             = 'খসড়া উপর স্বতঃসংরক্ষণ';
 $lang['nosecedit']             = 'পাতা ইতিমধ্যে পরিবর্তিত হয়েছিল, অধ্যায় তথ্যের পরিবর্তে পুরো পাতা লোড তারিখ সীমার বাইরে ছিল.
 ';
-$lang['regmissing']            = 'দুঃখিত, আপনি সমস্ত ক্ষেত্রগুলি পূরণ করা আবশ্যক.';
-$lang['reguexists']            = 'দুঃখিত, এই লগইন সঙ্গে একটি ব্যবহারকারী ইতিমধ্যেই বিদ্যমান.';
-$lang['regsuccess']            = 'ব্যবহারকারী তৈরি করা হয়েছে এবং পাসওয়ার্ড ইমেইল করে পাঠানো হয়েছিল.';
-$lang['regsuccess2']           = 'ব্যবহারকারী তৈরি করা হয়েছে.';
-$lang['regmailfail']           = 'একটি ত্রুটি পাসওয়ার্ড মেইল পাঠানোর নেভিগেশন ছিল মনে হচ্ছে. অ্যাডমিন যোগাযোগ করুন!';
-$lang['regbadmail']            = 'প্রদত্ত ইমেইল ঠিকানা সঠিক মনে হচ্ছে - আপনি এই একটি ত্রুটি মনে হলে, অ্যাডমিন যোগাযোগ';
-$lang['regbadpass']            = 'দুটি প্রদত্ত পাসওয়ার্ড অভিন্ন নয়, আবার চেষ্টা করুন.';
-$lang['regpwmail']             = 'আপনার DokuWiki পাসওয়ার্ড';
-$lang['reghere']               = 'যদিও তোমার কোনো একাউন্ট নেই? শুধু একটি পেতে';
-$lang['profna']                = 'এই উইকি প্রোফাইল পরিবর্তন সমর্থন করে না';
-$lang['profnochange']          = 'এমন কোন পরিবর্তন, না কিছুই.';
-$lang['profnoempty']           = 'একটি খালি নাম অথবা ইমেইল ঠিকানা অনুমোদিত নয়.';
-$lang['profchanged']           = 'ইউজার প্রোফাইল সফলভাবে আপডেট.';
-$lang['profnodelete']          = 'এই উইকি ব্যবহারকারী মুছে ফেলার সমর্থন করে না';
-$lang['profdeleteuser']        = 'একাউন্ট মুছে দিন';
-$lang['profdeleted']           = 'আপনার অ্যাকাউন্টটি এই উইকি থেকে মুছে ফেলা হয়েছে';
-$lang['profconfdelete']        = 'আমি এই উইকি থেকে আমার অ্যাকাউন্ট অপসারণ করতে ইচ্ছুক. <br/> এই ক্রিয়াটি পূর্বাবস্থায় ফেরানো যায় না.';
-$lang['profconfdeletemissing'] = 'নিশ্চিতকরণ চেক বক্স ticked না';
-$lang['pwdforget']             = 'আপনার পাসওয়ার্ড ভুলে গেছেন? একটি নতুন পান';
-$lang['resendna']              = 'এই উইকি পাসওয়ার্ড পুনরায় প্রেরণ সমর্থন করে না.';
-$lang['resendpwd']             = 'জন্য সেট করুন নতুন পাসওয়ার্ড';
-$lang['resendpwdmissing']      = 'দুঃখিত, আপনি সমস্ত ক্ষেত্রগুলি পূরণ করা আবশ্যক.';
-$lang['resendpwdnouser']       = 'দুঃখিত, আমরা আমাদের ডাটাবেসের মধ্যে ব্যবহারকারীর খুঁজে পাচ্ছি না.';
-$lang['resendpwdbadauth']      = 'দুঃখিত, এই auth কোড বৈধ নয়. আপনি সম্পূর্ণ কনফার্মেশন লিঙ্ক ব্যবহার নিশ্চিত করুন.';
-$lang['resendpwdconfirm']      = 'একটি নিশ্চায়ন লিঙ্ক ইমেলের মাধ্যমে পাঠানো হয়েছে.';
-$lang['resendpwdsuccess']      = 'আপনার নতুন পাসওয়ার্ড ইমেইলের মাধ্যমে পাঠানো হয়েছে.';
-$lang['license']               = 'অন্যথায় নোট যেখানে ছাড়া, এই উইকি নেভিগেশন কন্টেন্ট নিম্নলিখিত লাইসেন্সের আওতায় লাইসেন্সকৃত:';
-$lang['licenseok']             = 'দ্রষ্টব্য: আপনি নিম্নলিখিত লাইসেন্সের অধীনে আপনার বিষয়বস্তু লাইসেন্স সম্মত হন এই পৃষ্ঠার সম্পাদনার দ্বারা:';
-$lang['searchmedia']           = 'অনুসন্ধান ফাইলের নাম:';
-$lang['searchmedia_in']        = 'অনুসন্ধান %s -এ';
-$lang['txt_upload']            = 'আপলোড করার জন্য নির্বাচন করুন ফাইল:';
-$lang['txt_filename']          = 'হিসাবে আপলোড করুন (ঐচ্ছিক):';
-$lang['txt_overwrt']           = 'বিদ্যমান ফাইল মুছে যাবে';
-$lang['maxuploadsize']         = 'সর্বোচ্চ আপলোড করুন. %s-ফাইলের প্রতি.';
-$lang['lockedby']              = 'বর্তমানে দ্বারা লক:';
-$lang['lockexpire']            = 'তালা এ মেয়াদ শেষ:';
+$lang['search_fullresults']    = 'পূর্ণলেখা ফলাফল';
 $lang['js']['willexpire']      = 'এই পৃষ্ঠার সম্পাদনার জন্য আপনার লক এক মিনিটের মধ্যে মেয়াদ শেষ সম্পর্কে. \ দ্বন্দ্ব লক টাইমার রিসেট প্রিভিউ বাটন ব্যবহার এড়াতে.';
 $lang['js']['notsavedyet']     = 'অসংরক্ষিত পরিবর্তন হারিয়ে যাবে.';
 $lang['js']['searchmedia']     = 'ফাইলের জন্য অনুসন্ধান';
@@ -144,6 +110,42 @@ $lang['js']['media_done_btn']  = 'সাধিত';
 $lang['js']['media_drop']      = 'আপলোডের জন্য এখানে ফাইল ফেলুন';
 $lang['js']['media_cancel']    = 'অপসারণ';
 $lang['js']['media_overwrt']   = 'বর্তমান ফাইল ওভাররাইট করুন';
+$lang['regmissing']            = 'দুঃখিত, আপনি সমস্ত ক্ষেত্রগুলি পূরণ করা আবশ্যক.';
+$lang['reguexists']            = 'দুঃখিত, এই লগইন সঙ্গে একটি ব্যবহারকারী ইতিমধ্যেই বিদ্যমান.';
+$lang['regsuccess']            = 'ব্যবহারকারী তৈরি করা হয়েছে এবং পাসওয়ার্ড ইমেইল করে পাঠানো হয়েছিল.';
+$lang['regsuccess2']           = 'ব্যবহারকারী তৈরি করা হয়েছে.';
+$lang['regmailfail']           = 'একটি ত্রুটি পাসওয়ার্ড মেইল পাঠানোর নেভিগেশন ছিল মনে হচ্ছে. অ্যাডমিন যোগাযোগ করুন!';
+$lang['regbadmail']            = 'প্রদত্ত ইমেইল ঠিকানা সঠিক মনে হচ্ছে - আপনি এই একটি ত্রুটি মনে হলে, অ্যাডমিন যোগাযোগ';
+$lang['regbadpass']            = 'দুটি প্রদত্ত পাসওয়ার্ড অভিন্ন নয়, আবার চেষ্টা করুন.';
+$lang['regpwmail']             = 'আপনার DokuWiki পাসওয়ার্ড';
+$lang['reghere']               = 'যদিও তোমার কোনো একাউন্ট নেই? শুধু একটি পেতে';
+$lang['profna']                = 'এই উইকি প্রোফাইল পরিবর্তন সমর্থন করে না';
+$lang['profnochange']          = 'এমন কোন পরিবর্তন, না কিছুই.';
+$lang['profnoempty']           = 'একটি খালি নাম অথবা ইমেইল ঠিকানা অনুমোদিত নয়.';
+$lang['profchanged']           = 'ইউজার প্রোফাইল সফলভাবে আপডেট.';
+$lang['profnodelete']          = 'এই উইকি ব্যবহারকারী মুছে ফেলার সমর্থন করে না';
+$lang['profdeleteuser']        = 'একাউন্ট মুছে দিন';
+$lang['profdeleted']           = 'আপনার অ্যাকাউন্টটি এই উইকি থেকে মুছে ফেলা হয়েছে';
+$lang['profconfdelete']        = 'আমি এই উইকি থেকে আমার অ্যাকাউন্ট অপসারণ করতে ইচ্ছুক. <br/> এই ক্রিয়াটি পূর্বাবস্থায় ফেরানো যায় না.';
+$lang['profconfdeletemissing'] = 'নিশ্চিতকরণ চেক বক্স ticked না';
+$lang['pwdforget']             = 'আপনার পাসওয়ার্ড ভুলে গেছেন? একটি নতুন পান';
+$lang['resendna']              = 'এই উইকি পাসওয়ার্ড পুনরায় প্রেরণ সমর্থন করে না.';
+$lang['resendpwd']             = 'জন্য সেট করুন নতুন পাসওয়ার্ড';
+$lang['resendpwdmissing']      = 'দুঃখিত, আপনি সমস্ত ক্ষেত্রগুলি পূরণ করা আবশ্যক.';
+$lang['resendpwdnouser']       = 'দুঃখিত, আমরা আমাদের ডাটাবেসের মধ্যে ব্যবহারকারীর খুঁজে পাচ্ছি না.';
+$lang['resendpwdbadauth']      = 'দুঃখিত, এই auth কোড বৈধ নয়. আপনি সম্পূর্ণ কনফার্মেশন লিঙ্ক ব্যবহার নিশ্চিত করুন.';
+$lang['resendpwdconfirm']      = 'একটি নিশ্চায়ন লিঙ্ক ইমেলের মাধ্যমে পাঠানো হয়েছে.';
+$lang['resendpwdsuccess']      = 'আপনার নতুন পাসওয়ার্ড ইমেইলের মাধ্যমে পাঠানো হয়েছে.';
+$lang['license']               = 'অন্যথায় নোট যেখানে ছাড়া, এই উইকি নেভিগেশন কন্টেন্ট নিম্নলিখিত লাইসেন্সের আওতায় লাইসেন্সকৃত:';
+$lang['licenseok']             = 'দ্রষ্টব্য: আপনি নিম্নলিখিত লাইসেন্সের অধীনে আপনার বিষয়বস্তু লাইসেন্স সম্মত হন এই পৃষ্ঠার সম্পাদনার দ্বারা:';
+$lang['searchmedia']           = 'অনুসন্ধান ফাইলের নাম:';
+$lang['searchmedia_in']        = 'অনুসন্ধান %s -এ';
+$lang['txt_upload']            = 'আপলোড করার জন্য নির্বাচন করুন ফাইল:';
+$lang['txt_filename']          = 'হিসাবে আপলোড করুন (ঐচ্ছিক):';
+$lang['txt_overwrt']           = 'বিদ্যমান ফাইল মুছে যাবে';
+$lang['maxuploadsize']         = 'সর্বোচ্চ আপলোড করুন. %s-ফাইলের প্রতি.';
+$lang['lockedby']              = 'বর্তমানে দ্বারা লক:';
+$lang['lockexpire']            = 'তালা এ মেয়াদ শেষ:';
 $lang['rssfailed']             = 'ফিডটি জোগাড় করতে গিয়ে একটি ত্রুটি ঘটেছে:';
 $lang['nothingfound']          = 'কিছু পাওয়া যায়নি।';
 $lang['mediaselect']           = 'মিডিয়া ফাইল';
