@@ -3,25 +3,28 @@
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  *
+ * @author pau <pau@estuditic.com>
+ * @author Marc Zulet <marczulet@gmail.com>
+ * @author Joan <aseques@gmail.com>
+ * @author David Surroca <davidsurrocaestrada@gmail.com>
+ * @author Adolfo Jayme Barrientos <fito@libreoffice.org>
  * @author Carles Bellver <carles.bellver@cent.uji.es>
- * @author Carles Bellver <carles.bellver@gmail.com>
- * @author daniel@6temes.cat
+ * @author daniel <daniel@6temes.cat>
  * @author Eduard Díaz <edudiaz@scopia.es>
  * @author controlonline.net <controlonline.net@gmail.com>
  * @author Pauet <pauet@gmx.com>
  * @author Àngel Pérez Beroy <aperezberoy@gmail.com>
- * @author David Surroca <david.tb303@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
-$lang['doublequoteopening']    = '“';
-$lang['doublequoteclosing']    = '”';
-$lang['singlequoteopening']    = '‘';
-$lang['singlequoteclosing']    = '’';
+$lang['doublequoteopening']    = '«';
+$lang['doublequoteclosing']    = '»';
+$lang['singlequoteopening']    = '“';
+$lang['singlequoteclosing']    = '”';
 $lang['apostrophe']            = '’';
 $lang['btn_edit']              = 'Edita aquesta pàgina';
-$lang['btn_source']            = 'Mostra codi font';
-$lang['btn_show']              = 'Mostra pàgina';
+$lang['btn_source']            = 'Mostra el codi font';
+$lang['btn_show']              = 'Mostra la pàgina';
 $lang['btn_create']            = 'Crea aquesta pàgina';
 $lang['btn_search']            = 'Cerca';
 $lang['btn_save']              = 'Desa';
@@ -52,63 +55,28 @@ $lang['btn_draftdel']          = 'Suprimeix esborrany';
 $lang['btn_revert']            = 'Restaura';
 $lang['btn_register']          = 'Registra\'m';
 $lang['btn_apply']             = 'Aplica';
-$lang['btn_media']             = 'Mànager Multimèdia';
-$lang['btn_deleteuser']        = 'Esborrar compte';
+$lang['btn_media']             = 'Gestor multimèdia';
+$lang['btn_deleteuser']        = 'Suprimeix el meu compte';
 $lang['btn_img_backto']        = 'Torna a %s';
 $lang['btn_mediaManager']      = 'Veure a multimèdia mànager ';
 $lang['loggedinas']            = 'Heu entrat com:';
-$lang['user']                  = 'Nom d\'usuari';
+$lang['user']                  = 'Nom d’usuari';
 $lang['pass']                  = 'Contrasenya';
-$lang['newpass']               = 'Nova contrasenya';
+$lang['newpass']               = 'Contrasenya nova';
 $lang['oldpass']               = 'Confirmeu la contrasenya actual';
 $lang['passchk']               = 'una altra vegada';
-$lang['remember']              = 'Recorda\'m';
+$lang['remember']              = 'Recorda’m';
 $lang['fullname']              = 'Nom complet';
-$lang['email']                 = 'Correu electrònic';
-$lang['profile']               = 'Perfil d\'usuari';
+$lang['email']                 = 'Adreça electrònica';
+$lang['profile']               = 'Perfil d’usuari';
 $lang['badlogin']              = 'Nom d\'usuari o contrasenya incorrectes.';
 $lang['badpassconfirm']        = 'Contrasenya incorrecta';
 $lang['minoredit']             = 'Canvis menors';
 $lang['draftdate']             = 'L\'esborrany s\'ha desat automàticament';
 $lang['nosecedit']             = 'Mentrestant la pàgina ha estat modificada. La informació de seccions estava obsoleta i ha calgut carregar la pàgina sencera.';
-$lang['regmissing']            = 'Heu d\'omplir tots els camps.';
-$lang['reguexists']            = 'Ja existeix un altre usuari amb aquest nom.';
-$lang['regsuccess']            = 'S\'ha creat l\'usuari. La contrasenya s\'ha enviat per correu.';
-$lang['regsuccess2']           = 'S\'ha creat l\'usuari.';
-$lang['regfail']               = 'L\'usuari no pot ser creat';
-$lang['regmailfail']           = 'Sembla que un error ha impedit enviar la contrasenya per correu. Contacteu amb l\'administrador.';
-$lang['regbadmail']            = 'L\'adreça de correu que heu donat no sembla vàlida. Si creieu que això és un error, contacu amb l\'administrador.';
-$lang['regbadpass']            = 'Les dues contrasenyes no són iguals. Torneu a intentar-ho.';
-$lang['regpwmail']             = 'La vostra contrasenya per al Wiki';
-$lang['reghere']               = 'Si no teniu un compte, aquí en podeu obtenir un';
-$lang['profna']                = 'Aquest wiki no permet modificar el perfil';
-$lang['profnochange']          = 'No heu introduït cap canvi.';
-$lang['profnoempty']           = 'No es pot deixar en blanc el nom o l\'adreça de correu.';
-$lang['profchanged']           = 'El perfil d\'usuari s\'ha actualitzat correctament.';
-$lang['profnodelete']          = 'Aquesta wiki no permet esborrar usuaris';
-$lang['profdeleteuser']        = 'Esborrar compte';
-$lang['profdeleted']           = 'El vostre compte ha sigut esborrat d\'aquest compte';
-$lang['profconfdelete']        = 'Vull esmorrar el meu compte d\'aquesta wiki. </br> Aquesta acció no pot desfer-se.';
-$lang['profconfdeletemissing'] = 'Confirmació no acceptada';
-$lang['proffail']              = 'Perfil d\'usuari no actialitzat';
-$lang['pwdforget']             = 'Heu oblidat la contrasenya? Podeu obtenir-ne una de nova.';
-$lang['resendna']              = 'Aquest wiki no permet tornar a enviar la contrasenya.';
-$lang['resendpwd']             = 'Estableix una nova contrasenya per';
-$lang['resendpwdmissing']      = 'Heu d\'emplenar tots els camps.';
-$lang['resendpwdnouser']       = 'No s\'ha pogut trobar aquest usuari a la base de dades.';
-$lang['resendpwdbadauth']      = 'Aquest codi d\'autenticació no és vàlid. Assegureu-vos d\'utilitzar l\'enllaç de confirmació complet.';
-$lang['resendpwdconfirm']      = 'Se us ha enviat per correu electrònic un enllaç de confirmació.';
-$lang['resendpwdsuccess']      = 'Se us ha enviat la nova contrasenya per correu electrònic.';
-$lang['license']               = 'Excepte on es digui una altra cosa, el contingut d\'aquest wiki està subjecte a la llicència següent:';
-$lang['licenseok']             = 'Nota. En editar aquesta pàgina esteu acceptant que el vostre contingut estigui subjecte a la llicència següent:';
-$lang['searchmedia']           = 'Cerca pel nom de fitxer';
-$lang['searchmedia_in']        = 'Cerca en: %s';
-$lang['txt_upload']            = 'Trieu el fitxer que voleu penjar:';
-$lang['txt_filename']          = 'Introduïu el nom wiki (opcional):';
-$lang['txt_overwrt']           = 'Sobreescriu el fitxer actual';
-$lang['maxuploadsize']         = 'Puja com a màxim %s per arxiu.';
-$lang['lockedby']              = 'Actualment blocat per:';
-$lang['lockexpire']            = 'Venciment del blocatge:';
+$lang['searchcreatepage']      = 'Si no heu trobat el que cercàveu, podeu crear o editar la pàgina %s, el nom de la qual deriva de la vostra consulta.';
+$lang['search_fullresults']    = 'Resultats de text complet';
+$lang['js']['search_toggle_tools'] = 'Commuta les eines de cerca';
 $lang['js']['willexpire']      = 'El blocatge per a editar aquesta pàgina venç d\'aquí a un minut.\nUtilitzeu la visualització prèvia per reiniciar el rellotge i evitar conflictes.';
 $lang['js']['notsavedyet']     = 'Heu fet canvis que es perdran si no els deseu.
 Voleu continuar?';
@@ -152,6 +120,58 @@ $lang['js']['media_done_btn']  = 'Fet';
 $lang['js']['media_drop']      = 'Arrossega aquí els arxius a pujar';
 $lang['js']['media_cancel']    = 'esborra';
 $lang['js']['media_overwrt']   = 'Sobreescriu els arxius existents';
+$lang['js']['data_insecure']   = 'ADVERTÈNCIA: Sembla que el vostre directori de dades no està degudament protegit. Si us plau, llegiu sobre <a href="https://www.dokuwiki.org/security#web_access_security">Seguretat de l\'Accés Web a DokuWiki</a>.';
+$lang['search_exact_match']    = 'Coincidència exacta';
+$lang['search_starts_with']    = 'Comença per';
+$lang['search_ends_with']      = 'Termina per';
+$lang['search_contains']       = 'Conté';
+$lang['search_custom_match']   = 'Personalitzat';
+$lang['search_any_ns']         = 'Qualsevol espai de noms';
+$lang['search_any_time']       = 'Qualsevol temps';
+$lang['search_past_7_days']    = 'La setmana passada';
+$lang['search_past_month']     = 'El mes passat';
+$lang['search_past_year']      = 'L’any passat';
+$lang['search_sort_by_hits']   = 'Ordena per visites';
+$lang['search_sort_by_mtime']  = 'Ordena per darrera modificació';
+$lang['regmissing']            = 'Heu d\'omplir tots els camps.';
+$lang['reguexists']            = 'Ja existeix un altre usuari amb aquest nom.';
+$lang['regsuccess']            = 'S\'ha creat l\'usuari. La contrasenya s\'ha enviat per correu.';
+$lang['regsuccess2']           = 'S\'ha creat l\'usuari.';
+$lang['regfail']               = 'L\'usuari no pot ser creat';
+$lang['regmailfail']           = 'Sembla que un error ha impedit enviar la contrasenya per correu. Contacteu amb l\'administrador.';
+$lang['regbadmail']            = 'L\'adreça de correu que heu donat no sembla vàlida. Si creieu que això és un error, contacu amb l\'administrador.';
+$lang['regbadpass']            = 'Les dues contrasenyes no són iguals. Torneu a intentar-ho.';
+$lang['regpwmail']             = 'La vostra contrasenya per al Wiki';
+$lang['reghere']               = 'Si no teniu un compte, aquí en podeu obtenir un';
+$lang['profna']                = 'Aquest wiki no permet modificar el perfil';
+$lang['profnochange']          = 'No heu introduït cap canvi.';
+$lang['profnoempty']           = 'No es pot deixar en blanc el nom o l\'adreça de correu.';
+$lang['profchanged']           = 'El perfil d\'usuari s\'ha actualitzat correctament.';
+$lang['profnodelete']          = 'Aquesta wiki no permet esborrar usuaris';
+$lang['profdeleteuser']        = 'Esborrar compte';
+$lang['profdeleted']           = 'El vostre compte ha sigut esborrat d\'aquest compte';
+$lang['profconfdelete']        = 'Vull esmorrar el meu compte d\'aquesta wiki. </br> Aquesta acció no pot desfer-se.';
+$lang['profconfdeletemissing'] = 'Confirmació no acceptada';
+$lang['proffail']              = 'Perfil d\'usuari no actialitzat';
+$lang['pwdforget']             = 'Heu oblidat la contrasenya? Podeu obtenir-ne una de nova.';
+$lang['resendna']              = 'Aquest wiki no permet tornar a enviar la contrasenya.';
+$lang['resendpwd']             = 'Estableix una nova contrasenya per';
+$lang['resendpwdmissing']      = 'Heu d\'emplenar tots els camps.';
+$lang['resendpwdnouser']       = 'No s\'ha pogut trobar aquest usuari a la base de dades.';
+$lang['resendpwdbadauth']      = 'Aquest codi d\'autenticació no és vàlid. Assegureu-vos d\'utilitzar l\'enllaç de confirmació complet.';
+$lang['resendpwdconfirm']      = 'Se us ha enviat per correu electrònic un enllaç de confirmació.';
+$lang['resendpwdsuccess']      = 'Se us ha enviat la nova contrasenya per correu electrònic.';
+$lang['license']               = 'Excepte on es digui una altra cosa, el contingut d\'aquest wiki està subjecte a la llicència següent:';
+$lang['licenseok']             = 'Nota. En editar aquesta pàgina esteu acceptant que el vostre contingut estigui subjecte a la llicència següent:';
+$lang['searchmedia']           = 'Cerca pel nom de fitxer';
+$lang['searchmedia_in']        = 'Cerca en: %s';
+$lang['txt_upload']            = 'Trieu el fitxer que voleu penjar:';
+$lang['txt_filename']          = 'Introduïu el nom wiki (opcional):';
+$lang['txt_overwrt']           = 'Sobreescriu el fitxer actual';
+$lang['maxuploadsize']         = 'Puja com a màxim %s per arxiu.';
+$lang['allowedmime']           = 'Llista d\'extensions permeses';
+$lang['lockedby']              = 'Actualment blocat per:';
+$lang['lockexpire']            = 'Venciment del blocatge:';
 $lang['rssfailed']             = 'S\'ha produït un error en recollir aquesta alimentació: ';
 $lang['nothingfound']          = 'No s\'ha trobat res.';
 $lang['mediaselect']           = 'Selecció de fitxers';
@@ -203,7 +223,8 @@ $lang['created']               = 'creat';
 $lang['restored']              = 's\'ha restaurat una versió anterior %s';
 $lang['external_edit']         = 'edició externa';
 $lang['summary']               = 'Resum d\'edició';
-$lang['noflash']               = 'Per a visualitzar aquest contingut necessiteu el <a href="http://www.adobe.com/products/flashplayer/">connector d\'Adobe Flash</a>.';
+$lang['unknowndate']           = 'Data desconeguda';
+$lang['noflash']               = 'Per a visualitzar aquest contingut necessiteu el <a href="http://get.adobe.com/flashplayer">connector d\'Adobe Flash</a>.';
 $lang['download']              = 'Baixa el fragment';
 $lang['tools']                 = 'Eines';
 $lang['user_tools']            = 'Eines de l\'usuari';
@@ -213,7 +234,7 @@ $lang['skip_to_content']       = 'salta al contingut';
 $lang['sidebar']               = 'Barra lateral';
 $lang['mail_newpage']          = 'pàgina afegida:';
 $lang['mail_changed']          = 'pàgina modificada:';
-$lang['mail_subscribe_list']   = 'pagines canviades a l0espai de noms:';
+$lang['mail_subscribe_list']   = 'pàgines canviades a l’espai de noms:';
 $lang['mail_new_user']         = 'nou usuari:';
 $lang['mail_upload']           = 'fitxer penjat:';
 $lang['changes_type']          = 'Veure els canvis de';
@@ -244,7 +265,7 @@ $lang['qb_media']              = 'Afegeix imatges o altres fitxers';
 $lang['qb_sig']                = 'Insereix signatura';
 $lang['qb_smileys']            = 'Emoticones';
 $lang['qb_chars']              = 'Caràcters especials';
-$lang['upperns']               = 'Salta a l\'espai superior';
+$lang['upperns']               = 'salta a l’espai superior';
 $lang['metaedit']              = 'Edita metadades';
 $lang['metasaveerr']           = 'No s\'han pogut escriure les metadades';
 $lang['metasaveok']            = 'S\'han desat les metadades';
@@ -283,10 +304,13 @@ $lang['i_wikiname']            = 'Nom del wiki';
 $lang['i_enableacl']           = 'Habilita ACL (recomanat)';
 $lang['i_superuser']           = 'Superusuari';
 $lang['i_problems']            = 'L\'instal·lador ha trobat alguns problemes, que s\'indiquen més avall. No podeu continuar fins que no els hàgiu solucionat.';
-$lang['i_modified']            = 'Per raons de seguretat aquesta seqüència només funciona amb una instal·lació nova i no modificada de Dokuwiki. Hauríeu de tornar a baixar el paquet i/o descomprimir-lo o consultar les <a href="http://dokuwiki.org/install">instruccions d\'instal·lació de Dokuwiki</a> completes';
+$lang['i_modified']            = 'Per raons de seguretat aquesta seqüència només funciona amb una instal·lació nova i no modificada de Dokuwiki. Hauríeu de tornar a baixar el paquet i/o descomprimir-lo o consultar les <a href="https://www.dokuwiki.org/install">instruccions d\'instal·lació de Dokuwiki</a> completes';
 $lang['i_funcna']              = 'La funció PHP <code>%s</code> no està disponible. Potser el vostre proveïdor de serveis l\'ha inhabilitada per alguna raó';
+$lang['i_disabled']            = 'El vostre proveïdor l\'ha desactivat.';
+$lang['i_funcnmail']           = '<b>Nota:</b> La funció de correu PHP no està disponible. %s Si es manté no disponible, podeu instal·lar el <a href="https://www.dokuwiki.org/plugin:smtp">connector smtp</a>.';
 $lang['i_phpver']              = 'La vostra versió de PHP <code>%s</code> és inferior a la requerida <code>%s</code>. Necessiteu actualitzar la vostra instal·lació de PHP.';
 $lang['i_mbfuncoverload']      = 'mbstring.func_overload cal que sigui deshabilitada en php.ini perquè funcioni DokuWiki';
+$lang['i_urandom']             = 'DokuWiki no pot crear números criptogràficament segurs per a les galetes. És possible que vulgueu comprovar la vostra configuració d\'open_basedir al php.ini per un accés correcte a <code>/dev/urandom</code>.';
 $lang['i_permfail']            = 'DokuWiki no pot escriure <code>%s</code>. Heu d\'arreglar els permisos d\'aquest directori';
 $lang['i_confexists']          = '<code>%s</code> ja existeix';
 $lang['i_writeerr']            = 'No es pot crear <code>%s</code>. Comproveu els permisos del directori i/o del fitxer i creeu el fitxer manualment.';
@@ -337,6 +361,7 @@ $lang['media_perm_upload']     = 'No teniu permisos suficients per a pujar arxiu
 $lang['media_update']          = 'Puja la nova versió';
 $lang['media_restore']         = 'Restaura aquesta versió';
 $lang['media_acl_warning']     = 'Aquesta llista pot no estar completa per restriccions ACL i per llistes ocultes';
+$lang['email_fail']            = 'Falta el correu PHP () o està desactivat. No s\'ha enviat el correu electrònic següent:';
 $lang['currentns']             = 'Espai de noms actual';
 $lang['searchresult']          = 'Resultats cerca';
 $lang['plainhtml']             = 'HTML pla';
@@ -345,3 +370,4 @@ $lang['page_nonexist_rev']     = 'Pàgina no existeix a %s. Aixó es conseqüenc
 $lang['unable_to_parse_date']  = 'Impossible de esbrinar el paràmetre "%s".';
 $lang['email_signature_text']  = 'Aquest mail ha estat generat per DokuWiki a
 @DOKUWIKIURL@';
+$lang['log_file_too_large']    = 'Fitxer de log massa gran. Linies anteriors ignorades!';
