@@ -2,13 +2,17 @@
 
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
- * 
+ *
+ * @author Pasi <zazuu@zazuu.net>
+ * @author Tuomo Hartikainen <tuomo.hartikainen@heksia.fi>
  * @author Petteri <petteri@gmail.com>
  * @author Matti Pöllä <mpo@iki.fi>
  * @author Otto Vainio <otto@valjakko.net>
  * @author Teemu Mattila <ghcsystems@gmail.com>
  * @author Sami Olmari <sami@olmari.fi>
  * @author Rami Lehti <rammer@ipi.fi>
+ * @author Jussi Takala <jussi.takala@live.fi>
+ * @author Wiki Doku <SugarKidder@mailinator.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -16,7 +20,7 @@ $lang['doublequoteopening']    = '”';
 $lang['doublequoteclosing']    = '”';
 $lang['singlequoteopening']    = '’';
 $lang['singlequoteclosing']    = '’';
-$lang['apostrophe']            = '\'';
+$lang['apostrophe']            = '’';
 $lang['btn_edit']              = 'Muokkaa tätä sivua';
 $lang['btn_source']            = 'Näytä sivun lähdekoodi';
 $lang['btn_show']              = 'Näytä sivu';
@@ -40,7 +44,6 @@ $lang['btn_update']            = 'Päivitä';
 $lang['btn_delete']            = 'Poista';
 $lang['btn_back']              = 'Takaisin';
 $lang['btn_backlink']          = 'Paluulinkit';
-$lang['btn_backtomedia']       = 'Takaisin mediatiedostojen valintaan';
 $lang['btn_subscribe']         = 'Tilaa muutokset';
 $lang['btn_profile']           = 'Päivitä profiili';
 $lang['btn_reset']             = 'Tyhjennä';
@@ -53,7 +56,9 @@ $lang['btn_register']          = 'Rekisteröidy';
 $lang['btn_apply']             = 'Toteuta';
 $lang['btn_media']             = 'Media manager';
 $lang['btn_deleteuser']        = 'Poista tilini';
-$lang['loggedinas']            = 'Kirjautunut nimellä';
+$lang['btn_img_backto']        = 'Takaisin %s';
+$lang['btn_mediaManager']      = 'Näytä mediamanagerissa';
+$lang['loggedinas']            = 'Kirjautunut nimellä:';
 $lang['user']                  = 'Käyttäjänimi';
 $lang['pass']                  = 'Salasana';
 $lang['newpass']               = 'Uusi salasana';
@@ -68,42 +73,7 @@ $lang['badpassconfirm']        = 'Valitan. Salasana oli väärin';
 $lang['minoredit']             = 'Pieni muutos';
 $lang['draftdate']             = 'Luonnos tallennettu automaattisesti';
 $lang['nosecedit']             = 'Sivu on muuttunut välillä ja kappaleen tiedot olivat vanhentuneet. Koko sivu ladattu.';
-$lang['regmissing']            = 'Kaikki kentät tulee täyttää.';
-$lang['reguexists']            = 'Käyttäjä tällä käyttäjänimellä on jo olemassa.';
-$lang['regsuccess']            = 'Käyttäjä luotiin ja salasana lähetettiin sähköpostilla.';
-$lang['regsuccess2']           = 'Käyttäjänimi on luotu.';
-$lang['regmailfail']           = 'Näyttää siltä, että salasanan lähettämisessä tapahtui virhe. Ota yhteys ylläpitäjään!';
-$lang['regbadmail']            = 'Antamasi sähköpostiosoite näyttää epäkelvolta. Jos pidät tätä virheenä ota yhteys ylläpitäjään.';
-$lang['regbadpass']            = 'Annetut kaksi salasanaa eivät täsmää. Yritä uudelleen.';
-$lang['regpwmail']             = 'DokuWiki salasanasi';
-$lang['reghere']               = 'Puuttuuko sinulta käyttäjätili? Hanki sellainen';
-$lang['profna']                = 'Tässä wikissä profiilien muokkaaminen ei ole mahdollista';
-$lang['profnochange']          = 'Ei muutoksia.';
-$lang['profnoempty']           = 'Tyhjä nimi tai sähköpostiosoite ei ole sallittu.';
-$lang['profchanged']           = 'Käyttäjän profiilin päivitys onnistui.';
-$lang['profnodelete']          = 'Tässä wikissä ei voi poistaa käyttäjiä';
-$lang['profdeleteuser']        = 'Poista tili';
-$lang['profdeleted']           = 'Käyttäjätilisi on postettu tästä wikistä';
-$lang['profconfdelete']        = 'Haluan poistaa käyttäjätilini tästä wikistä. <br/> Tätä toimintoa ei voi myöhemmin peruuttaa.';
-$lang['profconfdeletemissing'] = 'Vahvistus rastia ei valittu';
-$lang['pwdforget']             = 'Unohtuiko salasana? Hanki uusi';
-$lang['resendna']              = 'Tämä wiki ei tue salasanan uudelleenlähettämistä.';
-$lang['resendpwd']             = 'Aseta uusisalasana';
-$lang['resendpwdmissing']      = 'Kaikki kentät on täytettävä.';
-$lang['resendpwdnouser']       = 'Käyttäjää ei löydy tietokannastamme.';
-$lang['resendpwdbadauth']      = 'Tunnistuskoodi on virheellinen. Varmista, että käytit koko varmistuslinkkiä.';
-$lang['resendpwdconfirm']      = 'Varmistuslinkki on lähetetty sähköpostilla';
-$lang['resendpwdsuccess']      = 'Uusi salasanasi on lähetetty sähköpostilla.';
-$lang['license']               = 'Jollei muuta ole mainittu, niin sisältö tässä wikissä on lisensoitu seuraavalla lisenssillä:';
-$lang['licenseok']             = 'Huom: Muokkaamalla tätä sivua suostut lisensoimaan sisällön seuraavan lisenssin mukaisesti:';
-$lang['searchmedia']           = 'Etsi tiedostoa nimeltä:';
-$lang['searchmedia_in']        = 'Etsi kohteesta %s';
-$lang['txt_upload']            = 'Valitse tiedosto lähetettäväksi';
-$lang['txt_filename']          = 'Lähetä nimellä (valinnainen)';
-$lang['txt_overwrt']           = 'Ylikirjoita olemassa oleva';
-$lang['maxuploadsize']         = 'Palvelimelle siirto max. %s / tiedosto.';
-$lang['lockedby']              = 'Tällä hetkellä tiedoston on lukinnut';
-$lang['lockexpire']            = 'Lukitus päättyy';
+$lang['searchcreatepage']      = 'Jos et löytänyt etsimääsi, voit luoda tai muokata sivua %s, joka on nimetty kyselysi mukaan.';
 $lang['js']['willexpire']      = 'Lukituksesi tämän sivun muokkaukseen päättyy minuutin kuluttua.\nRistiriitojen välttämiseksi paina esikatselu-nappia nollataksesi lukitusajan.';
 $lang['js']['notsavedyet']     = 'Dokumentissa on tallentamattomia muutoksia, jotka häviävät.
  Haluatko varmasti jatkaa?';
@@ -147,10 +117,46 @@ $lang['js']['media_done_btn']  = 'Valmis';
 $lang['js']['media_drop']      = 'Pudota lähetettävät tiedostot tähän';
 $lang['js']['media_cancel']    = 'Poista';
 $lang['js']['media_overwrt']   = 'Ylikirjoita olemassa olevat tiedostot';
+$lang['regmissing']            = 'Kaikki kentät tulee täyttää.';
+$lang['reguexists']            = 'Käyttäjä tällä käyttäjänimellä on jo olemassa.';
+$lang['regsuccess']            = 'Käyttäjä luotiin ja salasana lähetettiin sähköpostilla.';
+$lang['regsuccess2']           = 'Käyttäjänimi on luotu.';
+$lang['regfail']               = 'Valitsemaasi käyttäjää ei voitu luoda.';
+$lang['regmailfail']           = 'Näyttää siltä, että salasanan lähettämisessä tapahtui virhe. Ota yhteys ylläpitäjään!';
+$lang['regbadmail']            = 'Antamasi sähköpostiosoite näyttää epäkelvolta. Jos pidät tätä virheenä ota yhteys ylläpitäjään.';
+$lang['regbadpass']            = 'Annetut kaksi salasanaa eivät täsmää. Yritä uudelleen.';
+$lang['regpwmail']             = 'DokuWiki salasanasi';
+$lang['reghere']               = 'Puuttuuko sinulta käyttäjätili? Hanki sellainen';
+$lang['profna']                = 'Tässä wikissä profiilien muokkaaminen ei ole mahdollista';
+$lang['profnochange']          = 'Ei muutoksia.';
+$lang['profnoempty']           = 'Tyhjä nimi tai sähköpostiosoite ei ole sallittu.';
+$lang['profchanged']           = 'Käyttäjän profiilin päivitys onnistui.';
+$lang['profnodelete']          = 'Tässä wikissä ei voi poistaa käyttäjiä';
+$lang['profdeleteuser']        = 'Poista tili';
+$lang['profdeleted']           = 'Käyttäjätilisi on postettu tästä wikistä';
+$lang['profconfdelete']        = 'Haluan poistaa käyttäjätilini tästä wikistä. <br/> Tätä toimintoa ei voi myöhemmin peruuttaa.';
+$lang['profconfdeletemissing'] = 'Vahvistus rastia ei valittu';
+$lang['pwdforget']             = 'Unohtuiko salasana? Hanki uusi';
+$lang['resendna']              = 'Tämä wiki ei tue salasanan uudelleenlähettämistä.';
+$lang['resendpwd']             = 'Aseta uusisalasana';
+$lang['resendpwdmissing']      = 'Kaikki kentät on täytettävä.';
+$lang['resendpwdnouser']       = 'Käyttäjää ei löydy tietokannastamme.';
+$lang['resendpwdbadauth']      = 'Tunnistuskoodi on virheellinen. Varmista, että käytit koko varmistuslinkkiä.';
+$lang['resendpwdconfirm']      = 'Varmistuslinkki on lähetetty sähköpostilla';
+$lang['resendpwdsuccess']      = 'Uusi salasanasi on lähetetty sähköpostilla.';
+$lang['license']               = 'Jollei muuta ole mainittu, niin sisältö tässä wikissä on lisensoitu seuraavalla lisenssillä:';
+$lang['licenseok']             = 'Huom: Muokkaamalla tätä sivua suostut lisensoimaan sisällön seuraavan lisenssin mukaisesti:';
+$lang['searchmedia']           = 'Etsi tiedostoa nimeltä:';
+$lang['searchmedia_in']        = 'Etsi kohteesta %s';
+$lang['txt_upload']            = 'Valitse tiedosto lähetettäväksi:';
+$lang['txt_filename']          = 'Lähetä nimellä (valinnainen):';
+$lang['txt_overwrt']           = 'Ylikirjoita olemassa oleva';
+$lang['maxuploadsize']         = 'Palvelimelle siirto max. %s / tiedosto.';
+$lang['lockedby']              = 'Tällä hetkellä tiedoston on lukinnut:';
+$lang['lockexpire']            = 'Lukitus päättyy:';
 $lang['rssfailed']             = 'Virhe tapahtui noudettaessa tätä syötettä: ';
 $lang['nothingfound']          = 'Mitään ei löytynyt.';
 $lang['mediaselect']           = 'Mediatiedoston valinta';
-$lang['fileupload']            = 'Mediatiedoston lähetys';
 $lang['uploadsucc']            = 'Tiedoston lähetys onnistui';
 $lang['uploadfail']            = 'Tiedoston lähetys epäonnistui. Syynä ehkä väärät oikeudet?';
 $lang['uploadwrong']           = 'Tiedoston lähetys evätty. Tämä tiedostopääte on kielletty';
@@ -184,17 +190,20 @@ $lang['difflink']              = 'Linkki vertailunäkymään';
 $lang['diff_type']             = 'Näytä eroavaisuudet:';
 $lang['diff_inline']           = 'Sisäkkäin';
 $lang['diff_side']             = 'Vierekkäin';
+$lang['diffprevrev']           = 'Edellinen revisio';
+$lang['diffnextrev']           = 'Seuraava revisio';
+$lang['difflastrev']           = 'Viimeisin revisio';
 $lang['line']                  = 'Rivi';
-$lang['breadcrumb']            = 'Jäljet';
-$lang['youarehere']            = 'Olet täällä';
-$lang['lastmod']               = 'Viimeksi muutettu';
+$lang['breadcrumb']            = 'Jäljet:';
+$lang['youarehere']            = 'Olet täällä:';
+$lang['lastmod']               = 'Viimeksi muutettu:';
 $lang['by']                    = '/';
 $lang['deleted']               = 'poistettu';
 $lang['created']               = 'luotu';
 $lang['restored']              = 'vanha versio palautettu (%s)';
 $lang['external_edit']         = 'ulkoinen muokkaus';
 $lang['summary']               = 'Yhteenveto muokkauksesta';
-$lang['noflash']               = 'Tarvitset <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash-liitännäisen</a> nähdäksesi tämän sisällön.';
+$lang['noflash']               = 'Tarvitset <a href="http://get.adobe.com/flashplayer">Adobe Flash-liitännäisen</a> nähdäksesi tämän sisällön.';
 $lang['download']              = 'Lataa palanen';
 $lang['tools']                 = 'Työkalut';
 $lang['user_tools']            = 'Käyttäjän työkalut';
@@ -236,24 +245,21 @@ $lang['qb_sig']                = 'Lisää allekirjoitus';
 $lang['qb_smileys']            = 'Hymiöt';
 $lang['qb_chars']              = 'Erikoismerkit';
 $lang['upperns']               = 'Hyppää edelliseen nimiavaruuteen';
-$lang['admin_register']        = 'Lisää uusi käyttäjä';
 $lang['metaedit']              = 'Muokkaa metadataa';
 $lang['metasaveerr']           = 'Metadatan kirjoittaminen epäonnistui';
 $lang['metasaveok']            = 'Metadata tallennettu';
-$lang['img_backto']            = 'Takaisin';
-$lang['img_title']             = 'Otsikko';
-$lang['img_caption']           = 'Kuvateksti';
-$lang['img_date']              = 'Päivämäärä';
-$lang['img_fname']             = 'Tiedoston nimi';
-$lang['img_fsize']             = 'Koko';
-$lang['img_artist']            = 'Kuvaaja';
-$lang['img_copyr']             = 'Tekijänoikeus';
-$lang['img_format']            = 'Formaatti';
-$lang['img_camera']            = 'Kamera';
-$lang['img_keywords']          = 'Avainsanat';
-$lang['img_width']             = 'Leveys';
-$lang['img_height']            = 'Korkeus';
-$lang['img_manager']           = 'Näytä mediamanagerissa';
+$lang['img_title']             = 'Otsikko:';
+$lang['img_caption']           = 'Kuvateksti:';
+$lang['img_date']              = 'Päivämäärä:';
+$lang['img_fname']             = 'Tiedoston nimi:';
+$lang['img_fsize']             = 'Koko:';
+$lang['img_artist']            = 'Kuvaaja:';
+$lang['img_copyr']             = 'Tekijänoikeus:';
+$lang['img_format']            = 'Formaatti:';
+$lang['img_camera']            = 'Kamera:';
+$lang['img_keywords']          = 'Avainsanat:';
+$lang['img_width']             = 'Leveys:';
+$lang['img_height']            = 'Korkeus:';
 $lang['subscr_subscribe_success'] = '%s lisätty %s tilauslistalle';
 $lang['subscr_subscribe_error'] = 'Virhe lisättäessä %s tilauslistalle %s';
 $lang['subscr_subscribe_noaddress'] = 'Login tiedoissasi ei ole sähköpostiosoitetta. Sinua ei voi lisätä tilaukseen';
@@ -271,16 +277,16 @@ $lang['subscr_style_every']    = 'Sähköposti joka muutoksesta';
 $lang['subscr_style_digest']   = 'yhteenveto-sähköposti joka sivusta (joka %.2f. päivä)';
 $lang['subscr_style_list']     = 'lista muuttuneista sivuista edellisen sähköpostin jälkeen (joka %.2f. päivä)';
 $lang['authtempfail']          = 'Käyttäjien autentikointi ei tällä hetkellä onnistu. Jos ongelma jatkuu, ota yhteyttä wikin ylläpitäjään.';
-$lang['authpwdexpire']         = 'Salasanasi vanhenee %d pv:n päästä, vaihda salasanasi pikaisesti.';
 $lang['i_chooselang']          = 'Valitse kieli';
 $lang['i_installer']           = 'DokuWikin asentaja';
 $lang['i_wikiname']            = 'Wikin nimi';
 $lang['i_enableacl']           = 'Käytä käyttöoikeuksien hallintaa (ACL) (Suositeltu)';
 $lang['i_superuser']           = 'Pääkäyttäjä';
 $lang['i_problems']            = 'Asennusohjelma löysi alla listattuja ongelmia ongelmia. Et voi jatkaa ennen kuin ne on korjattu.';
-$lang['i_modified']            = 'Turvallisuussyistä tämä ohjelma toimii vain uusien ja muokkaamattomien Dokuwiki-asennusten kanssa. Pura tiedostot uudestaan asennuspaketista, tai lue <a href="http://dokuwiki.org/install">Dokuwikin asennusohje (englanniksi)</a>';
+$lang['i_modified']            = 'Turvallisuussyistä tämä ohjelma toimii vain uusien ja muokkaamattomien Dokuwiki-asennusten kanssa. Pura tiedostot uudestaan asennuspaketista, tai lue <a href="https://www.dokuwiki.org/install">Dokuwikin asennusohje (englanniksi)</a>';
 $lang['i_funcna']              = 'PHP:n funktio <code>%s</code> ei ole käytettävissä. Palveluntarjoajasi on saattanut poistaa sen jostain syystä.';
 $lang['i_phpver']              = 'Käyttämäsi PHP-ohjelmiston versio <code>%s</code> on pienempi, kuin tarvitaan <code>%s</code>. PHP-asennuksesi pitää päivittää.';
+$lang['i_mbfuncoverload']      = 'mbstring.func_overload pitää ottaa pois käytöstä php.ini -tiedostosta käyttääksesi DokuWikiä';
 $lang['i_permfail']            = '<code>%s</code> ei ole DokuWikin kirjoitettavissa. Muokkaa hakemiston oikeuksia!';
 $lang['i_confexists']          = '<code>%s</code> on jo olemassa';
 $lang['i_writeerr']            = '<code>%s</code>n luonti epäonnistui. Tarkista hakemiston/tiedoston oikeudet ja luo tiedosto käsin.';
@@ -334,3 +340,6 @@ $lang['currentns']             = 'Nykyinen nimiavaruus';
 $lang['searchresult']          = 'Haun tulokset';
 $lang['plainhtml']             = 'pelkkä HTML';
 $lang['wikimarkup']            = 'Wiki markup';
+$lang['unable_to_parse_date']  = 'Parametrin "%s" jäsennys ei onnistu.';
+$lang['email_signature_text']  = 'Tämän postin loi DokuWiki osoitteessa
+@DOKUWIKIURL@';
