@@ -62,7 +62,6 @@ $lang['badlogin']              = 'Sentímolo, mais o nome de usuario ou o contra
 $lang['minoredit']             = 'Trocos Menores';
 $lang['draftdate']             = 'Borrador gardado automaticamente en';
 $lang['nosecedit']             = 'A páxina mudou entrementres, a información da sección estaba desfasada polo que se cargou a páxina completa no seu lugar.';
-$lang['searchcreatepage']      = "Se non atopaches o que estabas a procurar, podes crear ou editar a páxina co nome relacionado coa túa procura empregando o botón axeitado.";
 $lang['regmissing']            = 'Sentímolo, mais tes que cubrir todos os campos.';
 $lang['reguexists']            = 'Sentímolo, mais xa existe un usuario con ese nome.';
 $lang['regsuccess']            = 'O usuario foi creado e o contrasinal enviado por correo-e.';
@@ -183,7 +182,7 @@ $lang['created']               = 'creado';
 $lang['restored']              = 'revisión antiga restaurada (%s)';
 $lang['external_edit']         = 'edición externa';
 $lang['summary']               = 'Resumo da edición';
-$lang['noflash']               = 'Precísase o <a href="http://www.adobe.com/products/flashplayer/">Extensión Adobe Flash</a> para amosar este contido.';
+$lang['noflash']               = 'Precísase o <a href="http://get.adobe.com/flashplayer">Extensión Adobe Flash</a> para amosar este contido.';
 $lang['download']              = 'Descargar Retallo (Snippet)';
 $lang['tools']                 = 'Ferramentas';
 $lang['user_tools']            = 'Ferramentas de usuario';
@@ -265,7 +264,7 @@ $lang['i_superuser']           = 'Super-usuario';
 $lang['i_problems']            = 'O instalador atopou algúns problemas, que se amosan de seguido. Non poderás continuar até que os soluciones.';
 $lang['i_modified']            = 'Por razóns de seguridade este script só funcionará cunha instalación nova e sen modificar do Dokuwiki.
                          Podes ou ben extraer de novo os arquivos dende o paquete descargado ou consultar as
-                         <a href="http://dokuwiki.org/install">instruccións completas de instalación do Dokuwiki</a>';
+                         <a href="https://www.dokuwiki.org/install">instruccións completas de instalación do Dokuwiki</a>';
 $lang['i_funcna']              = 'A función <code>%s</code> do PHP non está dispoñíbel. Pode que o teu provedor de hospedaxe a desactivase por algún motivo?';
 $lang['i_phpver']              = 'A túa versión <code>%s</code> do PHP é inferior á <code>%s</code> precisa. Debes actualizar a túa instalación do PHP.';
 $lang['i_permfail']            = '<code>%s</code> non é escribíbel polo DokuWiki. Debes corrixir a configuración de permisos deste directorio!';
@@ -315,3 +314,5 @@ $lang['media_perm_read']       = 'Sentímolo, non tes permisos suficientes para
 $lang['media_perm_upload']     = 'Sentímolo, non tes permisos suficientes para subir arquivos.';
 $lang['media_update']          = 'Subir nova versión';
 $lang['media_restore']         = 'Restaurar esta versión';
+$lang['email_signature_text'] = 'Este correo foi xerado polo DokuWiki en
+@DOKUWIKIURL@';
