@@ -1,6 +1,8 @@
 /* Polish initialisation for the jQuery UI date picker plugin. */
 /* Written by Jacek Wysocki (jacek.wysocki@gmail.com). */
 ( function( factory ) {
+	"use strict";
+
 	if ( typeof define === "function" && define.amd ) {
 
 		// AMD. Register as an anonymous module.
@@ -10,20 +12,21 @@
 		// Browser globals
 		factory( jQuery.datepicker );
 	}
-}( function( datepicker ) {
+} )( function( datepicker ) {
+"use strict";
 
 datepicker.regional.pl = {
 	closeText: "Zamknij",
-	prevText: "&#x3C;Poprzedni",
-	nextText: "Następny&#x3E;",
+	prevText: "Poprzedni",
+	nextText: "Następny",
 	currentText: "Dziś",
-	monthNames: [ "Styczeń","Luty","Marzec","Kwiecień","Maj","Czerwiec",
-	"Lipiec","Sierpień","Wrzesień","Październik","Listopad","Grudzień" ],
-	monthNamesShort: [ "Sty","Lu","Mar","Kw","Maj","Cze",
-	"Lip","Sie","Wrz","Pa","Lis","Gru" ],
-	dayNames: [ "Niedziela","Poniedziałek","Wtorek","Środa","Czwartek","Piątek","Sobota" ],
-	dayNamesShort: [ "Nie","Pn","Wt","Śr","Czw","Pt","So" ],
-	dayNamesMin: [ "N","Pn","Wt","Śr","Cz","Pt","So" ],
+	monthNames: [ "Styczeń", "Luty", "Marzec", "Kwiecień", "Maj", "Czerwiec",
+	"Lipiec", "Sierpień", "Wrzesień", "Październik", "Listopad", "Grudzień" ],
+	monthNamesShort: [ "Sty", "Lu", "Mar", "Kw", "Maj", "Cze",
+	"Lip", "Sie", "Wrz", "Pa", "Lis", "Gru" ],
+	dayNames: [ "Niedziela", "Poniedziałek", "Wtorek", "Środa", "Czwartek", "Piątek", "Sobota" ],
+	dayNamesShort: [ "Nie", "Pn", "Wt", "Śr", "Czw", "Pt", "So" ],
+	dayNamesMin: [ "N", "Pn", "Wt", "Śr", "Cz", "Pt", "So" ],
 	weekHeader: "Tydz",
 	dateFormat: "dd.mm.yy",
 	firstDay: 1,
@@ -34,4 +37,4 @@ datepicker.setDefaults( datepicker.regional.pl );
 
 return datepicker.regional.pl;
 
-} ) );
+} );
