@@ -1,24 +1,38 @@
 <?php
+
 /**
- * Brazilian Portuguese language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ *
+ * @author Thalles Lázaro <thallesprofissional@gmail.com>
+ * @author Daniel Dias Rodrigues <danieldiasr@gmail.com>
+ * @author Paul Nizan <paul_nizan@hormail.com>
+ * @author Eduardo Mozart de Oliveira <eduardomozart182@gmail.com>
+ * @author ANDRE BASSANI DE FREITAS <dedebf@gmail.com>
+ * @author Aleksandr Selivanov <alexgearbox@yandex.ru>
+ * @author Davi Jorge <davimoises2015@hotmail.com>
+ * @author Schopf <pschopf@gmail.com>
+ * @author Frederico Gonçalves Guimarães <frederico@teia.bio.br>
+ * @author Márcio Gomes Gonçalves <gomes@metha.com.br>
  * @author Luis Fernando Enciso <lfenciso@certto.com.br>
  * @author Alauton/Loug
- * @author Frederico Gonçalves Guimarães <frederico@teia.bio.br>
  * @author Felipe Castro <fefcas@gmail.com>
  * @author Lucien Raven <lucienraven@yahoo.com.br>
  * @author Enrico Nicoletto <liverig@gmail.com>
  * @author Flávio Veras <flaviove@gmail.com>
  * @author Jeferson Propheta <jeferson.propheta@gmail.com>
- * @author jair.henrique@gmail.com
+ * @author jair.henrique <jair.henrique@gmail.com>
  * @author Luis Dantas <luis@dantas.com>
- * @author Luis Dantas <luisdantas@gmail.com>
- * @author Jair Henrique <jair.henrique@gmail.com>
  * @author Sergio Motta <sergio@cisne.com.br>
  * @author Isaias Masiero Filho <masiero@masiero.org>
- * @author Frederico Guimarães <frederico@teia.bio.br>
  * @author Balaco Baco <balacobaco@imap.cc>
+ * @author Victor Westmann <victor.westmann@gmail.com>
+ * @author Leone Lisboa Magevski <leone1983@gmail.com>
+ * @author Dário Estevão <darioems@gmail.com>
+ * @author Juliano Marconi Lanigra <juliano.marconi@gmail.com>
+ * @author Ednei <leuloch@gmail.com>
+ * @author Hudson FAS <hudsonfas@gmail.com>
+ * @author Guilherme Cardoso <guicardoso@gmail.com>
+ * @author Viliam Dias <viliamjr@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -50,7 +64,6 @@ $lang['btn_update']            = 'Atualizar';
 $lang['btn_delete']            = 'Excluir';
 $lang['btn_back']              = 'Voltar';
 $lang['btn_backlink']          = 'Links reversos';
-$lang['btn_backtomedia']       = 'Voltar à seleção do arquivo de mídia';
 $lang['btn_subscribe']         = 'Monitorar alterações';
 $lang['btn_profile']           = 'Atualizar o perfil';
 $lang['btn_reset']             = 'Limpar';
@@ -62,7 +75,10 @@ $lang['btn_revert']            = 'Restaurar';
 $lang['btn_register']          = 'Cadastre-se';
 $lang['btn_apply']             = 'Aplicar';
 $lang['btn_media']             = 'Gerenciador de mídias';
-$lang['loggedinas']            = 'Identificado(a) como';
+$lang['btn_deleteuser']        = 'Remover minha conta';
+$lang['btn_img_backto']        = 'Voltar para %s';
+$lang['btn_mediaManager']      = 'Ver no gerenciador de mídias';
+$lang['loggedinas']            = 'Identificado(a) como:';
 $lang['user']                  = 'Nome de usuário';
 $lang['pass']                  = 'Senha';
 $lang['newpass']               = 'Nova senha';
@@ -73,40 +89,13 @@ $lang['fullname']              = 'Nome completo';
 $lang['email']                 = 'E-mail';
 $lang['profile']               = 'Perfil do usuário';
 $lang['badlogin']              = 'Desculpe, mas o nome de usuário ou a senha estão incorretos.';
+$lang['badpassconfirm']        = 'Desculpe, mas a senha está errada ';
 $lang['minoredit']             = 'Alterações mínimas';
 $lang['draftdate']             = 'O rascunho foi salvo automaticamente em';
 $lang['nosecedit']             = 'A página foi modificada nesse intervalo de tempo. Como a informação da seção estava desatualizada, foi carregada a página inteira.';
-$lang['regmissing']            = 'Desculpe, mas você precisa preencher todos os campos.';
-$lang['reguexists']            = 'Desculpe, mas já existe um usuário com esse nome.';
-$lang['regsuccess']            = 'O usuário foi criado e a senha enviada para seu e-mail.';
-$lang['regsuccess2']           = 'O usuário foi criado.';
-$lang['regmailfail']           = 'Aparentemente ocorreu um erro no envio da senha. Por favor, entre em contato com o administrador!';
-$lang['regbadmail']            = 'O endereço de e-mail fornecido é, aparentemente, inválido - se você acha que isso é um erro, entre em contato com o administrador';
-$lang['regbadpass']            = 'As senhas digitadas não são idênticas. Por favor, tente novamente.';
-$lang['regpwmail']             = 'A sua senha do DokuWiki';
-$lang['reghere']               = 'Ainda não tem uma conta? Crie uma';
-$lang['profna']                = 'Esse wiki não suporta modificações do perfil.';
-$lang['profnochange']          = 'Sem alterações, nada para fazer.';
-$lang['profnoempty']           = 'Não são permitidos nomes ou endereços de e-mail em branco.';
-$lang['profchanged']           = 'O perfil do usuário foi atualizado com sucesso.';
-$lang['pwdforget']             = 'Esqueceu sua senha? Solicite outra';
-$lang['resendna']              = 'Esse wiki não tem suporte para o reenvio de senhas.';
-$lang['resendpwd']             = 'Definir a nova senha para';
-$lang['resendpwdmissing']      = 'Desculpe, você deve preencher todos os campos.';
-$lang['resendpwdnouser']       = 'Desculpe, não foi possível encontrar esse usuário no nosso banco de dados.';
-$lang['resendpwdbadauth']      = 'Desculpe, esse código de autorização é inválido. Certifique-se de que você usou o link de confirmação inteiro.';
-$lang['resendpwdconfirm']      = 'Um link de confirmação foi enviado por e-mail.';
-$lang['resendpwdsuccess']      = 'Sua nova senha foi enviada por e-mail.';
-$lang['license']               = 'Exceto onde for informado ao contrário, o conteúdo neste wiki está sob a seguinte licença:';
-$lang['licenseok']             = 'Observe: editando esta página você aceita disponibilizar o seu conteúdo sob a seguinte licença:';
-$lang['searchmedia']           = 'Buscar arquivo:';
-$lang['searchmedia_in']        = 'Buscar em %s';
-$lang['txt_upload']            = 'Selecione o arquivo a ser enviado';
-$lang['txt_filename']          = 'Enviar como (opcional)';
-$lang['txt_overwrt']           = 'Substituir o arquivo existente';
-$lang['maxuploadsize']         = 'Tamanho máximo de %s por arquivo.';
-$lang['lockedby']              = 'Atualmente bloqueada por';
-$lang['lockexpire']            = 'O bloqueio expira em';
+$lang['searchcreatepage']      = 'Caso você não encontre o que está procurando, você pode criar ou editar a página %s, que recebeu esse nome após a sua pesquisa.';
+$lang['search_fullresults']    = 'Resultados de texto inteiro';
+$lang['js']['search_toggle_tools'] = 'Alternar as ferramentas de pesquisa';
 $lang['js']['willexpire']      = 'O seu bloqueio de edição deste página irá expirar em um minuto.\nPara evitar conflitos de edição, clique no botão de visualização para reiniciar o temporizador de bloqueio.';
 $lang['js']['notsavedyet']     = 'As alterações não salvas serão perdidas.
 Deseja realmente continuar?';
@@ -150,10 +139,64 @@ $lang['js']['media_done_btn']  = 'Concluído';
 $lang['js']['media_drop']      = 'Arraste os arquivos até aqui para enviar';
 $lang['js']['media_cancel']    = 'remover';
 $lang['js']['media_overwrt']   = 'Sobrescrever arquivos existentes';
+$lang['js']['data_insecure']   = 'AVISO: Parece que seu diretório data não está corretamente seguro. Por favor, leia sobre <a href="https://www.dokuwiki.org/security#web_access_security">Web Access Security in DokuWiki</a>.';
+$lang['search_exact_match']    = 'Correspondência exata';
+$lang['search_starts_with']    = 'Começa com';
+$lang['search_ends_with']      = 'Termina com';
+$lang['search_contains']       = 'Contém';
+$lang['search_custom_match']   = 'Personalizar';
+$lang['search_any_ns']         = 'Qualquer espaço de nomes';
+$lang['search_any_time']       = 'Qualquer hora';
+$lang['search_past_7_days']    = 'Semana passada';
+$lang['search_past_month']     = 'Mês passado';
+$lang['search_past_year']      = 'Ano passado';
+$lang['search_sort_by_hits']   = 'Ordenar pelos acertos';
+$lang['search_sort_by_mtime']  = 'Ordenar por última modificação';
+$lang['regmissing']            = 'Desculpe, mas você precisa preencher todos os campos.';
+$lang['reguexists']            = 'Desculpe, mas já existe um usuário com esse nome.';
+$lang['regsuccess']            = 'O usuário foi criado e a senha enviada para seu e-mail.';
+$lang['regsuccess2']           = 'O usuário foi criado.';
+$lang['regfail']               = 'Não foi possível criar esse usuário.';
+$lang['regmailfail']           = 'Aparentemente ocorreu um erro no envio da senha. Por favor, entre em contato com o administrador!';
+$lang['regbadmail']            = 'O endereço de e-mail fornecido é, aparentemente, inválido - se você acha que isso é um erro, entre em contato com o administrador';
+$lang['regbadpass']            = 'As senhas digitadas não são idênticas. Por favor, tente novamente.';
+$lang['regpwmail']             = 'A sua senha do DokuWiki';
+$lang['reghere']               = 'Ainda não tem uma conta? Crie uma';
+$lang['profna']                = 'Esse wiki não suporta modificações do perfil.';
+$lang['profnochange']          = 'Sem alterações, nada para fazer.';
+$lang['profnoempty']           = 'Não são permitidos nomes ou endereços de e-mail em branco.';
+$lang['profchanged']           = 'O perfil do usuário foi atualizado com sucesso.';
+$lang['profnodelete']          = 'Esse wiki não suporta a exclusão de usuários ';
+$lang['profdeleteuser']        = 'Excluir a conta';
+$lang['profdeleted']           = 'Sua conta de usuário foi excluída desse wiki';
+$lang['profconfdelete']        = 'Eu desejo remover minha conta dessa wiki. <br/> Essa ação não pode ser desfeita.';
+$lang['profconfdeletemissing'] = 'Caixa de confirmação não marcada';
+$lang['proffail']              = 'O perfil do usuário não foi atualizado.';
+$lang['proftokenlegend']       = 'Token de Autenticação';
+$lang['proftokengenerate']     = 'Redefinir Token';
+$lang['proftokeninfo']         = 'O token de autenticação pode ser usado para permitir que aplicativos de terceiros façam login e atuem em seu nome.  A redefinição do token invalidará o antigo e desconectará todos os aplicativos que usaram o token anterior.';
+$lang['pwdforget']             = 'Esqueceu sua senha? Solicite outra';
+$lang['resendna']              = 'Esse wiki não tem suporte para o reenvio de senhas.';
+$lang['resendpwd']             = 'Definir a nova senha para';
+$lang['resendpwdmissing']      = 'Desculpe, você deve preencher todos os campos.';
+$lang['resendpwdnouser']       = 'Desculpe, não foi possível encontrar esse usuário no nosso banco de dados.';
+$lang['resendpwdbadauth']      = 'Desculpe, esse código de autorização é inválido. Certifique-se de que você usou o link de confirmação inteiro.';
+$lang['resendpwdconfirm']      = 'Um link de confirmação foi enviado por e-mail.';
+$lang['resendpwdsuccess']      = 'Sua nova senha foi enviada por e-mail.';
+$lang['license']               = 'Exceto onde for informado ao contrário, o conteúdo neste wiki está sob a seguinte licença:';
+$lang['licenseok']             = 'Observe: editando esta página você aceita disponibilizar o seu conteúdo sob a seguinte licença:';
+$lang['searchmedia']           = 'Buscar arquivo:';
+$lang['searchmedia_in']        = 'Buscar em %s';
+$lang['txt_upload']            = 'Selecione o arquivo a ser enviado:';
+$lang['txt_filename']          = 'Enviar como (opcional):';
+$lang['txt_overwrt']           = 'Substituir o arquivo existente';
+$lang['maxuploadsize']         = 'Tamanho máximo de %s por arquivo.';
+$lang['allowedmime']           = 'Lista de extensões de arquivo permitidas';
+$lang['lockedby']              = 'Atualmente bloqueada por:';
+$lang['lockexpire']            = 'O bloqueio expira em:';
 $lang['rssfailed']             = 'Ocorreu um erro durante a atualização dessa fonte: ';
 $lang['nothingfound']          = 'Não foi encontrado nada.';
 $lang['mediaselect']           = 'Arquivos de mídia';
-$lang['fileupload']            = 'Envio de arquivo de mídia';
 $lang['uploadsucc']            = 'O envio foi efetuado com sucesso';
 $lang['uploadfail']            = 'Não foi possível enviar o arquivo. Será algum problema com as permissões?';
 $lang['uploadwrong']           = 'O envio foi bloqueado. Essa extensão de arquivo é proibida!';
@@ -171,7 +214,7 @@ $lang['accessdenied']          = 'Você não tem permissão para visualizar esta
 $lang['mediausage']            = 'Use a seguinte sintaxe para referenciar esse arquivo:';
 $lang['mediaview']             = 'Ver o arquivo original';
 $lang['mediaroot']             = 'raiz';
-$lang['mediaupload']           = 'Envie um arquivo para o espaço de nomes atual aqui. Para criar subespaços de nomes, preponha-os ao nome do arquivo no parâmetro "Enviar como", separados por vírgulas.';
+$lang['mediaupload']           = 'Envie um arquivo para o espaço de nomes atual aqui. Para criar subespaços de nomes, preponha-os ao nome do arquivo no parâmetro "Enviar como", separados por dois pontos.';
 $lang['mediaextchange']        = 'A extensão do arquivo mudou de .%s para .%s!';
 $lang['reference']             = 'Referências para';
 $lang['ref_inuse']             = 'O arquivo não pode ser excluído, porque ele ainda está sendo utilizado nas seguintes páginas:';
@@ -187,17 +230,23 @@ $lang['difflink']              = 'Link para esta página de comparações';
 $lang['diff_type']             = 'Ver as diferenças:';
 $lang['diff_inline']           = 'Mescladas';
 $lang['diff_side']             = 'Lado a lado';
+$lang['diffprevrev']           = 'Revisão anterior';
+$lang['diffnextrev']           = 'Próxima revisão';
+$lang['difflastrev']           = 'Última revisão';
+$lang['diffbothprevrev']       = 'Ambos lados da revisão anterior';
+$lang['diffbothnextrev']       = 'Ambos lados da revisão seguinte';
 $lang['line']                  = 'Linha';
-$lang['breadcrumb']            = 'Visitou';
-$lang['youarehere']            = 'Você está aqui';
-$lang['lastmod']               = 'Última modificação';
+$lang['breadcrumb']            = 'Visitou:';
+$lang['youarehere']            = 'Você está aqui:';
+$lang['lastmod']               = 'Última modificação:';
 $lang['by']                    = 'por';
 $lang['deleted']               = 'removida';
 $lang['created']               = 'criada';
 $lang['restored']              = 'a revisão anterior foi restaurada (%s)';
 $lang['external_edit']         = 'edição externa';
 $lang['summary']               = 'Resumo da edição';
-$lang['noflash']               = 'O <a href="http://www.adobe.com/products/flashplayer/">plug-in Adobe Flash</a> é necessário para exibir este conteúdo.';
+$lang['unknowndate']           = 'Data desconhecida';
+$lang['noflash']               = 'O <a href="http://get.adobe.com/flashplayer">plug-in Adobe Flash</a> é necessário para exibir este conteúdo.';
 $lang['download']              = 'Baixar o snippet';
 $lang['tools']                 = 'Ferramentas';
 $lang['user_tools']            = 'Ferramentas do usuário';
@@ -239,24 +288,21 @@ $lang['qb_sig']                = 'Inserir assinatura';
 $lang['qb_smileys']            = 'Carinhas';
 $lang['qb_chars']              = 'Caracteres especiais';
 $lang['upperns']               = 'Pular para espaço de nomes acima';
-$lang['admin_register']        = 'Adicionar novo usuário';
 $lang['metaedit']              = 'Editar metadados';
 $lang['metasaveerr']           = 'Não foi possível escrever os metadados';
 $lang['metasaveok']            = 'Os metadados foram salvos';
-$lang['img_backto']            = 'Voltar para';
-$lang['img_title']             = 'Título';
-$lang['img_caption']           = 'Descrição';
-$lang['img_date']              = 'Data';
-$lang['img_fname']             = 'Nome do arquivo';
-$lang['img_fsize']             = 'Tamanho';
-$lang['img_artist']            = 'Fotógrafo';
-$lang['img_copyr']             = 'Direitos autorais';
-$lang['img_format']            = 'Formato';
-$lang['img_camera']            = 'Câmera';
-$lang['img_keywords']          = 'Palavras-chave';
-$lang['img_width']             = 'Largura';
-$lang['img_height']            = 'Altura';
-$lang['img_manager']           = 'Ver no gerenciador de mídias';
+$lang['img_title']             = 'Título:';
+$lang['img_caption']           = 'Descrição:';
+$lang['img_date']              = 'Data:';
+$lang['img_fname']             = 'Nome do arquivo:';
+$lang['img_fsize']             = 'Tamanho:';
+$lang['img_artist']            = 'Fotógrafo:';
+$lang['img_copyr']             = 'Direitos autorais:';
+$lang['img_format']            = 'Formato:';
+$lang['img_camera']            = 'Câmera:';
+$lang['img_keywords']          = 'Palavras-chave:';
+$lang['img_width']             = 'Largura:';
+$lang['img_height']            = 'Altura:';
 $lang['subscr_subscribe_success'] = 'Adicionado %s à lista de monitoramentos de %s';
 $lang['subscr_subscribe_error'] = 'Ocorreu um erro na adição de %s à lista de monitoramentos de %s';
 $lang['subscr_subscribe_noaddress'] = 'Como não há nenhum endereço associado ao seu usuário, você não pode ser adicionado à lista de monitoramento';
@@ -273,9 +319,7 @@ $lang['subscr_m_receive']      = 'Receber';
 $lang['subscr_style_every']    = 'um e-mail a cada modificação';
 $lang['subscr_style_digest']   = 'um agrupamento de e-mails com as mudanças para cada página (a cada %.2f dias)';
 $lang['subscr_style_list']     = 'uma lista de páginas modificadas desde o último e-mail (a cada %.2f dias)';
-$lang['authmodfailed']         = 'A configuração da autenticação de usuário está com problemas. Por favor, informe ao administrador do wiki.';
 $lang['authtempfail']          = 'A autenticação de usuários está temporariamente desabilitada. Se essa situação persistir, por favor, informe ao administrador do Wiki.';
-$lang['authpwdexpire']         = 'Sua senha vai expirar em %d dias. Você deve mudá-la assim que for possível.';
 $lang['i_chooselang']          = 'Selecione o seu idioma';
 $lang['i_installer']           = 'Instalador do DokuWiki';
 $lang['i_wikiname']            = 'Nome do Wiki';
@@ -283,22 +327,30 @@ $lang['i_enableacl']           = 'Habilitar Lista de Controle de Acessos (recome
 $lang['i_superuser']           = 'Superusuário';
 $lang['i_problems']            = 'O instalador encontrou alguns problemas, indicados abaixo. Você não pode continuar até corrigi-los.';
 $lang['i_modified']            = 'Por questões de segurança, esse script funcionará apenas em uma instalação nova e não modificada do DokuWiki.
-Você pode extrair novamente os arquivos do pacote original ou consultar as <a href="http://dokuwiki.org/install">instruções de instalação do DokuWiki</a>.';
+Você pode extrair novamente os arquivos do pacote original ou consultar as <a href="https://www.dokuwiki.org/install">instruções de instalação do DokuWiki</a>.';
 $lang['i_funcna']              = 'A função PHP <code>%s</code> não está disponível. O seu host a mantém desabilitada por algum motivo?';
+$lang['i_disabled']            = 'Foi desativado pelo seu provedor.';
+$lang['i_funcnmail']           = '<b>Nota:</b> A função de correio PHP não está disponível. %s Se permanecer indisponível, você pode instalar o <a href="https://www.dokuwiki.org/plugin:smtp">plugin SMTP</a>.';
 $lang['i_phpver']              = 'A sua versão do PHP (<code>%s</code>) é inferior à necessária (<code>%s</code>). Você precisa atualizar a sua instalação do PHP.';
+$lang['i_mbfuncoverload']      = 'mbstring.func_overload precisa ser desabilitado no php.ini para executar o DokuWiki';
+$lang['i_urandom']             = 'O DokuWiki não pode criar números criptograficamente seguros para cookies. Você pode verificar as configurações do open_basedir no php.ini para obter o acesso <code> / dev / urandom </code> adequado.';
 $lang['i_permfail']            = 'O DokuWiki não tem permissão de escrita em <code>%s</code>. Você precisa corrigir as configurações de permissão nesse diretório!';
 $lang['i_confexists']          = '<code>%s</code> já existe';
 $lang['i_writeerr']            = 'Não foi possível criar <code>%s</code>. É necessário checar as permissões de arquivos/diretórios e criar o arquivo manualmente.';
 $lang['i_badhash']             = 'dokuwiki.php não reconhecido ou modificado (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - valor ilegal ou em branco';
-$lang['i_success']             = 'A configuração terminou com sucesso. Agora você deve excluir o arquivo install.php. Conheça o seu <a href="doku.php">novo DokuWiki</a>!';
-$lang['i_failure']             = 'Ocorreram alguns erros durante a escrita dos arquivos de configuração. É necessário corrigi-los manualmente antes de usar seu <a href="doku.php">novo DokuWiki</a>';
+$lang['i_success']             = 'A configuração terminou com sucesso. Agora você deve excluir o arquivo install.php. Conheça o seu <a href="doku.php?id=wiki:welcome">novo DokuWiki</a>!';
+$lang['i_failure']             = 'Ocorreram alguns erros durante a escrita dos arquivos de configuração. É necessário corrigi-los manualmente antes de usar seu <a href="doku.php?id=wiki:welcome">novo DokuWiki</a>';
 $lang['i_policy']              = 'Política inicial de permissões';
 $lang['i_pol0']                = 'Wiki aberto (leitura, escrita e envio de arquivos por todos)';
 $lang['i_pol1']                = 'Wiki público (leitura por todos, escrita e envio de arquivos por usuários registrados)';
 $lang['i_pol2']                = 'Wiki fechado (leitura, escrita e envio de arquivos somente por usuários registrados)';
+$lang['i_allowreg']            = 'Permite usuários se registrarem';
 $lang['i_retry']               = 'Tentar novamente';
 $lang['i_license']             = 'Por favor escolha a licença que voce deseja utilizar para seu conteúdo:';
+$lang['i_license_none']        = 'Não mostrar nenhuma informação da licença';
+$lang['i_pop_field']           = 'Por favor, nos ajude a melhorar sua experiência com DokuWiki:';
+$lang['i_pop_label']           = 'Uma vez por mês, enviar anonimamente informações de uso de dados para os desenvolvedores DokuWiki';
 $lang['recent_global']         = 'Você está observando as alterações dentro do espaço de nomes <b>%s</b>. Também é possível ver as <a href="%s">modificações recentes no wiki inteiro</a>.';
 $lang['years']                 = '%d anos atrás';
 $lang['months']                = '%d meses atrás';
@@ -331,3 +383,16 @@ $lang['media_perm_read']       = 'Desculpe, mas você não tem privilégios sufi
 $lang['media_perm_upload']     = 'Desculpe, mas você não tem privilégios suficientes para enviar arquivos.';
 $lang['media_update']          = 'Enviar uma nova versão';
 $lang['media_restore']         = 'Restaurar esta versão';
+$lang['media_acl_warning']     = 'Essa lista pode não estar completa devido a restrições de ACL e páginas ocultas.';
+$lang['email_fail']            = 'PHP mail () ausente ou desativado. O seguinte email não foi enviado:';
+$lang['currentns']             = 'Domínio atual';
+$lang['searchresult']          = 'Resultado da Busca';
+$lang['plainhtml']             = 'HTML simples';
+$lang['wikimarkup']            = 'Marcação wiki';
+$lang['page_nonexist_rev']     = 'Página não encontrada em %s. Foi criada posteriormente em <a href="%s">%s</a>.';
+$lang['unable_to_parse_date']  = 'Impossível analisar em "%s".';
+$lang['email_signature_text']  = 'Essa mensagem foi gerada pelo DokuWiki em
+@DOKUWIKIURL@';
+$lang['log_file_too_large']    = 'Arquivo de registro muito grande. As linhas anteriores foram ignoradas!';
+$lang['log_file_failed_to_open'] = 'Falha ao abrir o arquivo de log.';
+$lang['log_file_failed_to_read'] = 'Ocorreu um erro ao ler o log.';
