@@ -3,6 +3,8 @@
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  *
+ * @author CodyMaster007 <lazorenkoda1@gmail.com>
+ * @author Mykhailo <mvkorobkov@gmail.com>
  * @author velmyshanovnyi <velmyshanovnyi@gmail.com>
  * @author Dmytro Marchenko <dmytro.marchenko1989@gmail.com>
  * @author Oleksii <alexey.furashev@gmail.com>
@@ -155,6 +157,8 @@ $lang['profdeleted']           = 'Ваш профіль користувача 
 $lang['profconfdelete']        = 'Я хочу видалити мій акаунт з цієї вікі.';
 $lang['profconfdeletemissing'] = 'Галочка на "Підтверджено" не поставлена';
 $lang['proffail']              = 'Профіль користувача не вдалося поновити.';
+$lang['proftokenlegend']       = 'Токен авторизації';
+$lang['proftokengenerate']     = 'Скинути токен';
 $lang['pwdforget']             = 'Забули пароль? Отримайте новий';
 $lang['resendna']              = 'Ця Вікі не підтримує повторне відправлення пароля.';
 $lang['resendpwd']             = 'Встановити новий пароль для';
@@ -224,10 +228,11 @@ $lang['created']               = 'створено';
 $lang['restored']              = 'відновлено стару ревізію (%s)';
 $lang['external_edit']         = 'зовнішнє редагування';
 $lang['summary']               = 'Підсумок змін';
+$lang['unknowndate']           = 'Невідома дата';
 $lang['noflash']               = 'Для перегляду цієї сторінки необхідно встановити <a href="http://get.adobe.com/flashplayer">Adobe Flash Plugin</a>.';
 $lang['download']              = 'Завантажити фрагмент';
 $lang['tools']                 = 'Налаштування';
-$lang['user_tools']            = 'Користувальницькькі налаштування';
+$lang['user_tools']            = 'Користувальницькі налаштування';
 $lang['site_tools']            = 'Налаштування сайту';
 $lang['page_tools']            = 'Налаштування сторінки';
 $lang['skip_to_content']       = 'Перейти до змісту';
@@ -307,6 +312,7 @@ $lang['i_problems']            = 'Програма установки знайш
 $lang['i_modified']            = 'З причин безпеки цей скрипт буде працювати тільки з новою та немодифікованою установкою ДокуВікі.
 Вам слід або ще раз розпакувати файли із завантаженого пакету, або звернутися до повної <a href="https://www.dokuwiki.org/install">інструкції з установки ДокуВікі</a>';
 $lang['i_funcna']              = 'Функція PHP <code>%s</code> не доступна. Можливо, хостинг-провайдер відключив її з якихось причин?';
+$lang['i_disabled']            = 'Його було вимкнено вашим провайдером';
 $lang['i_phpver']              = 'Версія PHP <code>%s</code> менша, ніж необхідно - <code>%s</code>. Необхідно оновити PHP.';
 $lang['i_mbfuncoverload']      = 'mbstring.func_overload має бути вимкнена у php.ini щоб запустити DokuWiki.';
 $lang['i_permfail']            = 'ДокуВікі не має прав на запис <code>%s</code>. Необхідно змінити права доступа для цієї папки!';
@@ -369,3 +375,4 @@ $lang['page_nonexist_rev']     = 'Сторінка %s відсутня. Може
 $lang['unable_to_parse_date']  = 'Не можливо розібрати параметр "%s" ';
 $lang['email_signature_text']  = 'Це повідомлення було створене ДокуВікі з
 @DOKUWIKIURL@';
+$lang['log_file_failed_to_open'] = 'Помилка при відкритті файлу логів';
