@@ -1,20 +1,8 @@
 <?php
-/**
- * Renderer for metadata
- *
- * @author Esther Brunner <wikidesign@gmail.com>
- */
-if(!defined('DOKU_INC')) die('meh.');
 
-if(!defined('DOKU_LF')) {
-    // Some whitespace to help View > Source
-    define ('DOKU_LF', "\n");
-}
-
-if(!defined('DOKU_TAB')) {
-    // Some whitespace to help View > Source
-    define ('DOKU_TAB', "\t");
-}
+use dokuwiki\File\MediaResolver;
+use dokuwiki\File\PageResolver;
+use dokuwiki\Utf8\PhpString;
 
 /**
  * The MetaData Renderer
@@ -24,22 +12,25 @@ if(!defined('DOKU_TAB')) {
  * $persistent.
  *
  * Some simplified rendering to $doc is done to gather the page's (text-only) abstract.
+ *
+ * @author Esther Brunner <wikidesign@gmail.com>
  */
-class Doku_Renderer_metadata extends Doku_Renderer {
+class Doku_Renderer_metadata extends Doku_Renderer
+{
     /** the approximate byte lenght to capture for the abstract */
-    const ABSTRACT_LEN = 250;
+    public const ABSTRACT_LEN = 250;
 
     /** the maximum UTF8 character length for the abstract */
-    const ABSTRACT_MAX = 500;
+    public const ABSTRACT_MAX = 500;
 
     /** @var array transient meta data, will be reset on each rendering */
-    public $meta = array();
+    public $meta = [];
 
     /** @var array persistent meta data, will be kept until explicitly deleted */
-    public $persistent = array();
+    public $persistent = [];
 
     /** @var array the list of headers used to create unique link ids */
-    protected $headers = array();
+    protected $headers = [];
 
     /** @var string temporary $doc store */
     protected $store = '';
@@ -47,6 +38,9 @@ class Doku_Renderer_metadata extends Doku_Renderer {
     /** @var string keeps the first image reference */
     protected $firstimage = '';
 
+    /** @var bool whether or not data is being captured for the abstract, public to be accessible by plugins */
+    public $capturing = true;
+
     /** @var bool determines if enough data for the abstract was collected, yet */
     public $capture = true;
 
@@ -58,7 +52,8 @@ class Doku_Renderer_metadata extends Doku_Renderer {
      *
      * @return string always 'metadata'
      */
-    function getFormat() {
+    public function getFormat()
+    {
         return 'metadata';
     }
 
@@ -67,19 +62,20 @@ class Doku_Renderer_metadata extends Doku_Renderer {
      *
      * Sets up some of the persistent info about the page if it doesn't exist, yet.
      */
-    function document_start() {
+    public function document_start()
+    {
         global $ID;
 
-        $this->headers = array();
+        $this->headers = [];
 
         // external pages are missing create date
-        if(!$this->persistent['date']['created']) {
+        if (!isset($this->persistent['date']['created']) || !$this->persistent['date']['created']) {
             $this->persistent['date']['created'] = filectime(wikiFN($ID));
         }
-        if(!isset($this->persistent['user'])) {
+        if (!isset($this->persistent['user'])) {
             $this->persistent['user'] = '';
         }
-        if(!isset($this->persistent['creator'])) {
+        if (!isset($this->persistent['creator'])) {
             $this->persistent['creator'] = '';
         }
         // reset metadata to persistent values
@@ -91,27 +87,27 @@ class Doku_Renderer_metadata extends Doku_Renderer {
      *
      * Stores collected data in the metadata
      */
-    function document_end() {
+    public function document_end()
+    {
         global $ID;
 
         // store internal info in metadata (notoc,nocache)
         $this->meta['internal'] = $this->info;
 
-        if(!isset($this->meta['description']['abstract'])) {
+        if (!isset($this->meta['description']['abstract'])) {
             // cut off too long abstracts
             $this->doc = trim($this->doc);
-            if(strlen($this->doc) > self::ABSTRACT_MAX) {
-                $this->doc = utf8_substr($this->doc, 0, self::ABSTRACT_MAX).'…';
+            if (strlen($this->doc) > self::ABSTRACT_MAX) {
+                $this->doc = PhpString::substr($this->doc, 0, self::ABSTRACT_MAX) . '…';
             }
             $this->meta['description']['abstract'] = $this->doc;
         }
 
         $this->meta['relation']['firstimage'] = $this->firstimage;
 
-        if(!isset($this->meta['date']['modified'])) {
+        if (!isset($this->meta['date']['modified'])) {
             $this->meta['date']['modified'] = filemtime(wikiFN($ID));
         }
-
     }
 
     /**
@@ -122,82 +118,94 @@ class Doku_Renderer_metadata extends Doku_Renderer {
      *
      * @param $text
      */
-    function cdata($text) {
-        if(!$this->capture) return;
+    public function cdata($text)
+    {
+        if (!$this->capture || !$this->capturing) {
+            return;
+        }
 
         $this->doc .= $text;
 
         $this->captured += strlen($text);
-        if($this->captured > self::ABSTRACT_LEN) $this->capture = false;
+        if ($this->captured > self::ABSTRACT_LEN) {
+            $this->capture = false;
+        }
     }
 
     /**
      * Add an item to the TOC
      *
-     * @param string $id       the hash link
-     * @param string $text     the text to display
-     * @param int    $level    the nesting level
+     * @param string $id the hash link
+     * @param string $text the text to display
+     * @param int $level the nesting level
      */
-    function toc_additem($id, $text, $level) {
+    public function toc_additem($id, $text, $level)
+    {
         global $conf;
 
         //only add items within configured levels
-        if($level >= $conf['toptoclevel'] && $level <= $conf['maxtoclevel']) {
+        if ($level >= $conf['toptoclevel'] && $level <= $conf['maxtoclevel']) {
             // the TOC is one of our standard ul list arrays ;-)
-            $this->meta['description']['tableofcontents'][] = array(
-                'hid'   => $id,
+            $this->meta['description']['tableofcontents'][] = [
+                'hid' => $id,
                 'title' => $text,
-                'type'  => 'ul',
+                'type' => 'ul',
                 'level' => $level - $conf['toptoclevel'] + 1
-            );
+            ];
         }
-
     }
 
     /**
      * Render a heading
      *
-     * @param string $text  the text to display
-     * @param int    $level header level
-     * @param int    $pos   byte position in the original source
+     * @param string $text the text to display
+     * @param int $level header level
+     * @param int $pos byte position in the original source
      */
-    function header($text, $level, $pos) {
-        if(!isset($this->meta['title'])) $this->meta['title'] = $text;
+    public function header($text, $level, $pos)
+    {
+        if (!isset($this->meta['title'])) {
+            $this->meta['title'] = $text;
+        }
 
         // add the header to the TOC
         $hid = $this->_headerToLink($text, true);
         $this->toc_additem($hid, $text, $level);
 
         // add to summary
-        $this->cdata(DOKU_LF.$text.DOKU_LF);
+        $this->cdata(DOKU_LF . $text . DOKU_LF);
     }
 
     /**
      * Open a paragraph
      */
-    function p_open() {
+    public function p_open()
+    {
         $this->cdata(DOKU_LF);
     }
 
     /**
      * Close a paragraph
      */
-    function p_close() {
+    public function p_close()
+    {
         $this->cdata(DOKU_LF);
     }
 
     /**
      * Create a line break
      */
-    function linebreak() {
+    public function linebreak()
+    {
         $this->cdata(DOKU_LF);
     }
 
     /**
      * Create a horizontal line
      */
-    function hr() {
-        $this->cdata(DOKU_LF.'----------'.DOKU_LF);
+    public function hr()
+    {
+        $this->cdata(DOKU_LF . '----------' . DOKU_LF);
     }
 
     /**
@@ -209,26 +217,34 @@ class Doku_Renderer_metadata extends Doku_Renderer {
      *
      * @author Andreas Gohr <andi@splitbrain.org>
      */
-    function footnote_open() {
-        if($this->capture) {
-            // move current content to store and record footnote
+    public function footnote_open()
+    {
+        if ($this->capture) {
+            // move current content to store
+            // this is required to ensure safe behaviour of plugins accessed within footnotes
             $this->store = $this->doc;
-            $this->doc   = '';
+            $this->doc = '';
+
+            // disable capturing
+            $this->capturing = false;
         }
     }
 
     /**
      * Callback for footnote end syntax
      *
-     * All rendered content is moved to the $footnotes array and the old
-     * content is restored from $store again
+     * All content rendered whilst within footnote syntax mode is discarded,
+     * the previously rendered content is restored and capturing is re-enabled.
      *
      * @author Andreas Gohr
      */
-    function footnote_close() {
-        if($this->capture) {
-            // restore old content
-            $this->doc   = $this->store;
+    public function footnote_close()
+    {
+        if ($this->capture) {
+            // re-enable capturing
+            $this->capturing = true;
+            // restore previously rendered content
+            $this->doc = $this->store;
             $this->store = '';
         }
     }
@@ -236,14 +252,16 @@ class Doku_Renderer_metadata extends Doku_Renderer {
     /**
      * Open an unordered list
      */
-    function listu_open() {
+    public function listu_open()
+    {
         $this->cdata(DOKU_LF);
     }
 
     /**
      * Open an ordered list
      */
-    function listo_open() {
+    public function listo_open()
+    {
         $this->cdata(DOKU_LF);
     }
 
@@ -253,14 +271,16 @@ class Doku_Renderer_metadata extends Doku_Renderer {
      * @param int $level the nesting level
      * @param bool $node true when a node; false when a leaf
      */
-    function listitem_open($level,$node=false) {
-        $this->cdata(str_repeat(DOKU_TAB, $level).'* ');
+    public function listitem_open($level, $node = false)
+    {
+        $this->cdata(str_repeat(DOKU_TAB, $level) . '* ');
     }
 
     /**
      * Close a list item
      */
-    function listitem_close() {
+    public function listitem_close()
+    {
         $this->cdata(DOKU_LF);
     }
 
@@ -269,22 +289,25 @@ class Doku_Renderer_metadata extends Doku_Renderer {
      *
      * @param string $text
      */
-    function preformatted($text) {
+    public function preformatted($text)
+    {
         $this->cdata($text);
     }
 
     /**
      * Start a block quote
      */
-    function quote_open() {
-        $this->cdata(DOKU_LF.DOKU_TAB.'"');
+    public function quote_open()
+    {
+        $this->cdata(DOKU_LF . DOKU_TAB . '"');
     }
 
     /**
      * Stop a block quote
      */
-    function quote_close() {
-        $this->cdata('"'.DOKU_LF);
+    public function quote_close()
+    {
+        $this->cdata('"' . DOKU_LF);
     }
 
     /**
@@ -294,19 +317,21 @@ class Doku_Renderer_metadata extends Doku_Renderer {
      * @param string $lang programming language to use for syntax highlighting
      * @param string $file file path label
      */
-    function file($text, $lang = null, $file = null) {
-        $this->cdata(DOKU_LF.$text.DOKU_LF);
+    public function file($text, $lang = null, $file = null)
+    {
+        $this->cdata(DOKU_LF . $text . DOKU_LF);
     }
 
     /**
      * Display text as code content, optionally syntax highlighted
      *
-     * @param string $text     text to show
+     * @param string $text text to show
      * @param string $language programming language to use for syntax highlighting
-     * @param string $file     file path label
+     * @param string $file file path label
      */
-    function code($text, $language = null, $file = null) {
-        $this->cdata(DOKU_LF.$text.DOKU_LF);
+    public function code($text, $language = null, $file = null)
+    {
+        $this->cdata(DOKU_LF . $text . DOKU_LF);
     }
 
     /**
@@ -316,7 +341,8 @@ class Doku_Renderer_metadata extends Doku_Renderer {
      *
      * @param string $acronym
      */
-    function acronym($acronym) {
+    public function acronym($acronym)
+    {
         $this->cdata($acronym);
     }
 
@@ -327,7 +353,8 @@ class Doku_Renderer_metadata extends Doku_Renderer {
      *
      * @param string $smiley
      */
-    function smiley($smiley) {
+    public function smiley($smiley)
+    {
         $this->cdata($smiley);
     }
 
@@ -340,7 +367,8 @@ class Doku_Renderer_metadata extends Doku_Renderer {
      *
      * @param string $entity
      */
-    function entity($entity) {
+    public function entity($entity)
+    {
         $this->cdata($entity);
     }
 
@@ -352,14 +380,16 @@ class Doku_Renderer_metadata extends Doku_Renderer {
      * @param string|int $x first value
      * @param string|int $y second value
      */
-    function multiplyentity($x, $y) {
-        $this->cdata($x.'×'.$y);
+    public function multiplyentity($x, $y)
+    {
+        $this->cdata($x . '×' . $y);
     }
 
     /**
      * Render an opening single quote char (language specific)
      */
-    function singlequoteopening() {
+    public function singlequoteopening()
+    {
         global $lang;
         $this->cdata($lang['singlequoteopening']);
     }
@@ -367,7 +397,8 @@ class Doku_Renderer_metadata extends Doku_Renderer {
     /**
      * Render a closing single quote char (language specific)
      */
-    function singlequoteclosing() {
+    public function singlequoteclosing()
+    {
         global $lang;
         $this->cdata($lang['singlequoteclosing']);
     }
@@ -375,7 +406,8 @@ class Doku_Renderer_metadata extends Doku_Renderer {
     /**
      * Render an apostrophe char (language specific)
      */
-    function apostrophe() {
+    public function apostrophe()
+    {
         global $lang;
         $this->cdata($lang['apostrophe']);
     }
@@ -383,7 +415,8 @@ class Doku_Renderer_metadata extends Doku_Renderer {
     /**
      * Render an opening double quote char (language specific)
      */
-    function doublequoteopening() {
+    public function doublequoteopening()
+    {
         global $lang;
         $this->cdata($lang['doublequoteopening']);
     }
@@ -391,7 +424,8 @@ class Doku_Renderer_metadata extends Doku_Renderer {
     /**
      * Render an closinging double quote char (language specific)
      */
-    function doublequoteclosing() {
+    public function doublequoteclosing()
+    {
         global $lang;
         $this->cdata($lang['doublequoteclosing']);
     }
@@ -402,7 +436,8 @@ class Doku_Renderer_metadata extends Doku_Renderer {
      * @param string $link The link name
      * @see http://en.wikipedia.org/wiki/CamelCase
      */
-    function camelcaselink($link) {
+    public function camelcaselink($link)
+    {
         $this->internallink($link, $link);
     }
 
@@ -412,45 +447,52 @@ class Doku_Renderer_metadata extends Doku_Renderer {
      * @param string $hash hash link identifier
      * @param string $name name for the link
      */
-    function locallink($hash, $name = null) {
-        if(is_array($name)) {
+    public function locallink($hash, $name = null)
+    {
+        if (is_array($name)) {
             $this->_firstimage($name['src']);
-            if($name['type'] == 'internalmedia') $this->_recordMediaUsage($name['src']);
+            if ($name['type'] == 'internalmedia') {
+                $this->_recordMediaUsage($name['src']);
+            }
         }
     }
 
     /**
      * keep track of internal links in $this->meta['relation']['references']
      *
-     * @param string            $id   page ID to link to. eg. 'wiki:syntax'
+     * @param string $id page ID to link to. eg. 'wiki:syntax'
      * @param string|array|null $name name for the link, array for media file
      */
-    function internallink($id, $name = null) {
+    public function internallink($id, $name = null)
+    {
         global $ID;
 
-        if(is_array($name)) {
+        if (is_array($name)) {
             $this->_firstimage($name['src']);
-            if($name['type'] == 'internalmedia') $this->_recordMediaUsage($name['src']);
+            if ($name['type'] == 'internalmedia') {
+                $this->_recordMediaUsage($name['src']);
+            }
         }
 
         $parts = explode('?', $id, 2);
-        if(count($parts) === 2) {
+        if (count($parts) === 2) {
             $id = $parts[0];
         }
 
         $default = $this->_simpleTitle($id);
 
         // first resolve and clean up the $id
-        resolve_pageid(getNS($ID), $id, $exists);
-        @list($page) = explode('#', $id, 2);
+        $resolver = new PageResolver($ID);
+        $id = $resolver->resolveId($id);
+        [$page] = sexplode('#', $id, 2);
 
         // set metadata
-        $this->meta['relation']['references'][$page] = $exists;
+        $this->meta['relation']['references'][$page] = page_exists($page);
         // $data = array('relation' => array('isreferencedby' => array($ID => true)));
         // p_set_metadata($id, $data);
 
         // add link title to summary
-        if($this->capture) {
+        if ($this->capture) {
             $name = $this->_getLinkTitle($name, $default, $id);
             $this->doc .= $name;
         }
@@ -459,17 +501,20 @@ class Doku_Renderer_metadata extends Doku_Renderer {
     /**
      * Render an external link
      *
-     * @param string            $url  full URL with scheme
+     * @param string $url full URL with scheme
      * @param string|array|null $name name for the link, array for media file
      */
-    function externallink($url, $name = null) {
-        if(is_array($name)) {
+    public function externallink($url, $name = null)
+    {
+        if (is_array($name)) {
             $this->_firstimage($name['src']);
-            if($name['type'] == 'internalmedia') $this->_recordMediaUsage($name['src']);
+            if ($name['type'] == 'internalmedia') {
+                $this->_recordMediaUsage($name['src']);
+            }
         }
 
-        if($this->capture) {
-            $this->doc .= $this->_getLinkTitle($name, '<'.$url.'>');
+        if ($this->capture) {
+            $this->doc .= $this->_getLinkTitle($name, '<' . $url . '>');
         }
     }
 
@@ -478,19 +523,22 @@ class Doku_Renderer_metadata extends Doku_Renderer {
      *
      * You may want to use $this->_resolveInterWiki() here
      *
-     * @param string       $match     original link - probably not much use
-     * @param string|array $name      name for the link, array for media file
-     * @param string       $wikiName  indentifier (shortcut) for the remote wiki
-     * @param string       $wikiUri   the fragment parsed from the original link
+     * @param string $match original link - probably not much use
+     * @param string|array $name name for the link, array for media file
+     * @param string $wikiName indentifier (shortcut) for the remote wiki
+     * @param string $wikiUri the fragment parsed from the original link
      */
-    function interwikilink($match, $name = null, $wikiName, $wikiUri) {
-        if(is_array($name)) {
+    public function interwikilink($match, $name, $wikiName, $wikiUri)
+    {
+        if (is_array($name)) {
             $this->_firstimage($name['src']);
-            if($name['type'] == 'internalmedia') $this->_recordMediaUsage($name['src']);
+            if ($name['type'] == 'internalmedia') {
+                $this->_recordMediaUsage($name['src']);
+            }
         }
 
-        if($this->capture) {
-            list($wikiUri) = explode('#', $wikiUri, 2);
+        if ($this->capture) {
+            [$wikiUri] = explode('#', $wikiUri, 2);
             $name = $this->_getLinkTitle($name, $wikiUri);
             $this->doc .= $name;
         }
@@ -499,18 +547,24 @@ class Doku_Renderer_metadata extends Doku_Renderer {
     /**
      * Link to windows share
      *
-     * @param string       $url  the link
+     * @param string $url the link
      * @param string|array $name name for the link, array for media file
      */
-    function windowssharelink($url, $name = null) {
-        if(is_array($name)) {
+    public function windowssharelink($url, $name = null)
+    {
+        if (is_array($name)) {
             $this->_firstimage($name['src']);
-            if($name['type'] == 'internalmedia') $this->_recordMediaUsage($name['src']);
+            if ($name['type'] == 'internalmedia') {
+                $this->_recordMediaUsage($name['src']);
+            }
         }
 
-        if($this->capture) {
-            if($name) $this->doc .= $name;
-            else $this->doc .= '<'.$url.'>';
+        if ($this->capture) {
+            if ($name) {
+                $this->doc .= $name;
+            } else {
+                $this->doc .= '<' . $url . '>';
+            }
         }
     }
 
@@ -519,35 +573,50 @@ class Doku_Renderer_metadata extends Doku_Renderer {
      *
      * Should honor $conf['mailguard'] setting
      *
-     * @param string       $address Email-Address
-     * @param string|array $name    name for the link, array for media file
+     * @param string $address Email-Address
+     * @param string|array $name name for the link, array for media file
      */
-    function emaillink($address, $name = null) {
-        if(is_array($name)) {
+    public function emaillink($address, $name = null)
+    {
+        if (is_array($name)) {
             $this->_firstimage($name['src']);
-            if($name['type'] == 'internalmedia') $this->_recordMediaUsage($name['src']);
+            if ($name['type'] == 'internalmedia') {
+                $this->_recordMediaUsage($name['src']);
+            }
         }
 
-        if($this->capture) {
-            if($name) $this->doc .= $name;
-            else $this->doc .= '<'.$address.'>';
+        if ($this->capture) {
+            if ($name) {
+                $this->doc .= $name;
+            } else {
+                $this->doc .= '<' . $address . '>';
+            }
         }
     }
 
     /**
      * Render an internal media file
      *
-     * @param string $src     media ID
-     * @param string $title   descriptive text
-     * @param string $align   left|center|right
-     * @param int    $width   width of media in pixel
-     * @param int    $height  height of media in pixel
-     * @param string $cache   cache|recache|nocache
+     * @param string $src media ID
+     * @param string $title descriptive text
+     * @param string $align left|center|right
+     * @param int $width width of media in pixel
+     * @param int $height height of media in pixel
+     * @param string $cache cache|recache|nocache
      * @param string $linking linkonly|detail|nolink
      */
-    function internalmedia($src, $title = null, $align = null, $width = null,
-                           $height = null, $cache = null, $linking = null) {
-        if($this->capture && $title) $this->doc .= '['.$title.']';
+    public function internalmedia(
+        $src,
+        $title = null,
+        $align = null,
+        $width = null,
+        $height = null,
+        $cache = null,
+        $linking = null
+    ) {
+        if ($this->capture && $title) {
+            $this->doc .= '[' . $title . ']';
+        }
         $this->_firstimage($src);
         $this->_recordMediaUsage($src);
     }
@@ -555,27 +624,37 @@ class Doku_Renderer_metadata extends Doku_Renderer {
     /**
      * Render an external media file
      *
-     * @param string $src     full media URL
-     * @param string $title   descriptive text
-     * @param string $align   left|center|right
-     * @param int    $width   width of media in pixel
-     * @param int    $height  height of media in pixel
-     * @param string $cache   cache|recache|nocache
+     * @param string $src full media URL
+     * @param string $title descriptive text
+     * @param string $align left|center|right
+     * @param int $width width of media in pixel
+     * @param int $height height of media in pixel
+     * @param string $cache cache|recache|nocache
      * @param string $linking linkonly|detail|nolink
      */
-    function externalmedia($src, $title = null, $align = null, $width = null,
-                           $height = null, $cache = null, $linking = null) {
-        if($this->capture && $title) $this->doc .= '['.$title.']';
+    public function externalmedia(
+        $src,
+        $title = null,
+        $align = null,
+        $width = null,
+        $height = null,
+        $cache = null,
+        $linking = null
+    ) {
+        if ($this->capture && $title) {
+            $this->doc .= '[' . $title . ']';
+        }
         $this->_firstimage($src);
     }
 
     /**
      * Render the output of an RSS feed
      *
-     * @param string $url    URL of the feed
-     * @param array  $params Finetuning of the output
+     * @param string $url URL of the feed
+     * @param array $params Finetuning of the output
      */
-    function rss($url, $params) {
+    public function rss($url, $params)
+    {
         $this->meta['relation']['haspart'][$url] = true;
 
         $this->meta['date']['valid']['age'] =
@@ -590,65 +669,54 @@ class Doku_Renderer_metadata extends Doku_Renderer {
      * Removes any Namespace from the given name but keeps
      * casing and special chars
      *
-     * @author Andreas Gohr <andi@splitbrain.org>
-     *
      * @param string $name
      *
      * @return mixed|string
+     * @author Andreas Gohr <andi@splitbrain.org>
+     *
      */
-    function _simpleTitle($name) {
+    public function _simpleTitle($name)
+    {
         global $conf;
 
-        if(is_array($name)) return '';
+        if (is_array($name)) {
+            return '';
+        }
 
-        if($conf['useslash']) {
+        if ($conf['useslash']) {
             $nssep = '[:;/]';
         } else {
             $nssep = '[:;]';
         }
-        $name = preg_replace('!.*'.$nssep.'!', '', $name);
+        $name = preg_replace('!.*' . $nssep . '!', '', $name);
         //if there is a hash we use the anchor name only
         $name = preg_replace('!.*#!', '', $name);
         return $name;
     }
 
-    /**
-     * Creates a linkid from a headline
-     *
-     * @author Andreas Gohr <andi@splitbrain.org>
-     * @param string  $title   The headline title
-     * @param boolean $create  Create a new unique ID?
-     * @return string
-     */
-    function _headerToLink($title, $create = false) {
-        if($create) {
-            return sectionID($title, $this->headers);
-        } else {
-            $check = false;
-            return sectionID($title, $check);
-        }
-    }
-
     /**
      * Construct a title and handle images in titles
      *
-     * @author Harry Fuecks <hfuecks@gmail.com>
-     * @param string|array|null $title    either string title or media array
-     * @param string            $default  default title if nothing else is found
-     * @param null|string       $id       linked page id (used to extract title from first heading)
+     * @param string|array|null $title either string title or media array
+     * @param string $default default title if nothing else is found
+     * @param null|string $id linked page id (used to extract title from first heading)
      * @return string title text
+     * @author Harry Fuecks <hfuecks@gmail.com>
      */
-    function _getLinkTitle($title, $default, $id = null) {
-        if(is_array($title)) {
-            if($title['title']) {
-                return '['.$title['title'].']';
+    public function _getLinkTitle($title, $default, $id = null)
+    {
+        if (is_array($title)) {
+            if ($title['title']) {
+                return '[' . $title['title'] . ']';
             } else {
                 return $default;
             }
-        } else if(is_null($title) || trim($title) == '') {
-            if(useHeading('content') && $id) {
+        } elseif (is_null($title) || trim($title) == '') {
+            if (useHeading('content') && $id) {
                 $heading = p_get_first_heading($id, METADATA_DONT_RENDER);
-                if($heading) return $heading;
+                if ($heading) {
+                    return $heading;
+                }
             }
             return $default;
         } else {
@@ -661,15 +729,19 @@ class Doku_Renderer_metadata extends Doku_Renderer {
      *
      * @param string $src image URL or ID
      */
-    function _firstimage($src) {
-        if($this->firstimage) return;
+    protected function _firstimage($src)
+    {
         global $ID;
 
-        list($src) = explode('#', $src, 2);
-        if(!media_isexternal($src)) {
-            resolve_mediaid(getNS($ID), $src, $exists);
+        if ($this->firstimage) {
+            return;
         }
-        if(preg_match('/.(jpe?g|gif|png)$/i', $src)) {
+
+        [$src] = explode('#', $src, 2);
+        if (!media_isexternal($src)) {
+            $src = (new MediaResolver($ID))->resolveId($src);
+        }
+        if (preg_match('/.(jpe?g|gif|png|webp|svg)$/i', $src)) {
             $this->firstimage = $src;
         }
     }
@@ -679,13 +751,17 @@ class Doku_Renderer_metadata extends Doku_Renderer {
      *
      * @param string $src media ID
      */
-    function _recordMediaUsage($src) {
+    protected function _recordMediaUsage($src)
+    {
         global $ID;
 
-        list ($src) = explode('#', $src, 2);
-        if(media_isexternal($src)) return;
-        resolve_mediaid(getNS($ID), $src, $exists);
-        $this->meta['relation']['media'][$src] = $exists;
+        [$src] = explode('#', $src, 2);
+        if (media_isexternal($src)) {
+            return;
+        }
+        $src = (new MediaResolver($ID))->resolveId($src);
+        $file = mediaFN($src);
+        $this->meta['relation']['media'][$src] = file_exists($file);
     }
 
     #endregion
