@@ -1,15 +1,15 @@
 <?php
+
 /**
- * bulgarian language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ *
  * @author Nikolay Vladimirov <nikolay@vladimiroff.com>
  * @author Viktor Usunov <usun0v@mail.bg>
  * @author Kiril <neohidra@gmail.com>
  */
 $lang['admin_acl']             = 'Управление на списъците за достъп';
-$lang['acl_group']             = 'Група';
-$lang['acl_user']              = 'Потребител';
+$lang['acl_group']             = 'Група:';
+$lang['acl_user']              = 'Потребител:';
 $lang['acl_perms']             = 'Права за';
 $lang['page']                  = 'Страница';
 $lang['namespace']             = 'Именно пространство';
@@ -20,9 +20,9 @@ $lang['p_group_id']            = 'Членовете на групата <b clas
 $lang['p_group_ns']            = 'Членовете на групата <b class="aclgroup">%s</b> в момента имат следните права за именното пространство <b class="aclns">%s</b>: <i>%s</i>.';
 $lang['p_choose_id']           = 'Моля, <b>въведете потребител или група</b> в полето отгоре, за да видите или промените правата за страницата <b class="aclpage">%s</b>.';
 $lang['p_choose_ns']           = 'Моля, <b>въведете потребител или група</b> в полето отгоре, за да видите или промените правата за именното пространство <b class="aclns">%s</b>.';
-$lang['p_inherited']           = 'Бележка: Тези разрешения не са зададени директно, а са наследени от други групи или именни пространства.';
+$lang['p_inherited']           = 'Бележка: Тези права не са зададени директно, а са наследени от други групи или именни пространства.';
 $lang['p_isadmin']             = 'Бележка: Избраната група или потребител има всички права, защото е определен за супер потребител.';
-$lang['p_include']             = 'Висши права включват по-нисшите такива. Правата за създаване, качване и изтриване са приложими само за именни пространства, но не  за страници.';
+$lang['p_include']             = 'Висшите права включват по-нисши такива. Правата за създаване, качване и изтриване са приложими само за именни пространства, но не  за страници.';
 $lang['current']               = 'Текущи ACL права';
 $lang['where']                 = 'Страница/Именно пространство';
 $lang['who']                   = 'Потребител/Група';
@@ -34,4 +34,4 @@ $lang['acl_perm4']             = 'Създаване';
 $lang['acl_perm8']             = 'Качване';
 $lang['acl_perm16']            = 'Изтриване';
 $lang['acl_new']               = 'Добавяне на право';
-$lang['acl_mod']               = 'Промяна на записа';
+$lang['acl_mod']               = 'Промяна на правата';
