@@ -5,15 +5,16 @@ namespace dokuwiki\plugin\config\core\Setting;
 /**
  * Class setting_array
  */
-class SettingArray extends Setting {
-
+class SettingArray extends Setting
+{
     /**
      * Create an array from a string
      *
      * @param string $string
      * @return array
      */
-    protected function fromString($string) {
+    protected function fromString($string)
+    {
         $array = explode(',', $string);
         $array = array_map('trim', $array);
         $array = array_filter($array);
@@ -27,8 +28,9 @@ class SettingArray extends Setting {
      * @param array $array
      * @return string
      */
-    protected function fromArray($array) {
-        return join(', ', (array) $array);
+    protected function fromArray($array)
+    {
+        return implode(', ', (array) $array);
     }
 
     /**
@@ -38,17 +40,18 @@ class SettingArray extends Setting {
      * @param string $input
      * @return bool true if changed, false otherwise (incl. on error)
      */
-    public function update($input) {
-        if(is_null($input)) return false;
-        if($this->isProtected()) return false;
+    public function update($input)
+    {
+        if (is_null($input)) return false;
+        if ($this->isProtected()) return false;
 
         $input = $this->fromString($input);
 
         $value = is_null($this->local) ? $this->default : $this->local;
-        if($value == $input) return false;
+        if ($value == $input) return false;
 
-        foreach($input as $item) {
-            if($this->pattern && !preg_match($this->pattern, $item)) {
+        foreach ($input as $item) {
+            if ($this->pattern && !preg_match($this->pattern, $item)) {
                 $this->error = true;
                 $this->input = $input;
                 return false;
@@ -60,18 +63,17 @@ class SettingArray extends Setting {
     }
 
     /** @inheritdoc */
-    public function html(\admin_plugin_config $plugin, $echo = false) {
+    public function html(\admin_plugin_config $plugin, $echo = false)
+    {
         $disable = '';
 
-        if($this->isProtected()) {
+        if ($this->isProtected()) {
             $value = $this->protected;
             $disable = 'disabled="disabled"';
+        } elseif ($echo && $this->error) {
+            $value = $this->input;
         } else {
-            if($echo && $this->error) {
-                $value = $this->input;
-            } else {
-                $value = is_null($this->local) ? $this->default : $this->local;
-            }
+            $value = is_null($this->local) ? $this->default : $this->local;
         }
 
         $key = htmlspecialchars($this->key);
@@ -80,6 +82,6 @@ class SettingArray extends Setting {
         $label = '<label for="config___' . $key . '">' . $this->prompt($plugin) . '</label>';
         $input = '<input id="config___' . $key . '" name="config[' . $key .
             ']" type="text" class="edit" value="' . $value . '" ' . $disable . '/>';
-        return array($label, $input);
+        return [$label, $input];
     }
 }
