@@ -5,6 +5,7 @@ namespace dokuwiki\plugin\config\core\Setting;
 /**
  * Class setting_hidden
  */
-class SettingHidden extends Setting {
+class SettingHidden extends Setting
+{
     // Used to explicitly ignore a setting in the configuration manager.
 }
