@@ -5,16 +5,17 @@ namespace dokuwiki\plugin\config\core\Setting;
 /**
  * Class setting_password
  */
-class SettingPassword extends SettingString {
-
+class SettingPassword extends SettingString
+{
     protected $code = 'plain';  // mechanism to be used to obscure passwords
 
     /** @inheritdoc */
-    public function update($input) {
-        if($this->isProtected()) return false;
-        if(!$input) return false;
+    public function update($input)
+    {
+        if ($this->isProtected()) return false;
+        if (!$input) return false;
 
-        if($this->pattern && !preg_match($this->pattern, $input)) {
+        if ($this->pattern && !preg_match($this->pattern, $input)) {
             $this->error = true;
             $this->input = $input;
             return false;
@@ -25,7 +26,8 @@ class SettingPassword extends SettingString {
     }
 
     /** @inheritdoc */
-    public function html(\admin_plugin_config $plugin, $echo = false) {
+    public function html(\admin_plugin_config $plugin, $echo = false)
+    {
 
         $disable = $this->isProtected() ? 'disabled="disabled"' : '';
 
@@ -34,6 +36,6 @@ class SettingPassword extends SettingString {
         $label = '<label for="config___' . $key . '">' . $this->prompt($plugin) . '</label>';
         $input = '<input id="config___' . $key . '" name="config[' . $key .
             ']" autocomplete="off" type="password" class="edit" value="" ' . $disable . ' />';
-        return array($label, $input);
+        return [$label, $input];
     }
 }
