@@ -5,20 +5,20 @@ namespace dokuwiki\plugin\config\core\Setting;
 /**
  * Class setting_string
  */
-class SettingString extends Setting {
+class SettingString extends Setting
+{
     /** @inheritdoc */
-    public function html(\admin_plugin_config $plugin, $echo = false) {
+    public function html(\admin_plugin_config $plugin, $echo = false)
+    {
         $disable = '';
 
-        if($this->isProtected()) {
+        if ($this->isProtected()) {
             $value = $this->protected;
             $disable = 'disabled="disabled"';
+        } elseif ($echo && $this->error) {
+            $value = $this->input;
         } else {
-            if($echo && $this->error) {
-                $value = $this->input;
-            } else {
-                $value = is_null($this->local) ? $this->default : $this->local;
-            }
+            $value = is_null($this->local) ? $this->default : $this->local;
         }
 
         $key = htmlspecialchars($this->key);
@@ -27,6 +27,6 @@ class SettingString extends Setting {
         $label = '<label for="config___' . $key . '">' . $this->prompt($plugin) . '</label>';
         $input = '<input id="config___' . $key . '" name="config[' . $key .
             ']" type="text" class="edit" value="' . $value . '" ' . $disable . '/>';
-        return array($label, $input);
+        return [$label, $input];
     }
 }
