@@ -94,10 +94,6 @@ $lang['indexdelay']            = 'دواخستنی کات پێش پێڕستکر
 $lang['mailguard']             = 'ناونیشانی ئیمەیلی نادیار';
 $lang['iexssprotect']          = 'پشکنینی فایلە بارکراوەکان بۆ ئەگەری خراپی JavaScript یان HTML کۆد';
 $lang['usedraft']              = 'بە شێوەیەکی ئۆتۆماتیکی ڕەشنووسێک لە کاتی بژارکردندا خزن بکە';
-$lang['htmlok']                = 'ڕێپێدانی HTML ی بنچینکراو
-';
-$lang['phpok']                 = 'ڕێپێدانی PHPچەسپێنراو
-';
 $lang['locktime']              = 'بەرزترین تەمەن بۆ فایلەکانی قوفڵ (چرکە)
 ';
 $lang['cachetime']             = 'بەرزترین تەمەن بۆ حەشارگە (چرکە)
