@@ -1,28 +1,32 @@
 <?php
+
 /**
+ * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ *
  * Estonian language file
  *
- * @author kristian.kankainen@kuu.la
+ * @author Werewolf <alvar@raamat.polva.ee>
+ * @author kristian.kankainen <kristian.kankainen@kuu.la>
  * @author Rivo Zängov <eraser@eraser.ee>
  */
 $lang['menu']                  = 'Seadete haldamine';
 $lang['_configuration_manager'] = 'Seadete haldamine';
 $lang['_basic']                = 'Peamised seaded';
 $lang['_display']              = 'Näitamise seaded';
-$lang['_authentication']       = 'Audentimise seaded';
+$lang['_authentication']       = 'Autentimise seaded';
 $lang['_anti_spam']            = 'Spämmitõrje seaded';
-$lang['_editing']              = 'Muutmise seaded';
+$lang['_editing']              = 'Muudatuste seaded';
 $lang['_links']                = 'Lingi seaded';
 $lang['_media']                = 'Meedia seaded';
 $lang['_advanced']             = 'Laiendatud seaded';
 $lang['_network']              = 'Võrgu seaded';
-$lang['_plugin_sufix']         = 'Plugina seaded';
-$lang['_template_sufix']       = 'Kujunduse seaded';
 $lang['title']                 = 'Wiki pealkiri';
 $lang['template']              = 'Kujundus';
 $lang['recent']                = 'Viimased muudatused';
 $lang['signature']             = 'Allkiri';
-$lang['defaultgroup']          = 'Vaikimisi grupp';
+$lang['passcrypt']             = 'Parooli krüptimismeetod';
+$lang['defaultgroup']          = 'Vaikimisi grupp, kõik uued kasutajad lisatakse sellesse gruppi';
+$lang['superuser']             = 'Superkasutaja - grupp, kasutaja või komaga eraldatud loetelu kasutaja1,@grupp1,kasutaja2 täielike pääsuõigustega lehekülgedele ja funktsioonidele, sõltumata ACL seadistustest';
 $lang['disableactions_check']  = 'Kontrolli';
 $lang['compression_o_0']       = 'pole';
 $lang['compression_o_gz']      = 'gzip';
