@@ -86,8 +86,6 @@ $lang['indexdelay']            = 'Denbora atzerapena indexatu baino lehen (seg)'
 $lang['mailguard']             = 'Ezkutatu posta-e helbidea';
 $lang['iexssprotect']          = 'Egiaztatu igotako fitxategiak JavaScript edo HTML kode maltzurra detektatzeko';
 $lang['usedraft']              = 'Automatikoki zirriborroa gorde editatze garaian';
-$lang['htmlok']                = 'Enbotatutako HTMLa baimendu';
-$lang['phpok']                 = 'Enbotatutako PHPa baimendu';
 $lang['locktime']              = 'Adin maximoa lock fitxategientzat (seg)';
 $lang['cachetime']             = 'Adin maximoa cachearentzat (seg)';
 $lang['target____wiki']        = 'Barne estekentzat helburu leihoa';
@@ -135,12 +133,6 @@ $lang['proxy____user']         = 'Proxyaren erabiltzaile izena';
 $lang['proxy____pass']         = 'Proxyaren pasahitza ';
 $lang['proxy____ssl']          = 'Erabili SSL Proxyra konektatzeko';
 $lang['proxy____except']       = 'URLak detektatzeko espresio erregularra, zeinentzat Proxy-a sahiestu beharko litzatekeen.';
-$lang['safemodehack']          = 'Gaitu modu segurua hack-a';
-$lang['ftp____host']           = 'FTP zerbitzaria modu seguruarentzat';
-$lang['ftp____port']           = 'FTP portua modu seguruarentzat';
-$lang['ftp____user']           = 'FTP erabiltzailea modu seguruarentzat';
-$lang['ftp____pass']           = 'FTP pasahitza modu seguruarentzat';
-$lang['ftp____root']           = 'FTP erro direktorioa modu seguruarentzat';
 $lang['license_o_']            = 'Bat ere ez hautaturik';
 $lang['typography_o_0']        = 'ezer';
 $lang['typography_o_1']        = 'Komatxo bikoitzak bakarrik';
