@@ -29,8 +29,6 @@ $lang['passcrypt']             = 'Dulritunaraðferð aðgangsorðs';
 $lang['defaultgroup']          = 'Sjálfgefinn hópur';
 $lang['superuser']             = 'Hópur kerfisstjóra ';
 $lang['profileconfirm']        = 'Staðfestu breytingar með aðgangsorði';
-$lang['htmlok']                = 'Fella HTML inn';
-$lang['phpok']                 = 'Fella PHP inn';
 $lang['gdlib']                 = 'Útgáfa af GD Lib';
 $lang['jpg_quality']           = 'JPG gæðastilling (0-100)';
 $lang['mailfrom']              = 'Rafpóstfang fyrir sjálfvirkar póstsendingar';
