@@ -44,9 +44,7 @@ $lang['recent']                = 'Extremae mutationes';
 $lang['breadcrumbs']           = 'Numerus uestigiorum';
 $lang['youarehere']            = 'Ordo uestigiorum';
 $lang['typography']            = 'Signa supponentes';
-$lang['htmlok']                = 'HTML aptum facere';
-$lang['phpok']                 = 'PHP aptum facere';
-$lang['dformat']               = 'Forma diei (uide paginam <a href="http://www.php.net/strftime">de diebus</a>)';
+$lang['dformat']               = 'Forma diei (uide paginam <a href="http://php.net/strftime">de diebus</a>)';
 $lang['signature']             = 'Subscriptio';
 $lang['toptoclevel']           = 'Gradus maior tabularum argumentorum';
 $lang['tocminheads']           = 'Minimus numerus capitum';
@@ -127,12 +125,6 @@ $lang['proxy____user']         = 'Proxis nomen sodalis';
 $lang['proxy____pass']         = 'Proxis tessera';
 $lang['proxy____ssl']          = 'SSL ut connectas uti';
 $lang['proxy____except']       = 'Verba, ut VRL inspicias, quibus Proxis non agnoscitur.';
-$lang['safemodehack']          = 'Ad tempus conseruatio apta facere';
-$lang['ftp____host']           = 'FTP computator seruitor ad tempus seruatis';
-$lang['ftp____port']           = 'FTP ianua ad tempus seruatis';
-$lang['ftp____user']           = 'FTP Sodalis ad tempus seruatis';
-$lang['ftp____pass']           = 'FTP tessera ad tempus seruatis';
-$lang['ftp____root']           = 'FTP domicilium ad tempus seruatis';
 $lang['license_o_']            = 'Nihil electum';
 $lang['typography_o_0']        = 'neuter';
 $lang['typography_o_1']        = 'sine singulis uirgulis';
