@@ -89,8 +89,6 @@ $lang['indexdelay']            = 'Časovni zamik pred ustvarjanjem kazala (v sek
 $lang['mailguard']             = 'Šifriraj elektronske naslove';
 $lang['iexssprotect']          = 'Preveri poslane datoteke za zlonamerno kodo JavaScript ali HTML';
 $lang['usedraft']              = 'Samodejno shrani osnutek med urejanjem strani';
-$lang['htmlok']                = 'Dovoli vstavljeno kodo HTML';
-$lang['phpok']                 = 'Dovoli vstavljeno kodo PHP';
 $lang['locktime']              = 'Največja dovoljena starost datotek zaklepa (v sekundah)';
 $lang['cachetime']             = 'Največja dovoljena starost predpomnilnika (v sekundah)';
 $lang['target____wiki']        = 'Ciljno okno za notranje povezave';
@@ -139,12 +137,6 @@ $lang['proxy____user']         = 'Uporabniško ime posredniškega strežnika';
 $lang['proxy____pass']         = 'Geslo posredniškega strežnika';
 $lang['proxy____ssl']          = 'Uporabi varno povezavo SSL za povezavo z posredniškim strežnikom';
 $lang['proxy____except']       = 'Logični izrazi morajo biti skladni z naslovi URL, ki gredo mimo posredniškega strežnika.';
-$lang['safemodehack']          = 'Omogoči obhod načina SafeMode PHP';
-$lang['ftp____host']           = 'Strežnik FTP za obhod načina SafeMode';
-$lang['ftp____port']           = 'Vrata strežnika FTP za obhod načina SafeMode';
-$lang['ftp____user']           = 'Uporabniško ime za FTP za obhod načina SafeMode';
-$lang['ftp____pass']           = 'Geslo za strežnik FTP za obhod načina SafeMode';
-$lang['ftp____root']           = 'Korenska mapa FTP za obhod načina SafeMode';
 $lang['license_o_']            = 'Ni izbranega dovoljenja';
 $lang['typography_o_0']        = 'brez';
 $lang['typography_o_1']        = 'izloči enojne narekovaje';
