@@ -83,8 +83,6 @@ $lang['indexdelay']            = 'Одлагање индексирања (се
 $lang['mailguard']             = 'Замутити Е-адресе';
 $lang['iexssprotect']          = 'Провера потенцијално малициозног кода у Јаваскрипт или ХТМЛ коду';
 $lang['usedraft']              = 'Аутоматски сачувај скицу у току писања измена';
-$lang['htmlok']                = 'Дозволи угњежђени ХТМЛ';
-$lang['phpok']                 = 'Дозволи угњежђени ПХП';
 $lang['locktime']              = 'МАксимално трајање закључавања датотека (сек)';
 $lang['cachetime']             = 'Максимално трајање оставе (сек)';
 $lang['target____wiki']        = 'Циљни прозор за интерне линкове';
