@@ -41,8 +41,6 @@ $lang['disableactions_check']  = 'ตรวจสอบ';
 $lang['auth_security_timeout'] = 'ระยะเวลาที่จะตัดการเชื่อมต่อแบบการใช้งานด้วยสิทธิ์ผู้ใช้ (วินาที)';
 $lang['usewordblock']          = 'คำที่จะถือว่าเป็นสแปม';
 $lang['relnofollow']           = 'ใช้ rel="nofollow" สำหรับลิงก์ภายนอก';
-$lang['htmlok']                = 'อนุญาตให้ใช้ HTML';
-$lang['phpok']                 = 'อนุญาตให้ใช้ PHP';
 $lang['locktime']              = 'ระยะเวลานานสุด ที่จะล็อคไม่ให้แก้ไขไฟล์ (วินาที)';
 $lang['cachetime']             = 'ระยะเวลาสำหรับการเก็บแคช (วินาที)';
 $lang['target____wiki']        = 'เปิดแสดงลิงก์ภายใน ในหน้าเว็บแบบใด';
