@@ -12,7 +12,7 @@ $lang['js']['loader']          = 'La prévisualisation est en chargement... <br
 $lang['js']['popup']           = 'Ouvrir dans une nouvelle fenêtre';
 $lang['error']                 = 'Désolé, ce thème n\'utilise pas cette fonctionnalité.';
 $lang['btn_preview']           = 'Aperçu des changements';
-$lang['btn_save']              = 'sauvegarder les changements.';
+$lang['btn_save']              = 'Sauvegarder les changements.';
 $lang['btn_reset']             = 'Remettre les changements courants à zéro';
 $lang['btn_revert']            = 'Remettre les styles du thème aux valeurs par défaut';
 $lang['__text__']              = 'Couleur de texte principale';
