@@ -1,28 +1,35 @@
 <?php
+
 /**
- * Spanish language file
+ * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  *
  * @author Miguel Pagano <miguel.pagano>
  * @author Oscar M. Lage <r0sk10@gmail.com>
  * @author Gabriel Castillo <gch@pumas.ii.unam.mx>
- * @author oliver@samera.com.py
+ * @author oliver <oliver@samera.com.py>
  * @author Enrico Nicoletto <liverig@gmail.com>
  * @author Manuel Meco <manuel.meco@gmail.com>
  * @author VictorCastelan <victorcastelan@gmail.com>
- * @author Jordan Mero  hack.jord@gmail.com
+ * @author Jordan Mero <hack.jord@gmail.com>
  * @author Felipe Martinez <metalmartinez@gmail.com>
  * @author Javier Aranda <internet@javierav.com>
  * @author Zerial <fernando@zerial.org>
  * @author Marvin Ortega <maty1206@maryanlinux.com>
  * @author Daniel Castro Alvarado <dancas2@gmail.com>
  * @author Fernando J. Gómez <fjgomez@gmail.com>
- * @author Victor Castelan <victorcastelan@gmail.com>
  * @author Mauro Javier Giamberardino <mgiamberardino@gmail.com>
  * @author emezeta <emezeta@infoprimo.com>
  * @author Oscar Ciudad <oscar@jacho.net>
  * @author Ruben Figols <ruben.figols@gmail.com>
  * @author Gerardo Zamudio <gerardo@gerardozamudio.net>
- * @author Mercè López mercelz@gmail.com
+ * @author Mercè López <mercelz@gmail.com>
+ * @author Antonio Bueno <atnbueno@gmail.com>
+ * @author Antonio Castilla <antoniocastilla@trazoide.com>
+ * @author Jonathan Hernández <me@jhalicea.com>
+ * @author Domingo Redal <docxml@gmail.com>
+ * @author solohazlo <solohhazlo@gmail.com>
+ * @author David Roy <davidroyapp@gmail.com>
+ * @author Enny Rodriguez <aquilez.4@gmail.com>
  */
 $lang['menu']                  = 'Administración de usuarios';
 $lang['noauth']                = '(la autenticación de usuarios no está disponible)';
@@ -45,6 +52,11 @@ $lang['search']                = 'Buscar';
 $lang['search_prompt']         = 'Realizar la búsqueda';
 $lang['clear']                 = 'Limpiar los filtros de la búsqueda';
 $lang['filter']                = 'Filtrar';
+$lang['export_all']            = 'Exportar Todos los Usuarios (CSV)';
+$lang['export_filtered']       = 'Exportar Lista de Usuarios Filtrada (CSV)';
+$lang['import']                = 'Importar Nuevos Usuarios';
+$lang['line']                  = 'Línea nº';
+$lang['error']                 = 'Mensaje de error';
 $lang['summary']               = 'Mostrando los usuarios %1$d-%2$d de %3$d encontrados. Cantidad total de usuarios %4$d.';
 $lang['nonefound']             = 'No se encontraron usuarios que coincidan con los párametros de la búsqueda. Cantidad total de usuarios %d.';
 $lang['delete_ok']             = '%d usuarios eliminados';
@@ -65,3 +77,24 @@ $lang['add_ok']                = 'El usuario fue creado exitosamente';
 $lang['add_fail']              = 'Falló la creación del usuario';
 $lang['notify_ok']             = 'Se envió la notificación por correo electrónico';
 $lang['notify_fail']           = 'No se pudo enviar la notificación por correo electrónico';
+$lang['import_userlistcsv']    = 'Lista de usuarios (CSV): ';
+$lang['import_header']         = 'Importaciones Más Recientes - Fallos';
+$lang['import_success_count']  = 'Importación de usuarios: %d usuarios encontrados, %d importados correctamente.';
+$lang['import_failure_count']  = 'Importación de usuarios: %d fallaron. Los fallos se enumeran a continuación.';
+$lang['import_error_fields']   = 'Campos insuficientes, encontrados %d, se requieren 4.';
+$lang['import_error_baduserid'] = 'Identificador de usuario no encontrado';
+$lang['import_error_badname']  = 'Nombre erróneo';
+$lang['import_error_badmail']  = 'Dirección de correo electrónico incorrecta';
+$lang['import_error_upload']   = 'Error al importar. El archivo csv no se pudo cargar o está vacío.';
+$lang['import_error_readfail'] = 'Error al importar. No se puede leer el archivo subido.';
+$lang['import_error_create']   = 'No se puede crear el usuario';
+$lang['import_notify_fail']    = 'Mensaje de notificación no se ha podido enviar por el usuario importado,%s con el email %s.';
+$lang['import_downloadfailures'] = 'Descarga errores en archivo CSV para la corrección';
+$lang['addUser_error_missing_pass'] = 'Por favor, establezca una contraseña o active las notificaciónes de usuario para permitir la generación de contraseñas.';
+$lang['addUser_error_pass_not_identical'] = 'Las contraseñas no coinciden';
+$lang['addUser_error_modPass_disabled'] = 'Está desactivado por ahora modificar contraseñas.';
+$lang['addUser_error_name_missing'] = 'Por favor teclea el nombre del nuevo usuario.';
+$lang['addUser_error_modName_disabled'] = 'La modificación de nombres está desactivada.';
+$lang['addUser_error_mail_missing'] = 'Por favor indica el email del nuevo usuario.';
+$lang['addUser_error_modMail_disabled'] = 'La modificación de email está desactivada.';
+$lang['addUser_error_create_event_failed'] = 'Un plugin impidió que se añadiera el nuevo usuario. Revisa los otros mensajes para obtener más detalles.';
