@@ -103,6 +103,7 @@ function createPicker(id,props,edid){
             jQuery(document.createElement('img'))
                 .attr('src', item)
                 .attr('alt', '')
+                .css('height', '16')
                 .appendTo($makebutton(key));
         }else if (typeof item == 'string'){
             // a list of text -> treat as text picker
@@ -209,7 +210,8 @@ function deleteDraft() {
     jQuery.post(DOKU_BASE + 'lib/exe/ajax.php',
         {
             call: 'draftdel',
-            id: $dwform.find('input[name=id]').val()
+            id: $dwform.find('input[name=id]').val(),
+            sectok: $dwform.find('input[name=sectok]').val()
         }
     );
 }
