@@ -22,6 +22,8 @@ var dw_linkwiz = {
         var pos = $editor.position();
 
         // create HTML Structure
+        if(dw_linkwiz.$wiz)
+            return;
         dw_linkwiz.$wiz = jQuery(document.createElement('div'))
                .dialog({
                    autoOpen: false,
@@ -55,9 +57,9 @@ var dw_linkwiz = {
         }
 
         // attach event handlers
-        jQuery('#link__wiz .ui-dialog-titlebar-close').click(dw_linkwiz.hide);
+        jQuery('#link__wiz .ui-dialog-titlebar-close').on('click', dw_linkwiz.hide);
         dw_linkwiz.$entry.keyup(dw_linkwiz.onEntry);
-        jQuery(dw_linkwiz.result).delegate('a', 'click', dw_linkwiz.onResultClick);
+        jQuery(dw_linkwiz.result).on('click', 'a', dw_linkwiz.onResultClick);
     },
 
     /**
@@ -212,7 +214,7 @@ var dw_linkwiz = {
             return;
         }
 
-        sel = getSelection(dw_linkwiz.textArea);
+        sel = DWgetSelection(dw_linkwiz.textArea);
         if(sel.start == 0 && sel.end == 0) {
             sel = dw_linkwiz.selection;
         }
@@ -235,19 +237,40 @@ var dw_linkwiz = {
            link = ':' + link;
         }
 
-        var so = link.length+3;
-
-        link = '[['+link+'|';
-        if(stxt) {
-            link += stxt;
+        var so = link.length;
+        var eo = 0;
+        if(dw_linkwiz.val){
+            if(dw_linkwiz.val.open) {
+                so += dw_linkwiz.val.open.length;
+                link = dw_linkwiz.val.open+link;
+            }
+            link += '|';
+            so += 1;
+            if(stxt) {
+                link += stxt;
+            }
+            if(dw_linkwiz.val.close) {
+                link += dw_linkwiz.val.close;
+                eo = dw_linkwiz.val.close.length;
+            }
         }
-        link += ']]';
 
-        pasteText(sel,link,{startofs: so, endofs: 2});
+        pasteText(sel,link,{startofs: so, endofs: eo});
         dw_linkwiz.hide();
 
         // reset the entry to the parent namespace
-        dw_linkwiz.$entry.val(dw_linkwiz.$entry.val().replace(/[^:]*$/, ''));
+        var externallinkpattern = new RegExp('^((f|ht)tps?:)?//', 'i'),
+            entry_value;
+        if (externallinkpattern.test(dw_linkwiz.$entry.val())) {
+            if (JSINFO.namespace) {
+                entry_value = JSINFO.namespace + ':';
+            } else {
+                entry_value = ''; //reset whole external links
+            }
+        } else {
+            entry_value = dw_linkwiz.$entry.val().replace(/[^:]*$/, '')
+        }
+        dw_linkwiz.$entry.val(entry_value);
     },
 
     /**
@@ -284,10 +307,15 @@ var dw_linkwiz = {
      * Show the link wizard
      */
     show: function(){
-        dw_linkwiz.selection  = getSelection(dw_linkwiz.textArea);
+        dw_linkwiz.selection  = DWgetSelection(dw_linkwiz.textArea);
         dw_linkwiz.$wiz.show();
         dw_linkwiz.$entry.focus();
         dw_linkwiz.autocomplete();
+
+        // Move the cursor to the end of the input
+        var temp = dw_linkwiz.$entry.val();
+        dw_linkwiz.$entry.val('');
+        dw_linkwiz.$entry.val(temp);
     },
 
     /**
