@@ -1,13 +1,14 @@
 <?php
+
 /**
  * DokuWiki Media Manager Popup
  *
  * @author   Andreas Gohr <andi@splitbrain.org>
  * @license  GPL 2 (http://www.gnu.org/licenses/gpl.html)
  */
+
 // must be run from within DokuWiki
 if (!defined('DOKU_INC')) die();
-header('X-UA-Compatible: IE=edge,chrome=1');
 
 ?><!DOCTYPE html>
 <html lang="<?php echo $conf['lang']?>" dir="<?php echo $lang['direction'] ?>" class="popup no-js">
@@ -20,25 +21,25 @@ header('X-UA-Compatible: IE=edge,chrome=1');
     <script>(function(H){H.className=H.className.replace(/\bno-js\b/,'js')})(document.documentElement)</script>
     <?php tpl_metaheaders()?>
     <meta name="viewport" content="width=device-width,initial-scale=1" />
-    <?php echo tpl_favicon(array('favicon', 'mobile')) ?>
+    <?php echo tpl_favicon(['favicon', 'mobile']) ?>
     <?php tpl_includeFile('meta.html') ?>
 </head>
 
 <body>
     <div id="media__manager" class="dokuwiki">
         <?php html_msgarea() ?>
-        <div id="mediamgr__aside"><div class="pad">
+        <nav id="mediamgr__aside"><div class="pad">
             <h1><?php echo hsc($lang['mediaselect'])?></h1>
 
             <?php /* keep the id! additional elements are inserted via JS here */?>
             <div id="media__opts"></div>
 
             <?php tpl_mediaTree() ?>
-        </div></div>
+        </div></nav>
 
-        <div id="mediamgr__content"><div class="pad">
+        <main id="mediamgr__content"><div class="pad">
             <?php tpl_mediaContent() ?>
-        </div></div>
+        </div></main>
     </div>
 </body>
 </html>
